@@ -3,6 +3,8 @@
 #include <stdlib.h>
 #include <string.h>
 
+#include "config.h"
+
 #include <gtk/gtk.h>
 #include <glib/gstdio.h>
 
@@ -14,6 +16,8 @@ static GtkWidget *source_view;
 static gchar *current_file = NULL;
 
 static GtkWidget *notebook;
+static GtkWidget *treeview;
+static GtkWidget *headerbar;
 
 enum {
   NAME_COLUMN,
@@ -31,6 +35,55 @@ struct _CallbackData
   GtkTreePath *path;
 };
 
+static void
+activate_about (GSimpleAction *action,
+                GVariant      *parameter,
+                gpointer       user_data)
+{
+  GtkApplication *app = user_data;
+  const gchar *authors[] = {
+    "The GTK+ Team",
+    NULL
+  };
+
+  gtk_show_about_dialog (GTK_WINDOW (gtk_application_get_active_window (app)),
+                         "program-name", "GTK+ Demo",
+                         "version", g_strdup_printf ("%s,\nRunning against GTK+ %d.%d.%d",
+                                                     PACKAGE_VERSION,
+                                                     gtk_get_major_version (),
+                                                     gtk_get_minor_version (),
+                                                     gtk_get_micro_version ()),
+                         "copyright", "(C) 1997-2013 The GTK+ Team",
+                         "license-type", GTK_LICENSE_LGPL_2_1,
+                         "website", "http://www.gtk.org",
+                         "comments", "Program to demonstrate GTK+ widgets",
+                         "authors", authors,
+                         "logo-icon-name", "gtk3-demo",
+                         "title", "About GTK+ Demo",
+                         NULL);
+}
+
+static void
+activate_quit (GSimpleAction *action,
+               GVariant      *parameter,
+               gpointer       user_data)
+{
+  GtkApplication *app = user_data;
+  GtkWidget *win;
+  GList *list, *next;
+
+  list = gtk_application_get_windows (app);
+  while (list)
+    {
+      win = list->data;
+      next = list->next;
+
+      gtk_widget_destroy (GTK_WIDGET (win));
+
+      list = next;
+    }
+}
+
 static void
 window_closed_cb (GtkWidget *window, gpointer data)
 {
@@ -51,6 +104,65 @@ window_closed_cb (GtkWidget *window, gpointer data)
   g_free (cbdata);
 }
 
+static void
+run_example_for_row (GtkWidget    *window,
+                     GtkTreeModel *model,
+                     GtkTreeIter  *iter)
+{
+  PangoStyle style;
+  GDoDemoFunc func;
+  GtkWidget *demo;
+
+  gtk_tree_model_get (GTK_TREE_MODEL (model),
+                      iter,
+                      FUNC_COLUMN, &func,
+                      STYLE_COLUMN, &style,
+                      -1);
+
+  if (func)
+    {
+      gtk_tree_store_set (GTK_TREE_STORE (model),
+                          iter,
+                          STYLE_COLUMN, (style == PANGO_STYLE_ITALIC ? PANGO_STYLE_NORMAL : PANGO_STYLE_ITALIC),
+                          -1);
+      demo = (func) (window);
+
+      if (demo != NULL)
+        {
+          CallbackData *cbdata;
+
+          cbdata = g_new (CallbackData, 1);
+          cbdata->model = model;
+          cbdata->path = gtk_tree_model_get_path (model, iter);
+
+          if (gtk_widget_is_toplevel (demo))
+            {
+              gtk_window_set_transient_for (GTK_WINDOW (demo), GTK_WINDOW (window));
+              gtk_window_set_modal (GTK_WINDOW (demo), TRUE);
+            }
+
+          g_signal_connect (demo, "destroy",
+                            G_CALLBACK (window_closed_cb), cbdata);
+        }
+    }
+}
+
+static void
+activate_run (GSimpleAction *action,
+              GVariant      *parameter,
+              gpointer       user_data)
+{
+  GtkWidget *window = user_data;
+  GtkTreeSelection *selection;
+  GtkTreeModel *model;
+  GtkTreeIter iter;
+
+  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview));
+  gtk_tree_selection_get_selected (selection, &model, &iter);
+
+  run_example_for_row (window, model, &iter);
+}
+
 /* Stupid syntax highlighting.
  *
  * No regex was used in the making of this highlighting.
@@ -459,6 +571,10 @@ add_data_tab (const gchar *demoname)
       label = gtk_label_new (resources[i]);
       gtk_widget_show (label);
       gtk_notebook_append_page (GTK_NOTEBOOK (notebook), widget, label);
+      gtk_container_child_set (GTK_CONTAINER (notebook),
+                               GTK_WIDGET (widget),
+                               "tab-expand", TRUE,
+                               NULL);
 
       g_free (content_mime);
       g_free (content_type);
@@ -670,67 +786,31 @@ load_file (const gchar *demoname,
   g_object_unref (source_buffer);
 }
 
-void
-row_activated_cb (GtkTreeView       *tree_view,
-                  GtkTreePath       *path,
-                  GtkTreeViewColumn *column)
-{
-  GtkTreeIter iter;
-  PangoStyle style;
-  GDoDemoFunc func;
-  GtkWidget *window;
-  GtkTreeModel *model;
-
-  model = gtk_tree_view_get_model (tree_view);
-
-  gtk_tree_model_get_iter (model, &iter, path);
-  gtk_tree_model_get (GTK_TREE_MODEL (model),
-                      &iter,
-                      FUNC_COLUMN, &func,
-                      STYLE_COLUMN, &style,
-                      -1);
-
-  if (func)
-    {
-      gtk_tree_store_set (GTK_TREE_STORE (model),
-                          &iter,
-                          STYLE_COLUMN, (style == PANGO_STYLE_ITALIC ? PANGO_STYLE_NORMAL : PANGO_STYLE_ITALIC),
-                          -1);
-      window = (func) (gtk_widget_get_toplevel (GTK_WIDGET (tree_view)));
-
-      if (window != NULL)
-        {
-          CallbackData *cbdata;
-
-          cbdata = g_new (CallbackData, 1);
-          cbdata->model = model;
-          cbdata->path = gtk_tree_path_copy (path);
-
-          g_signal_connect (window, "destroy",
-                            G_CALLBACK (window_closed_cb), cbdata);
-        }
-    }
-}
-
 static void
 selection_cb (GtkTreeSelection *selection,
               GtkTreeModel     *model)
 {
   GtkTreeIter iter;
-  char *name, *filename;
+  char *name;
+  char *filename;
+  char *title;
 
   if (! gtk_tree_selection_get_selected (selection, NULL, &iter))
     return;
 
   gtk_tree_model_get (model, &iter,
                       NAME_COLUMN, &name,
+                      TITLE_COLUMN, &title,
                       FILENAME_COLUMN, &filename,
                       -1);
 
   if (filename)
     load_file (name, filename);
 
+  gtk_header_bar_set_title (GTK_HEADER_BAR (headerbar), title);
+
   g_free (name);
+  g_free (title);
   g_free (filename);
 }
 
@@ -747,7 +827,7 @@ create_text (GtkWidget **view,
                                   GTK_POLICY_AUTOMATIC,
                                   GTK_POLICY_AUTOMATIC);
   gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled_window),
-                                       GTK_SHADOW_IN);
+                                       GTK_SHADOW_NONE);
 
   *view = text_view = gtk_text_view_new ();
   g_object_set (text_view, "margin", 20, NULL);
@@ -780,34 +860,18 @@ create_text (GtkWidget **view,
   return scrolled_window;
 }
 
-static GtkWidget *
-create_tree (void)
+static void
+populate_model (GtkTreeModel *model)
 {
-  GtkTreeSelection *selection;
-  GtkCellRenderer *cell;
-  GtkWidget *tree_view;
-  GtkTreeViewColumn *column;
-  GtkTreeStore *model;
-  GtkTreeIter iter;
-  GtkWidget *box, *label, *scrolled_window;
-
   Demo *d = gtk_demos;
 
-  model = gtk_tree_store_new (NUM_COLUMNS, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_POINTER, G_TYPE_INT);
-  tree_view = gtk_tree_view_new ();
-  gtk_tree_view_set_model (GTK_TREE_VIEW (tree_view), GTK_TREE_MODEL (model));
-  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
-
-  gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection),
-                               GTK_SELECTION_BROWSE);
-  gtk_widget_set_size_request (tree_view, 200, -1);
-
   /* this code only supports 1 level of children. If we
    * want more we probably have to use a recursing function.
    */
   while (d->title)
     {
       Demo *children = d->children;
+      GtkTreeIter iter;
 
       gtk_tree_store_append (GTK_TREE_STORE (model), &iter, NULL);
 
@@ -844,50 +908,102 @@ create_tree (void)
         }
     }
 
-  cell = gtk_cell_renderer_text_new ();
+}
 
-  column = gtk_tree_view_column_new_with_attributes ("Widget (double click for demo)",
-                                                     cell,
-                                                     "text", TITLE_COLUMN,
-                                                     "style", STYLE_COLUMN,
-                                                     NULL);
+static void
+startup (GApplication *app)
+{
+  GtkBuilder *builder;
+  GMenuModel *appmenu;
 
-  gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view),
-                               GTK_TREE_VIEW_COLUMN (column));
+  builder = gtk_builder_new ();
+  gtk_builder_add_from_resource (builder, "/ui/main.ui", NULL);
 
-  gtk_tree_model_get_iter_first (GTK_TREE_MODEL (model), &iter);
-  gtk_tree_selection_select_iter (GTK_TREE_SELECTION (selection), &iter);
+  appmenu = (GMenuModel *)gtk_builder_get_object (builder, "appmenu");
 
-  g_signal_connect (selection, "changed", G_CALLBACK (selection_cb), model);
-  g_signal_connect (tree_view, "row_activated", G_CALLBACK (row_activated_cb), model);
+  gtk_application_set_app_menu (GTK_APPLICATION (app), appmenu);
 
-  gtk_tree_view_collapse_all (GTK_TREE_VIEW (tree_view));
-  gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (tree_view), FALSE);
+  g_object_unref (builder);
+}
 
-  scrolled_window = gtk_scrolled_window_new (NULL, NULL);
-  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
-                                  GTK_POLICY_NEVER,
-                                  GTK_POLICY_AUTOMATIC);
-  gtk_container_add (GTK_CONTAINER (scrolled_window), tree_view);
+static void
+row_activated_cb (GtkWidget         *tree_view,
+                  GtkTreePath       *path,
+                  GtkTreeViewColumn *column)
+{
+  GtkTreeIter iter;
+  GtkWidget *window;
+  GtkTreeModel *model;
 
-  label = gtk_label_new ("Widget (double click for demo)");
+  window = gtk_widget_get_toplevel (tree_view);
+  model = gtk_tree_view_get_model (GTK_TREE_VIEW (tree_view));
+  gtk_tree_model_get_iter (model, &iter, path);
 
-  box = gtk_notebook_new ();
-  gtk_notebook_append_page (GTK_NOTEBOOK (box), scrolled_window, label);
+  run_example_for_row (window, model, &iter);
+}
 
-  gtk_widget_grab_focus (tree_view);
+static void
+activate (GApplication *app)
+{
+  GtkBuilder *builder;
+  GtkWindow *window;
+  GtkWidget *widget;
+  GtkTreeModel *model;
+  GtkTreeIter iter;
+  GError *error = NULL;
+  static GActionEntry win_entries[] = {
+    { "run", activate_run, NULL, NULL, NULL }
+  };
 
-   g_object_unref (model);
+  builder = gtk_builder_new ();
+  gtk_builder_add_from_resource (builder, "/ui/main.ui", &error);
+  if (error != NULL)
+    {
+      g_critical ("%s", error->message);
+      exit (1);
+    }
 
-  return box;
+  window = (GtkWindow *)gtk_builder_get_object (builder, "window");
+  gtk_application_add_window (GTK_APPLICATION (app), window);
+  g_action_map_add_action_entries (G_ACTION_MAP (window),
+                                   win_entries, G_N_ELEMENTS (win_entries),
+                                   window);
+
+  notebook = (GtkWidget *)gtk_builder_get_object (builder, "notebook");
+
+  info_view = (GtkWidget *)gtk_builder_get_object (builder, "info-textview");
+  source_view = (GtkWidget *)gtk_builder_get_object (builder, "source-textview");
+  headerbar = (GtkWidget *)gtk_builder_get_object (builder, "headerbar");
+  treeview = (GtkWidget *)gtk_builder_get_object (builder, "treeview");
+  model = gtk_tree_view_get_model (GTK_TREE_VIEW (treeview));
+
+  load_file (gtk_demos[0].name, gtk_demos[0].filename);
+
+  populate_model (model);
+
+  g_signal_connect (treeview, "row-activated", G_CALLBACK (row_activated_cb), model);
+
+  widget = (GtkWidget *)gtk_builder_get_object (builder, "treeview-selection");
+  g_signal_connect (widget, "changed", G_CALLBACK (selection_cb), model);
+
+  gtk_tree_model_get_iter_first (gtk_tree_view_get_model (GTK_TREE_VIEW (treeview)), &iter);
+  gtk_tree_selection_select_iter (GTK_TREE_SELECTION (widget), &iter);
+
+  gtk_tree_view_collapse_all (GTK_TREE_VIEW (treeview));
+
+  gtk_widget_show_all (GTK_WIDGET (window));
+
+  g_object_unref (builder);
 }
 
 int
 main (int argc, char **argv)
 {
-  GtkWidget *window;
-  GtkWidget *hbox;
-  GtkWidget *tree;
+  GtkApplication *app;
+  static GActionEntry app_entries[] = {
+    { "about", activate_about, NULL, NULL, NULL },
+    { "quit", activate_quit, NULL, NULL, NULL },
+  };
 
   /* Most code in gtk-demo is intended to be exemplary, but not
    * these few lines, which are just a hack so gtk-demo will work
@@ -901,38 +1017,16 @@ main (int argc, char **argv)
 
   gtk_init (&argc, &argv);
 
-  gtk_window_set_default_icon_name ("gtk3-demo");
+  app = gtk_application_new ("org.gtk.Demo", 0);
 
-  window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-  gtk_window_set_title (GTK_WINDOW (window), "GTK+ Code Demos");
-  g_signal_connect_after (window, "destroy",
-                    G_CALLBACK (gtk_main_quit), NULL);
+  g_action_map_add_action_entries (G_ACTION_MAP (app),
+                                   app_entries, G_N_ELEMENTS (app_entries),
+                                   app);
 
-  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-  gtk_container_add (GTK_CONTAINER (window), hbox);
+  g_signal_connect (app, "startup", G_CALLBACK (startup), NULL);
+  g_signal_connect (app, "activate", G_CALLBACK (activate), NULL);
 
-  tree = create_tree ();
-  gtk_box_pack_start (GTK_BOX (hbox), tree, FALSE, FALSE, 0);
-
-  notebook = gtk_notebook_new ();
-  gtk_notebook_set_scrollable (GTK_NOTEBOOK (notebook), TRUE);
-  gtk_notebook_popup_enable (GTK_NOTEBOOK (notebook));
-  gtk_box_pack_start (GTK_BOX (hbox), notebook, TRUE, TRUE, 0);
-
-  gtk_notebook_append_page (GTK_NOTEBOOK (notebook),
-                            create_text (&info_view, FALSE),
-                            gtk_label_new_with_mnemonic ("_Info"));
-
-  gtk_notebook_append_page (GTK_NOTEBOOK (notebook),
-                            create_text (&source_view, TRUE),
-                            gtk_label_new_with_mnemonic ("_Source"));
-
-  gtk_window_set_default_size (GTK_WINDOW (window), 600, 400);
-  gtk_widget_show_all (window);
-
-  load_file (gtk_demos[0].name, gtk_demos[0].filename);
-
-  gtk_main ();
+  g_application_run (G_APPLICATION (app), argc, argv);
 
   return 0;
 }
