@@ -24,12 +24,17 @@
 
 #include "config.h"
 
+#define GDK_PIXBUF_ENABLE_BACKEND
+#include <gdk-pixbuf/gdk-pixbuf.h>
+
 #include "gdkcursor.h"
 #include "gdkcursorprivate.h"
 #include "gdkdisplayprivate.h"
 #include "gdkintl.h"
 #include "gdkinternals.h"
 
+#include <math.h>
+#include <errno.h>
 
 /**
  * SECTION:cursors
@@ -49,13 +54,13 @@
  * Cursors by themselves are not very interesting, they must be be
  * bound to a window for users to see them. This is done with
  * gdk_window_set_cursor() or by setting the cursor member of the
- * #GdkWindowAttr struct passed to gdk_window_new().
+ * #GdkWindowAttr passed to gdk_window_new().
  */
 
 /**
  * GdkCursor:
  *
- * The #GdkCursor structure represents a cursor. Its contents are private.
+ * A #GdkCursor represents a cursor. Its contents are private.
  */
 
 enum {
@@ -219,62 +224,24 @@ gdk_cursor_get_cursor_type (GdkCursor *cursor)
  *
  * Creates a new cursor from the set of builtin cursors.
  * Some useful ones are:
- * <itemizedlist>
- * <listitem><para>
- *  <inlinegraphic format="PNG" fileref="right_ptr.png"></inlinegraphic> #GDK_RIGHT_PTR (right-facing arrow)
- * </para></listitem>
- * <listitem><para>
- *  <inlinegraphic format="PNG" fileref="crosshair.png"></inlinegraphic> #GDK_CROSSHAIR (crosshair)
- * </para></listitem>
- * <listitem><para>
- *  <inlinegraphic format="PNG" fileref="xterm.png"></inlinegraphic> #GDK_XTERM (I-beam)
- * </para></listitem>
- * <listitem><para>
- * <inlinegraphic format="PNG" fileref="watch.png"></inlinegraphic> #GDK_WATCH (busy)
- * </para></listitem>
- * <listitem><para>
- * <inlinegraphic format="PNG" fileref="fleur.png"></inlinegraphic> #GDK_FLEUR (for moving objects)
- * </para></listitem>
- * <listitem><para>
- * <inlinegraphic format="PNG" fileref="hand1.png"></inlinegraphic> #GDK_HAND1 (a right-pointing hand)
- * </para></listitem>
- * <listitem><para>
- * <inlinegraphic format="PNG" fileref="hand2.png"></inlinegraphic> #GDK_HAND2 (a left-pointing hand)
- * </para></listitem>
- * <listitem><para>
- * <inlinegraphic format="PNG" fileref="left_side.png"></inlinegraphic> #GDK_LEFT_SIDE (resize left side)
- * </para></listitem>
- * <listitem><para>
- * <inlinegraphic format="PNG" fileref="right_side.png"></inlinegraphic> #GDK_RIGHT_SIDE (resize right side)
- * </para></listitem>
- * <listitem><para>
- * <inlinegraphic format="PNG" fileref="top_left_corner.png"></inlinegraphic> #GDK_TOP_LEFT_CORNER (resize northwest corner)
- * </para></listitem>
- * <listitem><para>
- * <inlinegraphic format="PNG" fileref="top_right_corner.png"></inlinegraphic> #GDK_TOP_RIGHT_CORNER (resize northeast corner)
- * </para></listitem>
- * <listitem><para>
- * <inlinegraphic format="PNG" fileref="bottom_left_corner.png"></inlinegraphic> #GDK_BOTTOM_LEFT_CORNER (resize southwest corner)
- * </para></listitem>
- * <listitem><para>
- * <inlinegraphic format="PNG" fileref="bottom_right_corner.png"></inlinegraphic> #GDK_BOTTOM_RIGHT_CORNER (resize southeast corner)
- * </para></listitem>
- * <listitem><para>
- * <inlinegraphic format="PNG" fileref="top_side.png"></inlinegraphic> #GDK_TOP_SIDE (resize top side)
- * </para></listitem>
- * <listitem><para>
- * <inlinegraphic format="PNG" fileref="bottom_side.png"></inlinegraphic> #GDK_BOTTOM_SIDE (resize bottom side)
- * </para></listitem>
- * <listitem><para>
- * <inlinegraphic format="PNG" fileref="sb_h_double_arrow.png"></inlinegraphic> #GDK_SB_H_DOUBLE_ARROW (move vertical splitter)
- * </para></listitem>
- * <listitem><para>
- * <inlinegraphic format="PNG" fileref="sb_v_double_arrow.png"></inlinegraphic> #GDK_SB_V_DOUBLE_ARROW (move horizontal splitter)
- * </para></listitem>
- * <listitem><para>
- * #GDK_BLANK_CURSOR (Blank cursor). Since 2.16
- * </para></listitem>
- * </itemizedlist>
+ * - <inlinegraphic format="PNG" fileref="right_ptr.png"></inlinegraphic> #GDK_RIGHT_PTR (right-facing arrow)
+ * - <inlinegraphic format="PNG" fileref="crosshair.png"></inlinegraphic> #GDK_CROSSHAIR (crosshair)
+ * - <inlinegraphic format="PNG" fileref="xterm.png"></inlinegraphic> #GDK_XTERM (I-beam)
+ * - <inlinegraphic format="PNG" fileref="watch.png"></inlinegraphic> #GDK_WATCH (busy)
+ * - <inlinegraphic format="PNG" fileref="fleur.png"></inlinegraphic> #GDK_FLEUR (for moving objects)
+ * - <inlinegraphic format="PNG" fileref="hand1.png"></inlinegraphic> #GDK_HAND1 (a right-pointing hand)
+ * - <inlinegraphic format="PNG" fileref="hand2.png"></inlinegraphic> #GDK_HAND2 (a left-pointing hand)
+ * - <inlinegraphic format="PNG" fileref="left_side.png"></inlinegraphic> #GDK_LEFT_SIDE (resize left side)
+ * - <inlinegraphic format="PNG" fileref="right_side.png"></inlinegraphic> #GDK_RIGHT_SIDE (resize right side)
+ * - <inlinegraphic format="PNG" fileref="top_left_corner.png"></inlinegraphic> #GDK_TOP_LEFT_CORNER (resize northwest corner)
+ * - <inlinegraphic format="PNG" fileref="top_right_corner.png"></inlinegraphic> #GDK_TOP_RIGHT_CORNER (resize northeast corner)
+ * - <inlinegraphic format="PNG" fileref="bottom_left_corner.png"></inlinegraphic> #GDK_BOTTOM_LEFT_CORNER (resize southwest corner)
+ * - <inlinegraphic format="PNG" fileref="bottom_right_corner.png"></inlinegraphic> #GDK_BOTTOM_RIGHT_CORNER (resize southeast corner)
+ * - <inlinegraphic format="PNG" fileref="top_side.png"></inlinegraphic> #GDK_TOP_SIDE (resize top side)
+ * - <inlinegraphic format="PNG" fileref="bottom_side.png"></inlinegraphic> #GDK_BOTTOM_SIDE (resize bottom side)
+ * - <inlinegraphic format="PNG" fileref="sb_h_double_arrow.png"></inlinegraphic> #GDK_SB_H_DOUBLE_ARROW (move vertical splitter)
+ * - <inlinegraphic format="PNG" fileref="sb_v_double_arrow.png"></inlinegraphic> #GDK_SB_V_DOUBLE_ARROW (move horizontal splitter)
+ * - #GDK_BLANK_CURSOR (Blank cursor). Since 2.16
  *
  * Return value: a new #GdkCursor
  *
@@ -331,7 +298,7 @@ gdk_cursor_new_from_name (GdkDisplay  *display,
  *
  * If @x or @y are <literal>-1</literal>, the pixbuf must have
  * options named "x_hot" and "y_hot", resp., containing
- * integer values between %0 and the width resp. height of
+ * integer values between <literal>0</literal> and the width resp. height of
  * the pixbuf. (Since: 3.0)
  *
  * On the X backend, support for RGBA cursors requires a
@@ -347,12 +314,81 @@ gdk_cursor_new_from_pixbuf (GdkDisplay *display,
                             gint        x,
                             gint        y)
 {
+  cairo_surface_t *surface;
+  const char *option;
+  char *end;
+  gint64 value;
+ 
   g_return_val_if_fail (GDK_IS_DISPLAY (display), NULL);
   g_return_val_if_fail (GDK_IS_PIXBUF (pixbuf), NULL);
 
-  return GDK_DISPLAY_GET_CLASS (display)->get_cursor_for_pixbuf (display, pixbuf, x, y);
+  if (x == -1 && (option = gdk_pixbuf_get_option (pixbuf, "x_hot")))
+    {
+      errno = 0;
+      end = NULL;
+      value = g_ascii_strtoll (option, &end, 10);
+      if (errno == 0 &&
+          end != option &&
+          value >= 0 && value < G_MAXINT)
+        x = (gint) value;
+    }
+  
+  if (y == -1 && (option = gdk_pixbuf_get_option (pixbuf, "y_hot")))
+    {
+      errno = 0;
+      end = NULL;
+      value = g_ascii_strtoll (option, &end, 10);
+      if (errno == 0 &&
+          end != option &&
+          value >= 0 && value < G_MAXINT)
+        y = (gint) value;
+    }
+
+  surface = gdk_cairo_surface_create_from_pixbuf (pixbuf, 1, NULL);
+  
+  return GDK_DISPLAY_GET_CLASS (display)->get_cursor_for_surface (display, surface, x, y);
 }
 
+/**
+ * gdk_cursor_new_from_surface:
+ * @display: the #GdkDisplay for which the cursor will be created
+ * @surface: the cairo image surface containing the cursor pixel data
+ * @x: the horizontal offset of the 'hotspot' of the cursor
+ * @y: the vertical offset of the 'hotspot' of the cursor
+ *
+ * Creates a new cursor from a cairo image surface.
+ *
+ * Not all GDK backends support RGBA cursors. If they are not
+ * supported, a monochrome approximation will be displayed.
+ * The functions gdk_display_supports_cursor_alpha() and
+ * gdk_display_supports_cursor_color() can be used to determine
+ * whether RGBA cursors are supported;
+ * gdk_display_get_default_cursor_size() and
+ * gdk_display_get_maximal_cursor_size() give information about
+ * cursor sizes.
+ *
+ * On the X backend, support for RGBA cursors requires a
+ * sufficently new version of the X Render extension.
+ *
+ * Returns: a new #GdkCursor.
+ *
+ * Since: 3.10
+ */
+GdkCursor *
+gdk_cursor_new_from_surface (GdkDisplay      *display,
+			     cairo_surface_t *surface,
+			     gdouble          x,
+			     gdouble          y)
+{
+  g_return_val_if_fail (GDK_IS_DISPLAY (display), NULL);
+  g_return_val_if_fail (surface != NULL, NULL);
+  g_return_val_if_fail (cairo_surface_get_type (surface) == CAIRO_SURFACE_TYPE_IMAGE, NULL);
+  g_return_val_if_fail (0 <= x && x < cairo_image_surface_get_width (surface), NULL);
+  g_return_val_if_fail (0 <= y && y < cairo_image_surface_get_height (surface), NULL);
+
+  return GDK_DISPLAY_GET_CLASS (display)->get_cursor_for_surface (display,
+								  surface, x, y);
+}
 /**
  * gdk_cursor_get_display:
  * @cursor: a #GdkCursor.
@@ -389,7 +425,73 @@ gdk_cursor_get_display (GdkCursor *cursor)
 GdkPixbuf*  
 gdk_cursor_get_image (GdkCursor *cursor)
 {
+  int w, h;
+  cairo_surface_t *surface;
+  GdkPixbuf *pixbuf;
+  gchar buf[32];
+  double x_hot, y_hot;
+  double x_scale, y_scale;
+
   g_return_val_if_fail (GDK_IS_CURSOR (cursor), NULL);
 
-  return GDK_CURSOR_GET_CLASS (cursor)->get_image (cursor);
+  surface = gdk_cursor_get_surface (cursor, &x_hot, &y_hot);
+  if (surface == NULL)
+    return NULL;
+
+  w = cairo_image_surface_get_width (surface);
+  h = cairo_image_surface_get_height (surface);
+
+  x_scale = y_scale = 1;
+#ifdef HAVE_CAIRO_SURFACE_SET_DEVICE_SCALE
+  cairo_surface_get_device_scale (surface, &x_scale, &y_scale);
+#endif
+
+  pixbuf = gdk_pixbuf_get_from_surface (surface, 0, 0, w, h);
+  cairo_surface_destroy (surface);
+
+  if (x_scale != 1)
+    {
+      GdkPixbuf *old;
+
+      old = pixbuf;
+      pixbuf = gdk_pixbuf_scale_simple (old,
+					w / x_scale, h / y_scale,
+					GDK_INTERP_HYPER);
+      g_object_unref (old);
+    }
+
+  
+  g_snprintf (buf, 32, "%d", (int)x_hot);
+  gdk_pixbuf_set_option (pixbuf, "x_hot", buf);
+
+  g_snprintf (buf, 32, "%d", (int)y_hot);
+  gdk_pixbuf_set_option (pixbuf, "y_hot", buf);
+
+  return pixbuf;
+}
+
+/**
+ * gdk_cursor_get_surface:
+ * @cursor: a #GdkCursor
+ * @x_hot: Location to store the hotspot x position, or %NULL
+ * @y_hot: Location to store the hotspot y position, or %NULL
+ *
+ * Returns a cairo image surface with the image used to display the cursor.
+ *
+ * Note that depending on the capabilities of the windowing system and
+ * on the cursor, GDK may not be able to obtain the image data. In this
+ * case, %NULL is returned.
+ *
+ * Returns: (transfer full): a #cairo_surface_t representing @cursor, or %NULL
+ *
+ * Since: 3.10
+ */
+cairo_surface_t *
+gdk_cursor_get_surface (GdkCursor *cursor,
+			gdouble   *x_hot,
+			gdouble   *y_hot)
+{
+  g_return_val_if_fail (GDK_IS_CURSOR (cursor), NULL);
+
+  return GDK_CURSOR_GET_CLASS (cursor)->get_surface (cursor, x_hot, y_hot);
 }
