@@ -189,25 +189,6 @@ gdk_keymap_init (GdkKeymap *keymap)
 /* Other key-handling stuff
  */
 
-/**
- * gdk_keyval_convert_case:
- * @symbol: a keyval
- * @lower: (out): return location for lowercase version of @symbol
- * @upper: (out): return location for uppercase version of @symbol
- *
- * Obtains the upper- and lower-case versions of the keyval @symbol.
- * Examples of keyvals are #GDK_KEY_a, #GDK_KEY_Enter, #GDK_KEY_F1, etc.
- */
-void
-gdk_keyval_convert_case (guint symbol,
-                         guint *lower,
-                         guint *upper)
-{
-  GdkDisplayManager *manager = gdk_display_manager_get ();
-
-  GDK_DISPLAY_MANAGER_GET_CLASS (manager)->keyval_convert_case (manager, symbol, lower, upper);
-}
-
 /**
  * gdk_keyval_to_upper:
  * @keyval: a key value.
@@ -400,7 +381,7 @@ gdk_keymap_get_modifier_state (GdkKeymap *keymap)
 /**
  * gdk_keymap_get_entries_for_keyval:
  * @keymap: a #GdkKeymap
- * @keyval: a keyval, such as %GDK_a, %GDK_Up, %GDK_Return, etc.
+ * @keyval: a keyval, such as %GDK_KEY_a, %GDK_KEY_Up, %GDK_KEY_Return, etc.
  * @keys: (out) (array length=n_keys) (transfer full): return location
  *     for an array of #GdkKeymapKey
  * @n_keys: return location for number of elements in returned array
@@ -514,48 +495,46 @@ gdk_keymap_lookup_key (GdkKeymap          *keymap,
  * @state. For convenience, #GdkEventKey already contains the translated
  * keyval, so this function isn't as useful as you might think.
  *
- * <note><para>
  * @consumed_modifiers gives modifiers that should be masked out
  * from @state when comparing this key press to a hot key. For
  * instance, on a US keyboard, the <literal>plus</literal>
  * symbol is shifted, so when comparing a key press to a
  * <literal>&lt;Control&gt;plus</literal> accelerator &lt;Shift&gt; should
  * be masked out.
- * </para>
- * <informalexample><programlisting>
- * &sol;* We want to ignore irrelevant modifiers like ScrollLock *&sol;
- * &num;define ALL_ACCELS_MASK (GDK_CONTROL_MASK | GDK_SHIFT_MASK | GDK_MOD1_MASK)
+ *
+ * |[<!-- language="C" -->
+ * /&ast; We want to ignore irrelevant modifiers like ScrollLock &ast;/;
+ * #define ALL_ACCELS_MASK (GDK_CONTROL_MASK | GDK_SHIFT_MASK | GDK_MOD1_MASK)
  * gdk_keymap_translate_keyboard_state (keymap, event->hardware_keycode,
  *                                      event->state, event->group,
- *                                      &amp;keyval, NULL, NULL, &amp;consumed);
+ *                                      &keyval, NULL, NULL, &consumed);
  * if (keyval == GDK_PLUS &&
- *     (event->state &amp; ~consumed &amp; ALL_ACCELS_MASK) == GDK_CONTROL_MASK)
- *   &sol;* Control was pressed *&sol;
- * </programlisting></informalexample>
- * <para>
+ *     (event->state & ~consumed & ALL_ACCELS_MASK) == GDK_CONTROL_MASK)
+ *   /&ast; Control was pressed &ast;/
+ * ]|
+ * 
  * An older interpretation @consumed_modifiers was that it contained
  * all modifiers that might affect the translation of the key;
  * this allowed accelerators to be stored with irrelevant consumed
- * modifiers, by doing:</para>
- * <informalexample><programlisting>
- * &sol;* XXX Don't do this XXX *&sol;
+ * modifiers, by doing:
+ * |[<!-- language="C" -->
+ * /&ast; XXX Don't do this XXX &ast;/
  * if (keyval == accel_keyval &&
- *     (event->state &amp; ~consumed &amp; ALL_ACCELS_MASK) == (accel_mods &amp; ~consumed))
- *   &sol;* Accelerator was pressed *&sol;
- * </programlisting></informalexample>
- * <para>
+ *     (event->state & ~consumed & ALL_ACCELS_MASK) == (accel_mods & ~consumed))
+ *   /&ast; Accelerator was pressed &ast;/
+ * ]|
+ *
  * However, this did not work if multi-modifier combinations were
  * used in the keymap, since, for instance, <literal>&lt;Control&gt;</literal>
  * would be masked out even if only <literal>&lt;Control&gt;&lt;Alt&gt;</literal>
  * was used in the keymap. To support this usage as well as well as
- * possible, all <emphasis>single modifier</emphasis> combinations
+ * possible, all single modifier combinations
  * that could affect the key for any combination of modifiers will
  * be returned in @consumed_modifiers; multi-modifier combinations
  * are returned only when actually found in @state. When you store
  * accelerators, you should always store them with consumed modifiers
  * removed. Store <literal>&lt;Control&gt;plus</literal>,
  * not <literal>&lt;Control&gt;&lt;Shift&gt;plus</literal>,
- * </para></note>
  *
  * Return value: %TRUE if there was a keyval bound to the keycode/state/group
  **/
@@ -584,12 +563,11 @@ gdk_keymap_translate_keyboard_state (GdkKeymap       *keymap,
 /**
  * gdk_keymap_add_virtual_modifiers:
  * @keymap: a #GdkKeymap
- * @state: (out): pointer to the modifier mask to change
+ * @state: (inout): pointer to the modifier mask to change
  *
- * Adds virtual modifiers (i.e. Super, Hyper and Meta) which correspond
- * to the real modifiers (i.e Mod2, Mod3, ...) in @modifiers.
- * are set in @state to their non-virtual counterparts (i.e. Mod2,
- * Mod3,...) and set the corresponding bits in @state.
+ * Maps the non-virtual modifiers (i.e Mod2, Mod3, ...) which are set
+ * in @state to the virtual modifiers (i.e. Super, Hyper and Meta) and
+ * set the corresponding bits in @state.
  *
  * GDK already does this before delivering key events, but for
  * compatibility reasons, it only sets the first virtual modifier
@@ -612,7 +590,7 @@ gdk_keymap_add_virtual_modifiers (GdkKeymap       *keymap,
 /**
  * gdk_keymap_map_virtual_modifiers:
  * @keymap: a #GdkKeymap
- * @state: (out): pointer to the modifier state to map
+ * @state: (inout): pointer to the modifier state to map
  *
  * Maps the virtual modifiers (i.e. Super, Hyper and Meta) which
  * are set in @state to their non-virtual counterparts (i.e. Mod2,
@@ -694,6 +672,7 @@ gdk_keymap_get_modifier_mask (GdkKeymap         *keymap,
   return GDK_KEYMAP_GET_CLASS (keymap)->get_modifier_mask (keymap, intent);
 }
 
+#include "gdkkeynames.c"
 
 /**
  * gdk_keyval_name:
@@ -712,10 +691,7 @@ gdk_keymap_get_modifier_mask (GdkKeymap         *keymap,
 gchar *
 gdk_keyval_name (guint keyval)
 {
-  GdkDisplayManager *manager = gdk_display_manager_get ();
-
-  return GDK_DISPLAY_MANAGER_GET_CLASS (manager)->get_keyval_name (manager,
-                                                                   keyval);
+  return _gdk_keyval_name (keyval);
 }
 
 /**
@@ -734,20 +710,27 @@ gdk_keyval_name (guint keyval)
 guint
 gdk_keyval_from_name (const gchar *keyval_name)
 {
-  GdkDisplayManager *manager = gdk_display_manager_get ();
-
-  return GDK_DISPLAY_MANAGER_GET_CLASS (manager)->lookup_keyval (manager,
-                                                                 keyval_name);
+  return _gdk_keyval_from_name (keyval_name);
 }
 
+/**
+ * gdk_keyval_convert_case:
+ * @symbol: a keyval
+ * @lower: (out): return location for lowercase version of @symbol
+ * @upper: (out): return location for uppercase version of @symbol
+ *
+ * Obtains the upper- and lower-case versions of the keyval @symbol.
+ * Examples of keyvals are #GDK_KEY_a, #GDK_KEY_Enter, #GDK_KEY_F1, etc.
+ */
 void
-_gdk_display_manager_real_keyval_convert_case (GdkDisplayManager *manager,
-                                               guint              symbol,
-                                               guint             *lower,
-                                               guint             *upper)
+gdk_keyval_convert_case (guint symbol,
+                         guint *lower,
+                         guint *upper)
 {
-  guint xlower = symbol;
-  guint xupper = symbol;
+  guint xlower, xupper;
+
+  xlower = symbol;
+  xupper = symbol;
 
   /* Check for directly encoded 24-bit UCS characters: */
   if ((symbol & 0xff000000) == 0x01000000)
