@@ -25,7 +25,6 @@
 #include "config.h"
 
 #include "gdkrectangle.h"
-#include <cairo-gobject.h>
 
 
 /**
@@ -34,7 +33,7 @@
  * @Title: Points and Rectangles
  *
  * GDK provides the #GdkPoint and #GdkRectangle data types for representing pixels
- * and sets of pixels on the screen. Together with Cairo’s #cairo_region_t data
+ * and sets of pixels on the screen. Together with Cairo's #cairo_region_t data
  * type, they make up the central types for representing graphical data.
  *
  * A #GdkPoint represents an x and y coordinate of a point.
@@ -87,7 +86,7 @@ gdk_rectangle_union (const GdkRectangle *src1,
  *
  * Calculates the intersection of two rectangles. It is allowed for
  * @dest to be the same as either @src1 or @src2. If the rectangles 
- * do not intersect, @dest’s width and height is set to 0 and its x 
+ * do not intersect, @dest's width and height is set to 0 and its x 
  * and y values are undefined. If you are only interested in whether
  * the rectangles intersect, but not in the intersecting area itself,
  * pass %NULL for @dest.
@@ -142,36 +141,6 @@ gdk_rectangle_copy (const GdkRectangle *rectangle)
   return result;
 }
 
-/* Transforms between identical boxed types.
- */
-static void
-gdk_rectangle_value_transform_rect (const GValue *src_value, GValue *dest_value)
-{
-  g_value_set_boxed (dest_value, g_value_get_boxed (src_value));
-}
-
-/* Allow GValue transformation between the identical structs
- * cairo_rectangle_int_t and GdkRectangle.
- */
-static void
-gdk_rectangle_register_value_transform_funcs (GType gtype_gdk_rectangle)
-{
-  /* This function is called from the first call to gdk_rectangle_get_type(),
-   * before g_once_init_leave() has been called.
-   * If gdk_rectangle_get_type() is called from here (e.g. via
-   * GDK_TYPE_RECTANGLE), the program will wait indefinitely at
-   * g_once_init_enter() in gdk_rectangle_get_type().
-   */
-  g_value_register_transform_func (CAIRO_GOBJECT_TYPE_RECTANGLE_INT,
-                                   gtype_gdk_rectangle,
-                                   gdk_rectangle_value_transform_rect);
-  g_value_register_transform_func (gtype_gdk_rectangle,
-                                   CAIRO_GOBJECT_TYPE_RECTANGLE_INT,
-                                   gdk_rectangle_value_transform_rect);
-}
-
-G_DEFINE_BOXED_TYPE_WITH_CODE (GdkRectangle, gdk_rectangle,
-                               gdk_rectangle_copy,
-                               g_free,
-                               gdk_rectangle_register_value_transform_funcs (g_define_type_id))
-
+G_DEFINE_BOXED_TYPE (GdkRectangle, gdk_rectangle,
+                     gdk_rectangle_copy,
+                     g_free)
