@@ -315,6 +315,10 @@ frame_callback (void               *data,
   GdkFrameTimings *timings;
 
   wl_callback_destroy (callback);
+
+  if (GDK_WINDOW_DESTROYED (window))
+    return;
+
   _gdk_frame_clock_thaw (clock);
 
   timings = gdk_frame_clock_get_timings (clock, impl->pending_frame_counter);
@@ -413,7 +417,11 @@ on_frame_clock_after_paint (GdkFrameClock *clock,
 
   data = cairo_surface_get_user_data (impl->cairo_surface,
                                       &gdk_wayland_cairo_key);
-  data->busy = TRUE;
+  if (!data->busy)
+    {
+      data->busy = TRUE;
+      cairo_surface_reference (impl->cairo_surface);
+    }
 }
 
 static void
@@ -606,7 +614,6 @@ gdk_wayland_cairo_surface_destroy (void *p)
   g_free (data);
 }
 
-
 struct wl_shm_pool *
 _create_shm_pool (struct wl_shm  *shm,
                   int             width,
@@ -663,9 +670,11 @@ static void
 buffer_release_callback (void             *_data,
                          struct wl_buffer *wl_buffer)
 {
-  GdkWaylandCairoSurfaceData *data = _data;
+  cairo_surface_t *surface = _data;
+  GdkWaylandCairoSurfaceData *data = cairo_surface_get_user_data (surface, &gdk_wayland_cairo_key);
 
   data->busy = FALSE;
+  cairo_surface_destroy (surface);
 }
 
 static const struct wl_buffer_listener buffer_listener = {
@@ -698,17 +707,17 @@ gdk_wayland_create_cairo_surface (GdkWaylandDisplay *display,
                                  &data->buf_length,
                                  &data->buf);
 
-  data->buffer = wl_shm_pool_create_buffer (data->pool, 0,
-                                            width*scale, height*scale,
-                                            stride*scale, WL_SHM_FORMAT_ARGB8888);
-  wl_buffer_add_listener (data->buffer, &buffer_listener, data);
-
   surface = cairo_image_surface_create_for_data (data->buf,
                                                  CAIRO_FORMAT_ARGB32,
                                                  width*scale,
                                                  height*scale,
                                                  stride*scale);
 
+  data->buffer = wl_shm_pool_create_buffer (data->pool, 0,
+                                            width*scale, height*scale,
+                                            stride*scale, WL_SHM_FORMAT_ARGB8888);
+  wl_buffer_add_listener (data->buffer, &buffer_listener, surface);
+
   cairo_surface_set_user_data (surface, &gdk_wayland_cairo_key,
                                data, gdk_wayland_cairo_surface_destroy);
 
@@ -2266,17 +2275,16 @@ gdk_wayland_window_get_wl_surface (GdkWindow *window)
  *
  * A good example would be writing a panel or on-screen-keyboard as an
  * out-of-process helper - as opposed to having those in the compositor
- * process. In this case the underlying surface isn't a wl_shell
+ * process. In this case the underlying surface isn't an xdg_shell
  * surface and the panel or OSK client need to identify the wl_surface
  * as a panel or OSK to the compositor. The assumption is that the
  * compositor will expose a private interface to the special client
  * that lets the client identify the wl_surface as a panel or such.
  *
  * This function should be called before a #GdkWindow is shown. This is
- * best done by connecting to the #GtkWidget::realized signal:
+ * best done by connecting to the #GtkWidget::realize signal:
  *
- * <informalexample>
- * <programlisting>
+ * |[<!-- language="C" -->
  *   static void
  *   widget_realize_cb (GtkWidget *widget)
  *   {
@@ -2297,8 +2305,7 @@ gdk_wayland_window_get_wl_surface (GdkWindow *window)
  *   {
  *     g_signal_connect (window, "realize", G_CALLBACK (widget_realize_cb), NULL);
  *   }
- * </programlisting>
- * </informalexample>
+ * ]|
  *
  * Since: 3.10
  */
