@@ -64,7 +64,7 @@ static guint theme_serial = 0;
 /* cursor_cache holds a cache of non-pixmap cursors to avoid expensive 
  * libXcursor searches, cursors are added to it but only removed when
  * their display is closed. We make the assumption that since there are 
- * a small number of display’s and a small number of cursor’s that this 
+ * a small number of display's and a small number of cursor's that this 
  * list will stay small enough not to be a problem.
  */
 static GSList* cursor_cache = NULL;
@@ -291,7 +291,7 @@ _gdk_x11_display_get_cursor_for_type (GdkDisplay    *display,
  * 
  * Returns the display of a #GdkCursor.
  * 
- * Returns: (transfer none): an Xlib Display*.
+ * Return value: (transfer none): an Xlib Display*.
  **/
 Display *
 gdk_x11_cursor_get_xdisplay (GdkCursor *cursor)
@@ -307,7 +307,7 @@ gdk_x11_cursor_get_xdisplay (GdkCursor *cursor)
  * 
  * Returns the X cursor belonging to a #GdkCursor.
  * 
- * Returns: an Xlib Cursor.
+ * Return value: an Xlib Cursor.
  **/
 Cursor
 gdk_x11_cursor_get_xcursor (GdkCursor *cursor)
@@ -319,7 +319,7 @@ gdk_x11_cursor_get_xcursor (GdkCursor *cursor)
 
 #if defined(HAVE_XCURSOR) && defined(HAVE_XFIXES) && XFIXES_MAJOR >= 2
 
-static cairo_surface_t *
+static cairo_surface_t *  
 gdk_x11_cursor_get_surface (GdkCursor *cursor,
 			    gdouble   *x_hot,
 			    gdouble   *y_hot)
@@ -524,7 +524,9 @@ get_surface_size (cairo_surface_t *surface,
 
   x_scale = y_scale = 1;
 
+#ifdef HAVE_CAIRO_SURFACE_SET_DEVICE_SCALE
   cairo_surface_get_device_scale (surface, &x_scale, &y_scale);
+#endif
 
   /* Assume any set scaling is icon scale */
   *width =
@@ -560,7 +562,9 @@ create_cursor_image (cairo_surface_t *source_surface,
                                                  height,
                                                  width * 4);
 
+#ifdef HAVE_CAIRO_SURFACE_SET_DEVICE_SCALE
   cairo_surface_set_device_scale (surface, scale, scale);
+#endif
 
   cr = cairo_create (surface);
   cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
@@ -607,60 +611,6 @@ _gdk_x11_display_get_cursor_for_surface (GdkDisplay *display,
   return GDK_CURSOR (private);
 }
 
-static const struct {
-  const gchar *css_name, *traditional_name;
-} name_map[] = {
-  { "default",      "left_ptr" },
-  { "help",         "left_ptr" },
-  { "context-menu", "left_ptr" },
-  { "pointer",      "hand" },
-  { "progress",     "left_ptr_watch" },
-  { "wait",         "watch" },
-  { "cell",         "crosshair" },
-  { "crosshair",    "cross" },
-  { "text",         "xterm" },
-  { "vertical-text","xterm" },
-  { "alias",        "dnd-link" },
-  { "copy",         "dnd-copy" },
-  { "move",         "dnd-move" },
-  { "no-drop",      "dnd-none" },
-  { "not-allowed",  "crossed_circle" },
-  { "grab",         "hand2" },
-  { "grabbing",     "hand2" },
-  { "all-scroll",   "left_ptr" },
-  { "col-resize",   "h_double_arrow" },
-  { "row-resize",   "v_double_arrow" },
-  { "n-resize",     "top_side" },
-  { "e-resize",     "right_side" },
-  { "s-resize",     "bottom_side" },
-  { "w-resize",     "left_side" },
-  { "ne-resize",    "top_right_corner" },
-  { "nw-resize",    "top_left_corner" },
-  { "se-resize",    "bottom_right_corner" },
-  { "sw-resize",    "bottom_left_corner" },
-  { "ew-resize",    "h_double_arrow" },
-  { "ns-resize",    "v_double_arrow" },
-  { "nesw-resize",  "fd_double_arrow" },
-  { "nwse-resize",  "bd_double_arrow" },
-  { "zoom-in",      "left_ptr" },
-  { "zoom-out",     "left_ptr" },
-  { NULL, NULL }
-};
-
-static const gchar *
-name_fallback (const gchar *name)
-{
-  gint i;
-
-  for (i = 0; name_map[i].css_name; i++)
-    {
-      if (g_str_equal (name_map[i].css_name, name))
-        return name_map[i].traditional_name;
-    }
-
-  return NULL;
-}
-
 GdkCursor*
 _gdk_x11_display_get_cursor_for_name (GdkDisplay  *display,
                                       const gchar *name)
@@ -675,9 +625,6 @@ _gdk_x11_display_get_cursor_for_name (GdkDisplay  *display,
     }
   else
     {
-      if (strcmp (name, "none") == 0)
-        return _gdk_x11_display_get_cursor_for_type (display, GDK_BLANK_CURSOR);
-
       private = find_in_cache (display, GDK_CURSOR_IS_PIXMAP, name);
 
       if (private)
@@ -690,18 +637,6 @@ _gdk_x11_display_get_cursor_for_name (GdkDisplay  *display,
 
       xdisplay = GDK_DISPLAY_XDISPLAY (display);
       xcursor = XcursorLibraryLoadCursor (xdisplay, name);
-      if (xcursor == None)
-        {
-          const char *fallback;
-
-          fallback = name_fallback (name);
-          if (fallback)
-            {
-              xcursor = XcursorLibraryLoadCursor (xdisplay, fallback);
-              if (xcursor == None)
-                xcursor = XcursorLibraryLoadCursor (xdisplay, "left_ptr");
-            }
-        }
       if (xcursor == None)
         return NULL;
     }
