@@ -368,6 +368,7 @@ void
 _gdk_x11_region_get_xrectangles (const cairo_region_t *region,
                                  gint             x_offset,
                                  gint             y_offset,
+                                 gint             scale,
                                  XRectangle     **rects,
                                  gint            *n_rects)
 {
@@ -381,10 +382,10 @@ _gdk_x11_region_get_xrectangles (const cairo_region_t *region,
   for (i = 0; i < n; i++)
     {
       cairo_region_get_rectangle (region, i, &box);
-      rectangles[i].x = CLAMP (box.x + x_offset, G_MINSHORT, G_MAXSHORT);
-      rectangles[i].y = CLAMP (box.y + y_offset, G_MINSHORT, G_MAXSHORT);
-      rectangles[i].width = CLAMP (box.width, G_MINSHORT, G_MAXSHORT);
-      rectangles[i].height = CLAMP (box.height, G_MINSHORT, G_MAXSHORT);
+      rectangles[i].x = CLAMP ((box.x + x_offset) * scale, G_MINSHORT, G_MAXSHORT);
+      rectangles[i].y = CLAMP ((box.y + y_offset) * scale, G_MINSHORT, G_MAXSHORT);
+      rectangles[i].width = CLAMP (box.width * scale, G_MINSHORT, G_MAXSHORT);
+      rectangles[i].height = CLAMP (box.height * scale, G_MINSHORT, G_MAXSHORT);
     }
 
   *n_rects = n;
@@ -438,7 +439,7 @@ gdk_x11_get_default_screen (void)
  * Gets the root window of the default screen 
  * (see gdk_x11_get_default_screen()).  
  * 
- * Return value: an Xlib <type>Window</type>.
+ * Return value: an Xlib Window.
  **/
 Window
 gdk_x11_get_default_root_xwindow (void)
@@ -451,7 +452,7 @@ gdk_x11_get_default_root_xwindow (void)
  * 
  * Gets the default GTK+ display.
  * 
- * Return value: (transfer none): the Xlib <type>Display*</type> for
+ * Return value: (transfer none): the Xlib Display* for
  * the display specified in the <option>--display</option> command
  * line option or the <envar>DISPLAY</envar> environment variable.
  **/
