@@ -47,6 +47,7 @@ static void atk_action_interface_init    (AtkActionIface *iface);
 static void atk_selection_interface_init (AtkSelectionIface *iface);
 
 G_DEFINE_TYPE_WITH_CODE (GtkMenuItemAccessible, gtk_menu_item_accessible, GTK_TYPE_CONTAINER_ACCESSIBLE,
+                         G_ADD_PRIVATE (GtkMenuItemAccessible)
                          G_IMPLEMENT_INTERFACE (ATK_TYPE_ACTION, atk_action_interface_init);
                          G_IMPLEMENT_INTERFACE (ATK_TYPE_SELECTION, atk_selection_interface_init))
 
@@ -59,11 +60,13 @@ gtk_menu_item_accessible_initialize (AtkObject *obj,
   GtkWidget *menu;
 
   ATK_OBJECT_CLASS (gtk_menu_item_accessible_parent_class)->initialize (obj, data);
-
   g_signal_connect (data, "select", G_CALLBACK (menu_item_select), NULL);
   g_signal_connect (data, "deselect", G_CALLBACK (menu_item_deselect), NULL);
 
   widget = GTK_WIDGET (data);
+  if ((gtk_widget_get_state_flags (widget) & GTK_STATE_FLAG_PRELIGHT) != 0)
+    GTK_MENU_ITEM_ACCESSIBLE (obj)->priv->selected = TRUE;
+
   parent = gtk_widget_get_parent (widget);
   if (GTK_IS_MENU (parent))
     {
@@ -258,16 +261,12 @@ gtk_menu_item_accessible_class_init (GtkMenuItemAccessibleClass *klass)
   class->initialize = gtk_menu_item_accessible_initialize;
   class->get_name = gtk_menu_item_accessible_get_name;
   class->get_role = gtk_menu_item_accessible_get_role;
-
-  g_type_class_add_private (klass, sizeof (GtkMenuItemAccessiblePrivate));
 }
 
 static void
 gtk_menu_item_accessible_init (GtkMenuItemAccessible *menu_item)
 {
-  menu_item->priv = G_TYPE_INSTANCE_GET_PRIVATE (menu_item,
-                                                 GTK_TYPE_MENU_ITEM_ACCESSIBLE,
-                                                 GtkMenuItemAccessiblePrivate);
+  menu_item->priv = gtk_menu_item_accessible_get_instance_private (menu_item);
 }
 
 static GtkWidget *
@@ -465,6 +464,33 @@ find_accel_by_closure (GtkAccelKey *key,
   return data == (gpointer) closure;
 }
 
+static GtkWidget *
+find_item_label (GtkWidget *item)
+{
+  GtkWidget *child;
+
+  child = gtk_bin_get_child (GTK_BIN (item));
+  if (GTK_IS_CONTAINER (child))
+    {
+      GList *children, *l;
+      children = gtk_container_get_children (GTK_CONTAINER (child));
+      for (l = children; l; l = l->next)
+        {
+          if (GTK_IS_LABEL (l->data))
+            {
+              child = l->data;
+              break;
+            }
+        }
+      g_list_free (children);
+    }
+
+  if (GTK_IS_LABEL (child))
+    return child;
+
+  return NULL;
+}
+
 /* This function returns a string of the form A;B;C where A is
  * the keybinding for the widget; B is the keybinding to traverse
  * from the menubar and C is the accelerator. The items in the
@@ -497,8 +523,7 @@ gtk_menu_item_accessible_get_keybinding (AtkAction *action,
       guint key_val;
       gchar *key, *temp_keybinding;
 
-      child = gtk_bin_get_child (GTK_BIN (temp_item));
-      if (child == NULL)
+      if (gtk_bin_get_child (GTK_BIN (temp_item)) == NULL)
         return NULL;
 
       parent = gtk_widget_get_parent (temp_item);
@@ -516,6 +541,7 @@ gtk_menu_item_accessible_get_keybinding (AtkAction *action,
               gtk_window_get_mnemonic_modifier (GTK_WINDOW (toplevel));
         }
 
+      child = find_item_label (temp_item);
       if (GTK_IS_LABEL (child))
         {
           key_val = gtk_label_get_mnemonic_keyval (GTK_LABEL (child));
@@ -563,17 +589,27 @@ gtk_menu_item_accessible_get_keybinding (AtkAction *action,
   parent = gtk_widget_get_parent (item);
   if (GTK_IS_MENU (parent))
     {
-      GtkAccelGroup *group;
-      GtkAccelKey *key;
-
-      group = gtk_menu_get_accel_group (GTK_MENU (parent));
-      if (group)
-        key = gtk_accel_group_find (group, find_accel_by_widget, item);
-      else
+      child = find_item_label (item);
+      if (GTK_IS_ACCEL_LABEL (child))
         {
-          key = NULL;
-          child = gtk_bin_get_child (GTK_BIN (item));
-          if (GTK_IS_ACCEL_LABEL (child))
+          guint accel_key;
+          GdkModifierType accel_mods;
+
+          gtk_accel_label_get_accel (GTK_ACCEL_LABEL (child), &accel_key, &accel_mods);
+
+          if (accel_key)
+            accelerator = gtk_accelerator_name (accel_key, accel_mods);
+        }
+        
+      if (!accelerator)
+        {
+          GtkAccelGroup *group;
+          GtkAccelKey *key = NULL;
+
+          group = gtk_menu_get_accel_group (GTK_MENU (parent));
+          if (group)
+            key = gtk_accel_group_find (group, find_accel_by_widget, item);
+          else if (GTK_IS_ACCEL_LABEL (child))
             {
               GtkAccelLabel *accel_label;
               GClosure      *accel_closure;
@@ -588,10 +624,10 @@ gtk_menu_item_accessible_get_keybinding (AtkAction *action,
                   g_closure_unref (accel_closure);
                 }
             }
-        }
 
-     if (key)
-       accelerator = gtk_accelerator_name (key->accel_key, key->accel_mods);
+         if (key)
+           accelerator = gtk_accelerator_name (key->accel_key, key->accel_mods);
+        }
    }
 
   /* Concatenate the bindings */
