@@ -762,7 +762,11 @@ gtk_tree_view_accessible_get_selected_rows (AtkTable  *table,
 
   widget = gtk_accessible_get_widget (GTK_ACCESSIBLE (table));
   if (widget == NULL)
-    return 0;
+    {
+      if (rows_selected != NULL)
+        *rows_selected = NULL;
+      return 0;
+    }
 
   data.treeview = GTK_TREE_VIEW (widget);
   data.array = g_array_new (FALSE, FALSE, sizeof (gint));
@@ -954,7 +958,7 @@ gtk_tree_view_accessible_ref_selection (AtkSelection *selection,
   table = ATK_TABLE (selection);
   n_columns = gtk_tree_view_accessible_get_n_columns (table);
   n_selected = gtk_tree_view_accessible_get_selected_rows (table, &selected);
-  if (i >= n_columns * n_selected)
+  if (n_columns == 0 || i >= n_columns * n_selected)
     return NULL;
 
   row = selected[i / n_columns];
@@ -1016,6 +1020,12 @@ gtk_tree_view_accessible_get_cell_area (GtkCellAccessibleParent *parent,
   GtkTreeViewAccessibleCellInfo *cell_info;
   GtkCellAccessible *top_cell;
 
+  /* Default value. */
+  cell_rect->x = 0;
+  cell_rect->y = 0;
+  cell_rect->width = 0;
+  cell_rect->height = 0;
+
   widget = gtk_accessible_get_widget (GTK_ACCESSIBLE (parent));
   if (widget == NULL)
     return;
@@ -1256,7 +1266,7 @@ gtk_tree_view_accessible_get_renderer_state (GtkCellAccessibleParent *parent,
       GtkTreeViewColumn *column;
       GtkTreePath *path;
       GtkRBTree *tree;
-      GtkRBNode *node;
+      GtkRBNode *node = NULL;
       
       gtk_tree_view_get_cursor (treeview, &path, &column);
       if (path)
@@ -1432,7 +1442,7 @@ cell_info_new (GtkTreeViewAccessible *accessible,
   cell_info->tree = tree;
   cell_info->node = node;
   cell_info->cell_col_ref = tv_col;
-  cell_info->cell = g_object_ref (cell);
+  cell_info->cell = cell;
   cell_info->view = accessible;
 
   g_object_set_qdata (G_OBJECT (cell), 
