@@ -31,7 +31,6 @@
 #include "gtkprivate.h"
 #include "gtkstock.h"
 #include "gtkiconfactory.h"
-#include "deprecated/gtkiconfactoryprivate.h"
 #include "gtkintl.h"
 
 /**
@@ -41,7 +40,7 @@ Prebuilt common menu/toolbar items and corresponding icons
  * @Title: Stock Items
  *
  * Stock items represent commonly-used menu or toolbar items such as
- * “Open” or “Exit”. Each stock item is identified by a stock ID;
+ * "Open" or "Exit". Each stock item is identified by a stock ID;
  * stock IDs are just strings, but macros such as #GTK_STOCK_OPEN are
  * provided to avoid typing mistakes in the strings.
  * Applications can register their own stock items in addition to those
@@ -50,9 +49,11 @@ Prebuilt common menu/toolbar items and corresponding icons
  * Each stock ID can be associated with a #GtkStockItem, which contains
  * the user-visible label, keyboard accelerator, and translation domain
  * of the menu or toolbar item; and/or with an icon stored in a
- * #GtkIconFactory. The connection between a
+ * #GtkIconFactory. See <link
+ * linkend="gtk3-Themeable-Stock-Images">GtkIconFactory</link> for
+ * more information on stock icons. The connection between a
  * #GtkStockItem and stock icons is purely conventional (by virtue of
- * using the same stock ID); it’s possible to register a stock item but
+ * using the same stock ID); it's possible to register a stock item but
  * no icon, and vice versa. Stock icons may have a RTL variant which gets
  * used for right-to-left locales.
  */
@@ -96,7 +97,7 @@ real_add (const GtkStockItem *items,
       gpointer old_key, old_value;
       const GtkStockItem *item = &items[i];
 
-      if (replace_primary && (guint)item->modifier == PRIMARY_MODIFIER)
+      if (replace_primary && item->modifier == PRIMARY_MODIFIER)
         {
           item = gtk_stock_item_copy (item);
           ((GtkStockItem *)item)->modifier = (NON_STATIC_MASK |
@@ -106,7 +107,7 @@ real_add (const GtkStockItem *items,
         {
           if (item->modifier & NON_STATIC_MASK)
             {
-              g_warning ("Bit 29 set in stock accelerator.");
+              g_warning ("Bit 29 set in stock accelerator.\n");
               copy = TRUE;
             }
 
@@ -160,7 +161,7 @@ gtk_stock_add (const GtkStockItem *items,
  * @items: (array length=n_items): a #GtkStockItem or array of #GtkStockItem
  * @n_items: number of items
  *
- * Same as gtk_stock_add(), but doesn’t copy @items, so
+ * Same as gtk_stock_add(), but doesn't copy @items, so
  * @items must persist until application exit.
  *
  * Deprecated: 3.10
@@ -182,7 +183,7 @@ gtk_stock_add_static (const GtkStockItem *items,
  * Fills @item with the registered values for @stock_id, returning %TRUE
  * if @stock_id was known.
  *
- * Returns: %TRUE if @item was initialized
+ * Return value: %TRUE if @item was initialized
  *
  * Deprecated: 3.10
  **/
@@ -230,7 +231,7 @@ gtk_stock_lookup (const gchar  *stock_id,
  * or registered with gtk_stock_add(). The list must be freed with g_slist_free(),
  * and each string in the list must be freed with g_free().
  *
- * Returns: (element-type utf8) (transfer full): a list of known stock IDs
+ * Return value: (element-type utf8) (transfer full): a list of known stock IDs
  *
  * Deprecated: 3.10
  **/
@@ -256,7 +257,7 @@ gtk_stock_list_ids (void)
     {
       GList *next;
 
-      next = ids->next;
+      next = g_list_next (ids);
 
       if (last_id && strcmp (ids->data, last_id) == 0)
         {
@@ -269,7 +270,7 @@ gtk_stock_list_ids (void)
         }
 
       g_list_free_1 (ids);
-
+      
       ids = next;
     }
 
@@ -282,7 +283,7 @@ gtk_stock_list_ids (void)
  * 
  * Copies a stock item, mostly useful for language bindings and not in applications.
  * 
- * Returns: a new #GtkStockItem
+ * Return value: a new #GtkStockItem
  *
  * Deprecated: 3.10
  **/
@@ -497,7 +498,7 @@ static const GtkStockItem builtin_items [] =
  *   return (gchar*)g_dpgettext2 (GETTEXT_PACKAGE, msgctxt, msgid);
  * }
  *
- * ...
+ * /&ast; ... &ast;/
  *
  * gtk_stock_add (items, G_N_ELEMENTS (items));
  * gtk_stock_set_translate_func ("odd-item-domain", my_translate_func, "odd items"); 
