@@ -52,6 +52,16 @@ typedef gchar * (*GtkTranslateFunc) (const gchar  *path,
 
 typedef struct _GtkStockItem GtkStockItem;
 
+/**
+ * GtkStockItem:
+ * @stock_id: Identifier.
+ * @label: User visible label.
+ * @modifier: Modifier type for keyboard accelerator
+ * @keyval: Keyboard accelerator
+ * @translation_domain: Translation domain of the menu or toolbar item
+ *
+ * Deprecated: 3.10
+ */
 struct _GtkStockItem
 {
   gchar *stock_id;
@@ -96,6 +106,8 @@ G_DEPRECATED
 #endif
 typedef char * GtkStock;
 
+#ifndef GTK_DISABLE_DEPRECATED
+
 /* Stock IDs (not all are stock items; some are images only) */
 /**
  * GTK_STOCK_ABOUT:
@@ -1251,6 +1263,8 @@ typedef char * GtkStock;
  */
 #define GTK_STOCK_ZOOM_OUT         ((GtkStock)"gtk-zoom-out")
 
+#endif
+
 G_END_DECLS
 
 #endif /* __GTK_STOCK_H__ */
