@@ -12,9 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -54,7 +52,7 @@ enum {
 
 static void gtk_accessible_real_connect_widget_destroyed (GtkAccessible *accessible);
 
-G_DEFINE_TYPE (GtkAccessible, gtk_accessible, ATK_TYPE_OBJECT)
+G_DEFINE_TYPE_WITH_PRIVATE (GtkAccessible, gtk_accessible, ATK_TYPE_OBJECT)
 
 static void
 gtk_accessible_set_property (GObject      *object,
@@ -98,9 +96,7 @@ gtk_accessible_get_property (GObject    *object,
 static void
 gtk_accessible_init (GtkAccessible *accessible)
 {
-  accessible->priv = G_TYPE_INSTANCE_GET_PRIVATE (accessible,
-                                                  GTK_TYPE_ACCESSIBLE,
-                                                  GtkAccessiblePrivate);
+  accessible->priv = gtk_accessible_get_instance_private (accessible);
 }
 
 static AtkStateSet *
@@ -161,8 +157,6 @@ gtk_accessible_class_init (GtkAccessibleClass *klass)
 							P_("The widget referenced by this accessible."),
 							GTK_TYPE_WIDGET,
 							G_PARAM_READWRITE));
-
-  g_type_class_add_private (klass, sizeof (GtkAccessiblePrivate));
 }
 
 /**
@@ -172,10 +166,11 @@ gtk_accessible_class_init (GtkAccessibleClass *klass)
  *
  * Sets the #GtkWidget corresponding to the #GtkAccessible.
  *
- * <note><para>@accessible will not hold a reference to @widget.
+ * @accessible will not hold a reference to @widget.
  * It is the caller's responsibility to ensure that when @widget
  * is destroyed, the widget is unset by calling this function
- * again with @widget set to %NULL.</para></note>
+ * again with @widget set to %NULL.
+ *
  * Since: 2.22
  */
 void
