@@ -26,7 +26,7 @@
 
 #include <string.h>
 
-/**
+/*< private >
  * SECTION:gtkactionmuxer
  * @short_description: Aggregate and monitor several action groups
  *
@@ -642,7 +642,7 @@ gtk_action_muxer_class_init (GObjectClass *class)
   g_object_class_install_properties (class, NUM_PROPERTIES, properties);
 }
 
-/**
+/*< private >
  * gtk_action_muxer_insert:
  * @muxer: a #GtkActionMuxer
  * @prefix: the prefix string for the action group
@@ -696,7 +696,7 @@ gtk_action_muxer_insert (GtkActionMuxer *muxer,
                                             G_CALLBACK (gtk_action_muxer_group_action_state_changed), group);
 }
 
-/**
+/*< private >
  * gtk_action_muxer_remove:
  * @muxer: a #GtkActionMuxer
  * @prefix: the prefix of the action group to remove
@@ -730,7 +730,7 @@ gtk_action_muxer_remove (GtkActionMuxer *muxer,
     }
 }
 
-/**
+/*< private >
  * gtk_action_muxer_new:
  *
  * Creates a new #GtkActionMuxer.
@@ -741,7 +741,7 @@ gtk_action_muxer_new (void)
   return g_object_new (GTK_TYPE_ACTION_MUXER, NULL);
 }
 
-/**
+/*< private >
  * gtk_action_muxer_get_parent:
  * @muxer: a #GtkActionMuxer
  *
@@ -775,7 +775,7 @@ emit_changed_accels (GtkActionMuxer  *muxer,
     }
 }
 
-/**
+/*< private >
  * gtk_action_muxer_set_parent:
  * @muxer: a #GtkActionMuxer
  * @parent: (allow-none): the new parent #GtkActionMuxer
@@ -887,8 +887,8 @@ gtk_print_action_and_target (const gchar *action_namespace,
 {
   GString *result;
 
-  g_return_if_fail (strchr (action_name, '|') == NULL);
-  g_return_if_fail (action_namespace == NULL || strchr (action_namespace, '|') == NULL);
+  g_return_val_if_fail (strchr (action_name, '|') == NULL, NULL);
+  g_return_val_if_fail (action_namespace == NULL || strchr (action_namespace, '|') == NULL, NULL);
 
   result = g_string_new (NULL);
 
