@@ -40,13 +40,9 @@
  * Of course, if the scale settings are both set to 1, the alignment settings
  * have no effect.
  *
- * <note>
- * <para>
  * Note that the desired effect can in most cases be achieved by using the
  * #GtkWidget:halign, #GtkWidget:valign and #GtkWidget:margin properties
  * on the child widget, so #GtkAlignment should not be used in new code.
- * </para>
- * </note>
  */
 
 #include "config.h"
@@ -509,18 +505,15 @@ gtk_alignment_size_allocate (GtkWidget     *widget,
   GtkWidget *child;
   gint width, height;
   gint border_width;
-  gint padding_horizontal, padding_vertical;
   gint baseline;
 
-  padding_horizontal = 0;
-  padding_vertical = 0;
-
   gtk_widget_set_allocation (widget, allocation);
   bin = GTK_BIN (widget);
 
   child = gtk_bin_get_child (bin);
   if (child && gtk_widget_get_visible (child))
     {
+      gint padding_horizontal, padding_vertical;
       gint child_nat_width;
       gint child_nat_height;
       gint child_width, child_height;
