@@ -53,9 +53,21 @@ struct _GtkAppChooserWidget {
   GtkAppChooserWidgetPrivate *priv;
 };
 
+/**
+ * GtkAppChooserWidgetClass:
+ * @parent_class: The parent class.
+ * @application_selected: Signal emitted when an application item is
+ *    selected from the widget's list.
+ * @application_activated: Signal emitted when an application item is
+ *    activated from the widget's list.
+ * @populate_popup: Signal emitted when a context menu is about to
+ *    popup over an application item.
+ */
 struct _GtkAppChooserWidgetClass {
   GtkBoxClass parent_class;
 
+  /*< public >*/
+
   void (* application_selected)  (GtkAppChooserWidget *self,
                                   GAppInfo            *app_info);
 
@@ -66,36 +78,52 @@ struct _GtkAppChooserWidgetClass {
                                   GtkMenu             *menu,
                                   GAppInfo            *app_info);
 
+  /*< private >*/
+
   /* padding for future class expansion */
   gpointer padding[16];
 };
 
+GDK_AVAILABLE_IN_ALL
 GType         gtk_app_chooser_widget_get_type             (void) G_GNUC_CONST;
 
+GDK_AVAILABLE_IN_ALL
 GtkWidget *   gtk_app_chooser_widget_new                  (const gchar         *content_type);
 
+GDK_AVAILABLE_IN_ALL
 void          gtk_app_chooser_widget_set_show_default     (GtkAppChooserWidget *self,
                                                            gboolean             setting);
+GDK_AVAILABLE_IN_ALL
 gboolean      gtk_app_chooser_widget_get_show_default     (GtkAppChooserWidget *self);
 
+GDK_AVAILABLE_IN_ALL
 void          gtk_app_chooser_widget_set_show_recommended (GtkAppChooserWidget *self,
                                                            gboolean             setting);
+GDK_AVAILABLE_IN_ALL
 gboolean      gtk_app_chooser_widget_get_show_recommended (GtkAppChooserWidget *self);
 
+GDK_AVAILABLE_IN_ALL
 void          gtk_app_chooser_widget_set_show_fallback    (GtkAppChooserWidget *self,
                                                            gboolean             setting);
+GDK_AVAILABLE_IN_ALL
 gboolean      gtk_app_chooser_widget_get_show_fallback    (GtkAppChooserWidget *self);
 
+GDK_AVAILABLE_IN_ALL
 void          gtk_app_chooser_widget_set_show_other       (GtkAppChooserWidget *self,
                                                            gboolean             setting);
+GDK_AVAILABLE_IN_ALL
 gboolean      gtk_app_chooser_widget_get_show_other       (GtkAppChooserWidget *self);
 
+GDK_AVAILABLE_IN_ALL
 void          gtk_app_chooser_widget_set_show_all         (GtkAppChooserWidget *self,
                                                            gboolean             setting);
+GDK_AVAILABLE_IN_ALL
 gboolean      gtk_app_chooser_widget_get_show_all         (GtkAppChooserWidget *self);
 
+GDK_AVAILABLE_IN_ALL
 void          gtk_app_chooser_widget_set_default_text     (GtkAppChooserWidget *self,
                                                            const gchar         *text);
+GDK_AVAILABLE_IN_ALL
 const gchar * gtk_app_chooser_widget_get_default_text     (GtkAppChooserWidget *self);
 
 G_END_DECLS
