@@ -38,12 +38,10 @@
  *
  * The main purpose of GtkButtonBox is to make sure the children have all the
  * same size. GtkButtonBox gives all children the same size, but it does allow
- * 'outliers' to keep their own larger size. To force all children to be
- * strictly the same size without exceptions, you can set the
- * #GtkButtonBox:homogeneous property to %TRUE.
+ * 'outliers' to keep their own larger size.
  *
  * To excempt individual children from homogeneous sizing regardless of their
- * 'outlier' status, you can set the #GtkButtonBox:non-homogeneous child
+ * 'outlier' status, you can set the non-homogeneous child
  * property.
  */
 
@@ -130,7 +128,14 @@ static void gtk_button_box_get_child_property (GtkContainer      *container,
 #define DEFAULT_CHILD_IPAD_Y 0
 #define DEFAULT_LAYOUT_STYLE GTK_BUTTONBOX_EDGE
 
-G_DEFINE_TYPE (GtkButtonBox, gtk_button_box, GTK_TYPE_BOX)
+G_DEFINE_TYPE_WITH_PRIVATE (GtkButtonBox, gtk_button_box, GTK_TYPE_BOX)
+
+static void
+gtk_button_box_add (GtkContainer *container,
+                    GtkWidget    *widget)
+{
+  gtk_box_pack_start (GTK_BOX (container), widget, TRUE, TRUE, 0);
+}
 
 static void
 gtk_button_box_class_init (GtkButtonBoxClass *class)
@@ -154,6 +159,7 @@ gtk_button_box_class_init (GtkButtonBoxClass *class)
   widget_class->size_allocate = gtk_button_box_size_allocate;
 
   container_class->remove = gtk_button_box_remove;
+  container_class->add = gtk_button_box_add;
   container_class->set_child_property = gtk_button_box_set_child_property;
   container_class->get_child_property = gtk_button_box_get_child_property;
   gtk_container_class_handle_border_width (container_class);
@@ -220,22 +226,15 @@ gtk_button_box_class_init (GtkButtonBoxClass *class)
                                                                     P_("If TRUE, the child will not be subject to homogeneous sizing"),
                                                                     FALSE,
                                                                     GTK_PARAM_READWRITE));
-
-  g_type_class_add_private (class, sizeof (GtkButtonBoxPrivate));
 }
 
 static void
 gtk_button_box_init (GtkButtonBox *button_box)
 {
-  GtkButtonBoxPrivate *priv;
-
-  button_box->priv = G_TYPE_INSTANCE_GET_PRIVATE (button_box,
-                                                  GTK_TYPE_BUTTON_BOX,
-                                                  GtkButtonBoxPrivate);
-  priv = button_box->priv;
+  button_box->priv = gtk_button_box_get_instance_private (button_box);
+  button_box->priv->layout_style = DEFAULT_LAYOUT_STYLE;
 
   gtk_box_set_spacing (GTK_BOX (button_box), 0);
-  priv->layout_style = DEFAULT_LAYOUT_STYLE;
 }
 
 static void
@@ -356,6 +355,18 @@ gtk_button_box_set_layout (GtkButtonBox      *widget,
   if (priv->layout_style != layout_style)
     {
       priv->layout_style = layout_style;
+
+      if (priv->layout_style == GTK_BUTTONBOX_EXPAND)
+        {
+          gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET (widget)), "linked");
+          gtk_box_set_homogeneous (GTK_BOX (widget), TRUE);
+        }
+      else
+        {
+          gtk_style_context_remove_class (gtk_widget_get_style_context (GTK_WIDGET (widget)), "linked");
+          gtk_box_set_homogeneous (GTK_BOX (widget), FALSE);
+        }
+
       g_object_notify (G_OBJECT (widget), "layout-style");
       gtk_widget_queue_resize (GTK_WIDGET (widget));
     }
@@ -423,15 +434,24 @@ gtk_button_box_set_child_secondary (GtkButtonBox *widget,
                                     GtkWidget    *child,
                                     gboolean      is_secondary)
 {
+  GtkButtonBox *bbox;
+
   g_return_if_fail (GTK_IS_BUTTON_BOX (widget));
   g_return_if_fail (GTK_IS_WIDGET (child));
   g_return_if_fail (gtk_widget_get_parent (child) == GTK_WIDGET (widget));
 
+  bbox = GTK_BUTTON_BOX (widget);
+
   g_object_set_data (G_OBJECT (child),
                      GTK_BOX_SECONDARY_CHILD,
                      is_secondary ? GINT_TO_POINTER (1) : NULL);
   gtk_widget_child_notify (child, "secondary");
 
+  if (bbox->priv->layout_style == GTK_BUTTONBOX_EXPAND)
+    {
+      gtk_box_reorder_child (GTK_BOX (bbox), child, is_secondary ? 0 : -1);
+    }
+
   if (gtk_widget_get_visible (GTK_WIDGET (widget)) &&
       gtk_widget_get_visible (child))
     gtk_widget_queue_resize (child);
@@ -721,6 +741,7 @@ gtk_button_box_size_request (GtkWidget      *widget,
           case GTK_BUTTONBOX_START:
           case GTK_BUTTONBOX_END:
           case GTK_BUTTONBOX_CENTER:
+          case GTK_BUTTONBOX_EXPAND:
             if (orientation == GTK_ORIENTATION_HORIZONTAL)
               requisition->width = total_size + ((nvis_children - 1)*spacing);
             else
@@ -834,6 +855,13 @@ gtk_button_box_size_allocate (GtkWidget     *widget,
   bbox = GTK_BUTTON_BOX (widget);
   priv = bbox->priv;
 
+  if (priv->layout_style == GTK_BUTTONBOX_EXPAND)
+    {
+      GTK_WIDGET_CLASS (gtk_button_box_parent_class)->size_allocate (widget, allocation);
+      return;
+    }
+
+
   orientation = gtk_orientable_get_orientation (GTK_ORIENTABLE (widget));
   spacing = gtk_box_get_spacing (GTK_BOX (widget));
 
