@@ -55,10 +55,32 @@ typedef void (* GtkCellLayoutDataFunc) (GtkCellLayout   *cell_layout,
                                         GtkTreeIter     *iter,
                                         gpointer         data);
 
+/**
+ * GtkCellLayoutIface:
+ * @pack_start: Packs the cell into the beginning of cell_layout.
+ * @pack_end: Adds the cell to the end of cell_layout.
+ * @clear: Unsets all the mappings on all renderers on cell_layout and
+ *    removes all renderers from cell_layout.
+ * @add_attribute: Adds an attribute mapping to the list in
+ *    cell_layout.
+ * @set_cell_data_func: Sets the #GtkCellLayoutDataFunc to use for
+ *    cell_layout.
+ * @clear_attributes: Clears all existing attributes previously set
+ *    with gtk_cell_layout_set_attributes().
+ * @reorder: Re-inserts cell at position.
+ * @get_cells: Get the cell renderers which have been added to
+ *    cell_layout.
+ * @get_area: Get the underlying #GtkCellArea which might be
+ *    cell_layout if called on a #GtkCellArea or might be NULL if no
+ *    #GtkCellArea is used by cell_layout.
+ */
 struct _GtkCellLayoutIface
 {
+  /*< private >*/
   GTypeInterface g_iface;
 
+  /*< public >*/
+
   /* Virtual Table */
   void (* pack_start)         (GtkCellLayout         *cell_layout,
                                GtkCellRenderer       *cell,
@@ -86,32 +108,43 @@ struct _GtkCellLayoutIface
   GtkCellArea *(* get_area)   (GtkCellLayout         *cell_layout);
 };
 
+GDK_AVAILABLE_IN_ALL
 GType gtk_cell_layout_get_type           (void) G_GNUC_CONST;
+GDK_AVAILABLE_IN_ALL
 void  gtk_cell_layout_pack_start         (GtkCellLayout         *cell_layout,
                                           GtkCellRenderer       *cell,
                                           gboolean               expand);
+GDK_AVAILABLE_IN_ALL
 void  gtk_cell_layout_pack_end           (GtkCellLayout         *cell_layout,
                                           GtkCellRenderer       *cell,
                                           gboolean               expand);
+GDK_AVAILABLE_IN_ALL
 GList *gtk_cell_layout_get_cells         (GtkCellLayout         *cell_layout);
+GDK_AVAILABLE_IN_ALL
 void  gtk_cell_layout_clear              (GtkCellLayout         *cell_layout);
+GDK_AVAILABLE_IN_ALL
 void  gtk_cell_layout_set_attributes     (GtkCellLayout         *cell_layout,
                                           GtkCellRenderer       *cell,
                                           ...) G_GNUC_NULL_TERMINATED;
+GDK_AVAILABLE_IN_ALL
 void  gtk_cell_layout_add_attribute      (GtkCellLayout         *cell_layout,
                                           GtkCellRenderer       *cell,
                                           const gchar           *attribute,
                                           gint                   column);
+GDK_AVAILABLE_IN_ALL
 void  gtk_cell_layout_set_cell_data_func (GtkCellLayout         *cell_layout,
                                           GtkCellRenderer       *cell,
                                           GtkCellLayoutDataFunc  func,
                                           gpointer               func_data,
                                           GDestroyNotify         destroy);
+GDK_AVAILABLE_IN_ALL
 void  gtk_cell_layout_clear_attributes   (GtkCellLayout         *cell_layout,
                                           GtkCellRenderer       *cell);
+GDK_AVAILABLE_IN_ALL
 void  gtk_cell_layout_reorder            (GtkCellLayout         *cell_layout,
                                           GtkCellRenderer       *cell,
                                           gint                   position);
+GDK_AVAILABLE_IN_ALL
 GtkCellArea *gtk_cell_layout_get_area    (GtkCellLayout         *cell_layout);
 
 gboolean _gtk_cell_layout_buildable_custom_tag_start (GtkBuildable  *buildable,
