@@ -52,9 +52,8 @@
  * You should not call gtk_combo_box_set_model() or attempt to pack more cells
  * into this combo box via its GtkCellLayout interface.
  *
- * <refsect2 id="GtkComboBoxText-BUILDER-UI">
- * <title>GtkComboBoxText as GtkBuildable</title>
- * <para>
+ * ## GtkComboBoxText as GtkBuildable
+ *
  * The GtkComboBoxText implementation of the GtkBuildable interface
  * supports adding items directly using the &lt;items&gt; element
  * and specifying &lt;item&gt; elements for each item. Each &lt;item&gt;
@@ -62,9 +61,8 @@
  * also supports the regular translation attributes "translatable",
  * "context" and "comments".
  *
- * <example>
- * <title>A UI definition fragment specifying GtkComboBoxText items</title>
- * <programlisting><![CDATA[
+ * Here is a a UI definition fragment specifying GtkComboBoxText items:
+ * |[
  * <object class="GtkComboBoxText">
  *   <items>
  *     <item translatable="yes" id="factory">Factory</item>
@@ -72,10 +70,7 @@
  *     <item translatable="yes" id="subway">Subway</item>
  *   </items>
  * </object>
- * ]]></programlisting>
- * </example>
- * </para>
- * </refsect2>
+ * ]|
  */
 
 static void     gtk_combo_box_text_buildable_interface_init     (GtkBuildableIface *iface);
@@ -240,8 +235,7 @@ item_end_element (GMarkupParseContext *context,
 	  translated = _gtk_builder_parser_translate (data->domain,
 						      data->context,
 						      data->string->str);
-	  g_string_set_size (data->string, 0);
-	  g_string_append (data->string, translated);
+	  g_string_assign (data->string, translated);
 	}
 
       gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (data->object), data->id, data->string->str);
