@@ -29,6 +29,7 @@
 
 #include "gtkbutton.h"
 #include "gtkdialog.h"
+#include "gtkheaderbar.h"
 #include "gtkbbox.h"
 #include "gtklabel.h"
 #include "gtkmarshalers.h"
@@ -56,14 +57,14 @@
  * GTK+ treats a dialog as a window split vertically. The top section is a
  * #GtkVBox, and is where widgets such as a #GtkLabel or a #GtkEntry should
  * be packed. The bottom area is known as the
- * <structfield>action_area</structfield>. This is generally used for
+ * <quote>action_area</quote>. This is generally used for
  * packing buttons into the dialog which may perform functions such as
  * cancel, ok, or apply.
  *
  * #GtkDialog boxes are created with a call to gtk_dialog_new() or
  * gtk_dialog_new_with_buttons(). gtk_dialog_new_with_buttons() is
- * recommended; it allows you to set the dialog title, some convenient flags,
- * and add simple buttons.
+ * recommended; it allows you to set the dialog title, some convenient
+ * flags, and add simple buttons.
  *
  * If 'dialog' is a newly created dialog, the two primary areas of the
  * window can be accessed through gtk_dialog_get_content_area() and
@@ -95,9 +96,9 @@
  * use #GtkMessageDialog to save yourself some effort. But you'd need to
  * create the dialog contents manually if you had more than a simple message
  * in the dialog.
- * <example>
- * <title>Simple GtkDialog usage</title>
- * <programlisting>
+ *
+ * An example for simple GtkDialog usage:
+ * |[<!-- language="C" -->
  * /&ast; Function to open a dialog box displaying the message provided. &ast;/
  * void
  * quick_message (gchar *message)
@@ -125,26 +126,23 @@
  *    gtk_container_add (GTK_CONTAINER (content_area), label);
  *    gtk_widget_show_all (dialog);
  * }
- * </programlisting>
- * </example>
+ * ]|
+ *
+ * ## GtkDialog as GtkBuildable
  *
- * <refsect2 id="GtkDialog-BUILDER-UI"><title>GtkDialog as GtkBuildable</title>
- * <para>
  * The GtkDialog implementation of the #GtkBuildable interface exposes the
  * @vbox and @action_area as internal children with the names "vbox" and
  * "action_area".
- * </para>
- * <para>
+ *
  * GtkDialog supports a custom &lt;action-widgets&gt; element, which
  * can contain multiple &lt;action-widget&gt; elements. The "response"
  * attribute specifies a numeric response, and the content of the element
  * is the id of widget (which should be a child of the dialogs @action_area).
- * </para>
- * <example>
- * <title>A <structname>GtkDialog</structname> UI definition fragment.</title>
- * <programlisting><![CDATA[
+ *
+ * An example of a #GtkDialog UI definition fragment:
+ * |[
  * <object class="GtkDialog" id="dialog1">
- *   <child internal-child="vbox">"
+ *   <child internal-child="vbox">
  *     <object class="GtkVBox" id="vbox">
  *       <child internal-child="action_area">
  *         <object class="GtkHButtonBox" id="button_box">
@@ -163,15 +161,17 @@
  *     <action-widget response="cancel">button_cancel</action-widget>
  *   </action-widgets>
  * </object>
- * ]]></programlisting>
- * </example>
- * </refsect2>
+ * ]|
  */
 
 struct _GtkDialogPrivate
 {
   GtkWidget *vbox;
+  GtkWidget *headerbar;
   GtkWidget *action_area;
+
+  gint use_header_bar;
+  gboolean constructed;
 };
 
 typedef struct _ResponseData ResponseData;
@@ -212,7 +212,7 @@ static void      gtk_dialog_buildable_custom_finished    (GtkBuildable  *buildab
 
 enum {
   PROP_0,
-  PROP_HAS_SEPARATOR
+  PROP_USE_HEADER_BAR
 };
 
 enum {
@@ -228,14 +228,249 @@ G_DEFINE_TYPE_WITH_CODE (GtkDialog, gtk_dialog, GTK_TYPE_WINDOW,
 			 G_IMPLEMENT_INTERFACE (GTK_TYPE_BUILDABLE,
 						gtk_dialog_buildable_interface_init))
 
+static void
+set_use_header_bar (GtkDialog *dialog,
+                    gint       use_header_bar)
+{
+  GtkDialogPrivate *priv = dialog->priv;
+
+  if (use_header_bar == -1)
+    return;
+
+  priv->use_header_bar = use_header_bar;
+}
+
+/* A convenience helper for built-in dialogs */
+void
+gtk_dialog_set_use_header_bar_from_setting (GtkDialog *dialog)
+{
+  GtkDialogPrivate *priv = dialog->priv;
+
+  g_assert (!priv->constructed);
+
+  g_object_get (gtk_widget_get_settings (GTK_WIDGET (dialog)),
+                "gtk-dialogs-use-header", &priv->use_header_bar,
+                NULL);
+}
+
+static void
+add_cb (GtkContainer *container,
+        GtkWidget    *widget,
+        GtkDialog    *dialog)
+{
+  GtkDialogPrivate *priv = dialog->priv;
+
+  if (priv->use_header_bar)
+    g_warning ("Content added to the action area of a dialog using header bars");
+
+  gtk_widget_show (GTK_WIDGET (container));
+}
+
+static void
+apply_use_header_bar (GtkDialog *dialog)
+{
+  GtkDialogPrivate *priv = dialog->priv;
+
+  gtk_widget_set_visible (priv->action_area, !priv->use_header_bar);
+  gtk_widget_set_visible (priv->headerbar, priv->use_header_bar);
+  if (!priv->use_header_bar)
+    gtk_window_set_titlebar (GTK_WINDOW (dialog), NULL);
+  if (priv->use_header_bar)
+    g_signal_connect (priv->action_area, "add", G_CALLBACK (add_cb), dialog);
+}
+
+static void
+gtk_dialog_set_property (GObject      *object,
+                         guint         prop_id,
+                         const GValue *value,
+                         GParamSpec   *pspec)
+{
+  GtkDialog *dialog = GTK_DIALOG (object);
+
+  switch (prop_id)
+    {
+    case PROP_USE_HEADER_BAR:
+      set_use_header_bar (dialog, g_value_get_int (value));
+      break;
+
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+      break;
+    }
+}
+
+static void
+gtk_dialog_get_property (GObject      *object,
+                         guint         prop_id,
+                         GValue       *value,
+                         GParamSpec   *pspec)
+{
+  GtkDialog *dialog = GTK_DIALOG (object);
+  GtkDialogPrivate *priv = dialog->priv;
+
+  switch (prop_id)
+    {
+    case PROP_USE_HEADER_BAR:
+      g_value_set_int (value, priv->use_header_bar);
+      break;
+
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+      break;
+    }
+}
+
+static void
+action_widget_activated (GtkWidget *widget, GtkDialog *dialog)
+{
+  gint response_id;
+
+  response_id = gtk_dialog_get_response_for_widget (dialog, widget);
+
+  gtk_dialog_response (dialog, response_id);
+}
+
+typedef struct {
+  GtkWidget *child;
+  gint       response_id;
+} ActionWidgetData;
+
+static void
+add_response_data (GtkDialog *dialog,
+                   GtkWidget *child,
+                   gint       response_id)
+{
+  ResponseData *ad;
+  guint signal_id;
+
+  ad = get_response_data (child, TRUE);
+  ad->response_id = response_id;
+
+  if (GTK_IS_BUTTON (child))
+    signal_id = g_signal_lookup ("clicked", GTK_TYPE_BUTTON);
+  else
+    signal_id = GTK_WIDGET_GET_CLASS (child)->activate_signal;
+
+  if (signal_id)
+    {
+      GClosure *closure;
+
+      closure = g_cclosure_new_object (G_CALLBACK (action_widget_activated),
+                                       G_OBJECT (dialog));
+      g_signal_connect_closure_by_id (child, signal_id, 0, closure, FALSE);
+    }
+  else
+    g_warning ("Only 'activatable' widgets can be packed into the action area of a GtkDialog");
+}
+
+static void
+add_to_header_bar (GtkDialog *dialog,
+                   GtkWidget *child,
+                   gint       response_id)
+{
+  GtkDialogPrivate *priv = dialog->priv;
+
+  gtk_widget_set_valign (child, GTK_ALIGN_CENTER);
+
+  if (response_id == GTK_RESPONSE_CANCEL || response_id == GTK_RESPONSE_HELP)
+    gtk_header_bar_pack_start (GTK_HEADER_BAR (priv->headerbar), child);
+  else 
+    gtk_header_bar_pack_end (GTK_HEADER_BAR (priv->headerbar), child);
+
+  if (response_id == GTK_RESPONSE_CANCEL || response_id == GTK_RESPONSE_CLOSE)
+    gtk_header_bar_set_show_close_button (GTK_HEADER_BAR (priv->headerbar), FALSE);
+}
+
+static void
+add_to_action_area (GtkDialog *dialog,
+                    GtkWidget *child,
+                    gint       response_id)
+{
+  GtkDialogPrivate *priv = dialog->priv;
+
+  gtk_widget_set_valign (child, GTK_ALIGN_BASELINE);
+
+  gtk_container_add (GTK_CONTAINER (priv->action_area), child);
+
+  if (response_id == GTK_RESPONSE_HELP)
+    gtk_button_box_set_child_secondary (GTK_BUTTON_BOX (priv->action_area), child, TRUE);
+}
+
+static void
+add_action_widgets (GtkDialog *dialog)
+{
+  GtkDialogPrivate *priv = dialog->priv;
+  GList *children;
+  GList *l;
+
+  if (priv->use_header_bar)
+    {
+      children = gtk_container_get_children (GTK_CONTAINER (priv->action_area));
+      for (l = children; l != NULL; l = l->next)
+        {
+          GtkWidget *child = l->data;
+          gboolean has_default;
+          ResponseData *rd;
+          gint response_id;
+
+          has_default = gtk_widget_has_default (child);
+          rd = get_response_data (child, FALSE);
+          response_id = rd ? rd->response_id : GTK_RESPONSE_NONE;
+
+          g_object_ref (child);
+          gtk_container_remove (GTK_CONTAINER (priv->action_area), child);
+          add_to_header_bar (dialog, child, response_id);
+          g_object_unref (child);
+
+          if (has_default)
+            {
+              gtk_widget_grab_default (child);
+              gtk_style_context_add_class (gtk_widget_get_style_context (child), "suggested-action");
+            }
+        }
+      g_list_free (children);
+    }
+}
+static GObject *
+gtk_dialog_constructor (GType                  type,
+                        guint                  n_construct_properties,
+                        GObjectConstructParam *construct_params)
+{
+  GObject *object;
+  GtkDialog *dialog;
+  GtkDialogPrivate *priv;
+
+  object = G_OBJECT_CLASS (gtk_dialog_parent_class)->constructor (type,
+                                                                  n_construct_properties,
+                                                                  construct_params);
+
+  dialog = GTK_DIALOG (object);
+  priv = dialog->priv;
+
+  priv->constructed = TRUE;
+  if (priv->use_header_bar == -1)
+    priv->use_header_bar = FALSE;
+
+  add_action_widgets (dialog);
+  apply_use_header_bar (dialog);
+
+  return object;
+}
+
 static void
 gtk_dialog_class_init (GtkDialogClass *class)
 {
+  GObjectClass *gobject_class;
   GtkWidgetClass *widget_class;
   GtkBindingSet *binding_set;
 
+  gobject_class = G_OBJECT_CLASS (class);
   widget_class = GTK_WIDGET_CLASS (class);
 
+  gobject_class->constructor  = gtk_dialog_constructor;
+  gobject_class->set_property = gtk_dialog_set_property;
+  gobject_class->get_property = gtk_dialog_get_property;
+
   widget_class->map = gtk_dialog_map;
   widget_class->style_updated = gtk_dialog_style_updated;
 
@@ -326,13 +561,33 @@ gtk_dialog_class_init (GtkDialogClass *class)
                                                              5,
                                                              GTK_PARAM_READABLE));
 
+  /**
+   * GtkDialog:use-header-bar:
+   *
+   * %TRUE if the dialog uses a #GtkHeaderBar for action buttons
+   * instead of the action-area.
+   *
+   * For technical reasons, this property is declared as an integer
+   * property, but you should only set it to %TRUE or %FALSE.
+   *
+   * Since: 3.12
+   */
+  g_object_class_install_property (gobject_class,
+                                   PROP_USE_HEADER_BAR,
+                                   g_param_spec_int ("use-header-bar",
+                                                     P_("Use Header Bar"),
+                                                     P_("Use Header Bar for actions."),
+                                                     -1, 1, -1,
+                                                     GTK_PARAM_READWRITE|G_PARAM_CONSTRUCT_ONLY));
+
   binding_set = gtk_binding_set_by_class (class);
   gtk_binding_entry_add_signal (binding_set, GDK_KEY_Escape, 0, "close", 0);
 
   /* Bind class to template
    */
-  gtk_widget_class_set_template_from_resource (widget_class, "/org/gtk/libgtk/gtkdialog.ui");
+  gtk_widget_class_set_template_from_resource (widget_class, "/org/gtk/libgtk/ui/gtkdialog.ui");
   gtk_widget_class_bind_template_child_internal_private (widget_class, GtkDialog, vbox);
+  gtk_widget_class_bind_template_child_internal_private (widget_class, GtkDialog, headerbar);
   gtk_widget_class_bind_template_child_internal_private (widget_class, GtkDialog, action_area);
   gtk_widget_class_bind_template_callback (widget_class, gtk_dialog_delete_event_handler);
 }
@@ -360,6 +615,7 @@ update_spacings (GtkDialog *dialog)
       gtk_box_set_spacing (GTK_BOX (priv->vbox), content_area_spacing);
       _gtk_box_set_spacing_set (GTK_BOX (priv->vbox), FALSE);
     }
+
   gtk_box_set_spacing (GTK_BOX (priv->action_area),
                        button_spacing);
   gtk_container_set_border_width (GTK_CONTAINER (priv->action_area),
@@ -371,6 +627,8 @@ gtk_dialog_init (GtkDialog *dialog)
 {
   dialog->priv = gtk_dialog_get_instance_private (dialog);
 
+  dialog->priv->use_header_bar = -1;
+
   gtk_widget_init_template (GTK_WIDGET (dialog));
 
   update_spacings (dialog);
@@ -398,6 +656,20 @@ gtk_dialog_delete_event_handler (GtkWidget   *widget,
   return FALSE;
 }
 
+static GList *
+get_action_children (GtkDialog *dialog)
+{
+  GtkDialogPrivate *priv = dialog->priv;
+  GList *children;
+
+  if (priv->constructed && priv->use_header_bar)
+    children = gtk_container_get_children (GTK_CONTAINER (priv->headerbar));
+  else
+    children = gtk_container_get_children (GTK_CONTAINER (priv->action_area));
+
+  return children;
+}
+
 /* A far too tricky heuristic for getting the right initial
  * focus widget if none was set. What we do is we focus the first
  * widget in the tab chain, but if this results in the focus
@@ -413,7 +685,6 @@ gtk_dialog_map (GtkWidget *widget)
   GtkWidget *default_widget, *focus;
   GtkWindow *window = GTK_WINDOW (widget);
   GtkDialog *dialog = GTK_DIALOG (widget);
-  GtkDialogPrivate *priv = dialog->priv;
 
   GTK_WIDGET_CLASS (gtk_dialog_parent_class)->map (widget);
 
@@ -442,7 +713,7 @@ gtk_dialog_map (GtkWidget *widget)
         }
       while (TRUE);
 
-      tmp_list = children = gtk_container_get_children (GTK_CONTAINER (priv->action_area));
+      tmp_list = children = get_action_children (dialog);
 
       while (tmp_list)
 	{
@@ -474,23 +745,22 @@ gtk_dialog_style_updated (GtkWidget *widget)
 
 static GtkWidget *
 dialog_find_button (GtkDialog *dialog,
-		    gint       response_id)
+                   gint       response_id)
 {
-  GtkDialogPrivate *priv = dialog->priv;
   GtkWidget *child = NULL;
   GList *children, *tmp_list;
 
-  children = gtk_container_get_children (GTK_CONTAINER (priv->action_area));
+  children = get_action_children (dialog);
 
   for (tmp_list = children; tmp_list; tmp_list = tmp_list->next)
     {
       ResponseData *rd = get_response_data (tmp_list->data, FALSE);
 
       if (rd && rd->response_id == response_id)
-	{
-	  child = tmp_list->data;
-	  break;
-	}
+       {
+         child = tmp_list->data;
+         break;
+       }
     }
 
   g_list_free (children);
@@ -501,18 +771,7 @@ dialog_find_button (GtkDialog *dialog,
 static void
 gtk_dialog_close (GtkDialog *dialog)
 {
-  /* Synthesize delete_event to close dialog. */
-
-  GtkWidget *widget = GTK_WIDGET (dialog);
-  GdkEvent *event;
-
-  event = gdk_event_new (GDK_DELETE);
-
-  event->any.window = g_object_ref (gtk_widget_get_window (widget));
-  event->any.send_event = TRUE;
-
-  gtk_main_do_event (event);
-  gdk_event_free (event);
+  gtk_window_close (GTK_WINDOW (dialog));
 }
 
 /**
@@ -538,7 +797,9 @@ gtk_dialog_new_empty (const gchar     *title,
 {
   GtkDialog *dialog;
 
-  dialog = g_object_new (GTK_TYPE_DIALOG, NULL);
+  dialog = g_object_new (GTK_TYPE_DIALOG,
+                         "use-header-bar", (flags & GTK_DIALOG_USE_HEADER_BAR) != 0,
+                         NULL);
 
   if (title)
     gtk_window_set_title (GTK_WINDOW (dialog), title);
@@ -582,7 +843,7 @@ gtk_dialog_new_empty (const gchar     *title,
  * so the first button in the list will be the leftmost button in the dialog.
  *
  * Here's a simple example:
- * |[
+ * |[<!-- language="C" -->
  *  GtkWidget *dialog = gtk_dialog_new_with_buttons ("My dialog",
  *                                                   main_app_window,
  *                                                   GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -624,7 +885,7 @@ response_data_free (gpointer data)
   g_slice_free (ResponseData, data);
 }
 
-static ResponseData*
+static ResponseData *
 get_response_data (GtkWidget *widget,
 		   gboolean   create)
 {
@@ -644,16 +905,6 @@ get_response_data (GtkWidget *widget,
   return ad;
 }
 
-static void
-action_widget_activated (GtkWidget *widget, GtkDialog *dialog)
-{
-  gint response_id;
-
-  response_id = gtk_dialog_get_response_for_widget (dialog, widget);
-
-  gtk_dialog_response (dialog, response_id);
-}
-
 /**
  * gtk_dialog_add_action_widget:
  * @dialog: a #GtkDialog
@@ -672,45 +923,17 @@ gtk_dialog_add_action_widget (GtkDialog *dialog,
                               GtkWidget *child,
                               gint       response_id)
 {
-  GtkDialogPrivate *priv;
-  ResponseData *ad;
-  guint signal_id;
+  GtkDialogPrivate *priv = dialog->priv;
 
   g_return_if_fail (GTK_IS_DIALOG (dialog));
   g_return_if_fail (GTK_IS_WIDGET (child));
 
-  priv = dialog->priv;
+  add_response_data (dialog, child, response_id);
 
-  ad = get_response_data (child, TRUE);
-
-  ad->response_id = response_id;
-
-  if (GTK_IS_BUTTON (child))
-    signal_id = g_signal_lookup ("clicked", GTK_TYPE_BUTTON);
+  if (priv->constructed && priv->use_header_bar)
+    add_to_header_bar (dialog, child, response_id);
   else
-    signal_id = GTK_WIDGET_GET_CLASS (child)->activate_signal;
-
-  if (signal_id)
-    {
-      GClosure *closure;
-
-      closure = g_cclosure_new_object (G_CALLBACK (action_widget_activated),
-				       G_OBJECT (dialog));
-      g_signal_connect_closure_by_id (child,
-				      signal_id,
-				      0,
-				      closure,
-				      FALSE);
-    }
-  else
-    g_warning ("Only 'activatable' widgets can be packed into the action area of a GtkDialog");
-
-  gtk_box_pack_end (GTK_BOX (priv->action_area),
-                    child,
-                    FALSE, TRUE, 0);
-
-  if (response_id == GTK_RESPONSE_HELP)
-    gtk_button_box_set_child_secondary (GTK_BUTTON_BOX (priv->action_area), child, TRUE);
+    add_to_action_area (dialog, child, response_id);
 }
 
 /**
@@ -751,14 +974,12 @@ gtk_dialog_add_button (GtkDialog   *dialog,
 
   G_GNUC_END_IGNORE_DEPRECATIONS;
 
+  gtk_style_context_add_class (gtk_widget_get_style_context (button), "text-button");
   gtk_widget_set_can_default (button, TRUE);
-  gtk_widget_set_valign (button, GTK_ALIGN_BASELINE);
 
   gtk_widget_show (button);
 
-  gtk_dialog_add_action_widget (dialog,
-                                button,
-                                response_id);
+  gtk_dialog_add_action_widget (dialog, button, response_id);
 
   return button;
 }
@@ -832,15 +1053,12 @@ gtk_dialog_set_response_sensitive (GtkDialog *dialog,
                                    gint       response_id,
                                    gboolean   setting)
 {
-  GtkDialogPrivate *priv;
   GList *children;
   GList *tmp_list;
 
   g_return_if_fail (GTK_IS_DIALOG (dialog));
 
-  priv = dialog->priv;
-
-  children = gtk_container_get_children (GTK_CONTAINER (priv->action_area));
+  children = get_action_children (dialog);
 
   tmp_list = children;
   while (tmp_list != NULL)
@@ -870,15 +1088,12 @@ void
 gtk_dialog_set_default_response (GtkDialog *dialog,
                                  gint       response_id)
 {
-  GtkDialogPrivate *priv;
   GList *children;
   GList *tmp_list;
 
   g_return_if_fail (GTK_IS_DIALOG (dialog));
 
-  priv = dialog->priv;
-
-  children = gtk_container_get_children (GTK_CONTAINER (priv->action_area));
+  children = get_action_children (dialog);
 
   tmp_list = children;
   while (tmp_list != NULL)
@@ -887,7 +1102,11 @@ gtk_dialog_set_default_response (GtkDialog *dialog,
       ResponseData *rd = get_response_data (widget, FALSE);
 
       if (rd && rd->response_id == response_id)
-	gtk_widget_grab_default (widget);
+        {
+	  gtk_widget_grab_default (widget);
+          if (dialog->priv->constructed && dialog->priv->use_header_bar == 1)
+            gtk_style_context_add_class (gtk_widget_get_style_context (widget), "suggested-action");
+        }
 
       tmp_list = g_list_next (tmp_list);
     }
@@ -1003,7 +1222,7 @@ run_destroy_handler (GtkDialog *dialog, gpointer data)
  * destroying the dialog if you wish to do so.
  *
  * Typical usage of this function might be:
- * |[
+ * |[<!-- language="C" -->
  *   gint result = gtk_dialog_run (GTK_DIALOG (dialog));
  *   switch (result)
  *     {
@@ -1020,7 +1239,7 @@ run_destroy_handler (GtkDialog *dialog, gpointer data)
  * Note that even though the recursive main loop gives the effect of a
  * modal dialog (it prevents the user from interacting with other
  * windows in the same window group while the dialog is run), callbacks
- * such as timeouts, IO channel watches, DND drops, etc, <emphasis>will</emphasis>
+ * such as timeouts, IO channel watches, DND drops, etc, will
  * be triggered during a gtk_dialog_run() call.
  *
  * Return value: response ID
@@ -1113,15 +1332,12 @@ GtkWidget*
 gtk_dialog_get_widget_for_response (GtkDialog *dialog,
 				    gint       response_id)
 {
-  GtkDialogPrivate *priv;
   GList *children;
   GList *tmp_list;
 
   g_return_val_if_fail (GTK_IS_DIALOG (dialog), NULL);
 
-  priv = dialog->priv;
-
-  children = gtk_container_get_children (GTK_CONTAINER (priv->action_area));
+  children = get_action_children (dialog);
 
   tmp_list = children;
   while (tmp_list != NULL)
@@ -1169,6 +1385,15 @@ gtk_dialog_get_response_for_widget (GtkDialog *dialog,
     return rd->response_id;
 }
 
+static gboolean
+gtk_alt_dialog_button_order (void)
+{
+  gboolean result;
+  g_object_get (gtk_settings_get_default (),
+		"gtk-alternative-button-order", &result, NULL);
+  return result;
+}
+
 /**
  * gtk_alternative_dialog_button_order:
  * @screen: (allow-none): a #GdkScreen, or %NULL to use the default screen
@@ -1186,28 +1411,18 @@ gtk_dialog_get_response_for_widget (GtkDialog *dialog,
  * Returns: Whether the alternative button order should be used
  *
  * Since: 2.6
+ * Deprecated: 3.10: Deprecated
  */
 gboolean
 gtk_alternative_dialog_button_order (GdkScreen *screen)
 {
-  GtkSettings *settings;
-  gboolean result;
-
-  if (screen)
-    settings = gtk_settings_get_for_screen (screen);
-  else
-    settings = gtk_settings_get_default ();
-
-  g_object_get (settings,
-		"gtk-alternative-button-order", &result, NULL);
-
-  return result;
+  return gtk_alt_dialog_button_order ();
 }
 
 static void
 gtk_dialog_set_alternative_button_order_valist (GtkDialog *dialog,
-						gint       first_response_id,
-						va_list    args)
+                                                gint       first_response_id,
+                                                va_list    args)
 {
   GtkDialogPrivate *priv = dialog->priv;
   GtkWidget *child;
@@ -1251,7 +1466,7 @@ gtk_dialog_set_alternative_button_order_valist (GtkDialog *dialog,
  *
  * Use this function after adding all the buttons to your dialog, as the
  * following example shows:
- * |[
+ * |[<!-- language="C" -->
  * cancel_button = gtk_dialog_add_button (GTK_DIALOG (dialog),
  *                                        _("_Cancel"),
  *                                        GTK_RESPONSE_CANCEL);
@@ -1274,26 +1489,29 @@ gtk_dialog_set_alternative_button_order_valist (GtkDialog *dialog,
  * ]|
  *
  * Since: 2.6
+ * Deprecated: 3.10: Deprecated
  */
 void
 gtk_dialog_set_alternative_button_order (GtkDialog *dialog,
 					 gint       first_response_id,
 					 ...)
 {
-  GdkScreen *screen;
+  GtkDialogPrivate *priv = dialog->priv;
   va_list args;
 
   g_return_if_fail (GTK_IS_DIALOG (dialog));
 
-  screen = gtk_widget_get_screen (GTK_WIDGET (dialog));
-  if (!gtk_alternative_dialog_button_order (screen))
-      return;
+  if (priv->constructed && priv->use_header_bar)
+    return;
+
+  if (!gtk_alt_dialog_button_order ())
+    return;
 
   va_start (args, first_response_id);
 
   gtk_dialog_set_alternative_button_order_valist (dialog,
-						  first_response_id,
-						  args);
+                                                 first_response_id,
+                                                 args);
   va_end (args);
 }
 /**
@@ -1313,6 +1531,7 @@ gtk_dialog_set_alternative_button_order (GtkDialog *dialog,
  * This function is for use by language bindings.
  *
  * Since: 2.6
+ * Deprecated: 3.10: Deprecated
  */
 void
 gtk_dialog_set_alternative_button_order_from_array (GtkDialog *dialog,
@@ -1320,16 +1539,17 @@ gtk_dialog_set_alternative_button_order_from_array (GtkDialog *dialog,
                                                     gint      *new_order)
 {
   GtkDialogPrivate *priv = dialog->priv;
-  GdkScreen *screen;
   GtkWidget *child;
   gint position;
 
   g_return_if_fail (GTK_IS_DIALOG (dialog));
   g_return_if_fail (new_order != NULL);
 
-  screen = gtk_widget_get_screen (GTK_WIDGET (dialog));
-  if (!gtk_alternative_dialog_button_order (screen))
-      return;
+  if (dialog->priv->use_header_bar)
+    return;
+
+  if (!gtk_alt_dialog_button_order ())
+    return;
 
   for (position = 0; position < n_params; position++)
   {
@@ -1519,8 +1739,8 @@ gtk_dialog_buildable_custom_finished (GtkBuildable *buildable,
 	}
 
       if (ad->response_id == GTK_RESPONSE_HELP)
-	gtk_button_box_set_child_secondary (GTK_BUTTON_BOX (priv->action_area),
-					    GTK_WIDGET (object), TRUE);
+       gtk_button_box_set_child_secondary (GTK_BUTTON_BOX (priv->action_area),
+                                           GTK_WIDGET (object), TRUE);
 
       g_free (item->widget_name);
       g_free (item);
@@ -1535,10 +1755,13 @@ gtk_dialog_buildable_custom_finished (GtkBuildable *buildable,
  *
  * Returns the action area of @dialog.
  *
- * Returns: (transfer none): the action area.
+ * Returns: (transfer none): the action area
  *
  * Since: 2.14
- **/
+ *
+ * Deprecated:3.12: Direct access to the action area
+ *   is discouraged; use gtk_dialog_add_button(), etc.
+ */
 GtkWidget *
 gtk_dialog_get_action_area (GtkDialog *dialog)
 {
@@ -1547,6 +1770,26 @@ gtk_dialog_get_action_area (GtkDialog *dialog)
   return dialog->priv->action_area;
 }
 
+/**
+ * gtk_dialog_get_header_bar:
+ * @dialog: a #GtkDialog
+ *
+ * Returns the header bar of @dialog. Note that the
+ * headerbar is only used by the dialog if the
+ * #GtkDialog:use-header-bar property is %TRUE.
+ *
+ * Returns: (transfer none): the header bar
+ *
+ * Since: 3.12
+ */
+GtkWidget *
+gtk_dialog_get_header_bar (GtkDialog *dialog)
+{
+  g_return_val_if_fail (GTK_IS_DIALOG (dialog), NULL);
+
+  return dialog->priv->headerbar;
+}
+
 /**
  * gtk_dialog_get_content_area:
  * @dialog: a #GtkDialog
