@@ -72,7 +72,7 @@
  *
  * <example>
  * <title>Create a button to let the user select a file in /etc</title>
- * <programlisting>
+ * |[<!-- language="C" -->
  * {
  *   GtkWidget *button;
  *
@@ -81,7 +81,7 @@
  *   gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (button),
  *                                        "/etc");
  * }
- * </programlisting>
+ * ]|
  * </example>
  *
  * The #GtkFileChooserButton supports the #GtkFileChooserAction<!-- -->s
@@ -392,7 +392,7 @@ gtk_file_chooser_button_class_init (GtkFileChooserButtonClass * class)
    *
    * The ::file-set signal is emitted when the user selects a file.
    *
-   * Note that this signal is only emitted when the <emphasis>user</emphasis>
+   * Note that this signal is only emitted when the user
    * changes the file.
    *
    * Since: 2.12
@@ -470,7 +470,7 @@ gtk_file_chooser_button_class_init (GtkFileChooserButtonClass * class)
   /* Bind class to template
    */
   gtk_widget_class_set_template_from_resource (widget_class,
-					       "/org/gtk/libgtk/gtkfilechooserbutton.ui");
+					       "/org/gtk/libgtk/ui/gtkfilechooserbutton.ui");
 
   gtk_widget_class_bind_template_child_private (widget_class, GtkFileChooserButton, model);
   gtk_widget_class_bind_template_child_private (widget_class, GtkFileChooserButton, button);
@@ -662,7 +662,7 @@ get_selected_file (GtkFileChooserButton *button)
   else if (gtk_file_chooser_get_action (GTK_FILE_CHOOSER (priv->dialog)) == GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER)
     {
       /* If there is no "real" selection in SELECT_FOLDER mode, then we'll just return
-       * the current folder, since that is what GtkFileChooserDefault would do.
+       * the current folder, since that is what GtkFileChooserWidget would do.
        */
       if (priv->current_folder_while_inactive)
 	retval = priv->current_folder_while_inactive;
@@ -810,10 +810,12 @@ gtk_file_chooser_button_constructor (GType                  type,
 
       gtk_dialog_set_default_response (GTK_DIALOG (priv->dialog),
 				       GTK_RESPONSE_ACCEPT);
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
       gtk_dialog_set_alternative_button_order (GTK_DIALOG (priv->dialog),
 					       GTK_RESPONSE_ACCEPT,
 					       GTK_RESPONSE_CANCEL,
 					       -1);
+G_GNUC_END_IGNORE_DEPRECATIONS
 
       gtk_file_chooser_button_set_title (button, _(DEFAULT_TITLE));
     }
@@ -2328,6 +2330,8 @@ name_cell_data_func (GtkCellLayout   *layout,
 
   if (type == ROW_TYPE_CURRENT_FOLDER)
     g_object_set (cell, "ellipsize", PANGO_ELLIPSIZE_END, NULL);
+  else if (type == ROW_TYPE_BOOKMARK || type == ROW_TYPE_SHORTCUT)
+    g_object_set (cell, "ellipsize", PANGO_ELLIPSIZE_MIDDLE, NULL);
   else
     g_object_set (cell, "ellipsize", PANGO_ELLIPSIZE_NONE, NULL);
 }
