@@ -29,6 +29,8 @@
 #include "gtksizerequest.h"
 #include "gtktypebuiltins.h"
 #include "gtkintl.h"
+#include "gtksettings.h"
+#include "gtkdialogprivate.h"
 
 #include <stdarg.h>
 
@@ -55,7 +57,7 @@
  * In the simplest of cases, you can the following code to use
  * #GtkFileChooserDialog to select a file for opening:
  * <para>
- * <informalexample><programlisting>
+ * |[
  * GtkWidget *dialog;
  *
  * dialog = gtk_file_chooser_dialog_new ("Open File",
@@ -75,11 +77,11 @@
  *   }
  *
  * gtk_widget_destroy (dialog);
- * </programlisting></informalexample>
+ * ]|
  * </para>
  * To use a dialog for saving, you can use this:
  * <para>
- * <informalexample><programlisting>
+ * |[
  * GtkWidget *dialog;
  *
  * dialog = gtk_file_chooser_dialog_new ("Save File",
@@ -105,32 +107,27 @@
  *   }
  *
  * gtk_widget_destroy (dialog);
- * </programlisting></informalexample>
+ * ]|
  * </para>
  * </example>
- * <section id="gtkfilechooserdialog-setting-up">
- * <title>Setting up a file chooser dialog</title>
+ *
+ * ## Setting up a file chooser dialog
+ *
+ * <para id="gtkfilechooserdialog-setting-up">
  * There are various cases in which you may need to use a #GtkFileChooserDialog:
- * <itemizedlist><listitem>To select a file for opening, as for a
- *   <guimenuitem>File/Open</guimenuitem> command.  Use
- *   #GTK_FILE_CHOOSER_ACTION_OPEN.
- * </listitem>
- * <listitem>To save a file for the first time, as for a
- *   <guimenuitem>File/Save</guimenuitem> command.  Use
- *   #GTK_FILE_CHOOSER_ACTION_SAVE, and suggest a name such as
- *   "Untitled" with gtk_file_chooser_set_current_name().
- * </listitem>
- * <listitem>To save a file under a different name, as for a
- *   <guimenuitem>File/Save As</guimenuitem> command.  Use
- *   #GTK_FILE_CHOOSER_ACTION_SAVE, and set the existing filename
- *   with gtk_file_chooser_set_filename().
- * </listitem>
- * <listitem>To choose a folder instead of a file.  Use
- *   #GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER.
- * </listitem></itemizedlist>
- * <note>
- * <para>
- * Old versions of the file chooser's documentation suggested
+ * </para>
+ *
+ * - To select a file for opening. Use #GTK_FILE_CHOOSER_ACTION_OPEN.
+ *
+ * - To save a file for the first time. Use #GTK_FILE_CHOOSER_ACTION_SAVE,
+ *   and suggest a name such as "Untitled" with gtk_file_chooser_set_current_name().
+ * 
+ * - To save a file under a different name. Use #GTK_FILE_CHOOSER_ACTION_SAVE,
+ *   and set the existing filename with gtk_file_chooser_set_filename().
+ *
+ * - To choose a folder instead of a file. Use #GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER.
+ *
+ * Note that old versions of the file chooser's documentation suggested
  * using gtk_file_chooser_set_current_folder() in various
  * situations, with the intention of letting the application
  * suggest a reasonable default folder.  This is no longer
@@ -138,20 +135,17 @@
  * able to make good suggestions on its own.  In general, you
  * should only cause the file chooser to show a specific folder
  * when it is appropriate to use gtk_file_chooser_set_filename(),
- * i.e. when you are doing a <guimenuitem>File/Save
- * As</guimenuitem> command <emphasis>and</emphasis> you already
+ * i.e. when you are doing a Save As command and you already
  * have a file saved somewhere.
- * </para>
- * </note>
- * </section>
- * <section id="gtkfilechooserdialog-response-codes">
- * <title>Response Codes</title>
+
+ * ## Response Codes
+ *
+ * <para id="gtkfilechooserdialog-response-codes">
  * #GtkFileChooserDialog inherits from #GtkDialog, so buttons that
  * go in its action area have response codes such as
  * #GTK_RESPONSE_ACCEPT and #GTK_RESPONSE_CANCEL.  For example, you
  * could call gtk_file_chooser_dialog_new() as follows:
- * <para>
- * <informalexample><programlisting>
+ * |[
  * GtkWidget *dialog;
  *
  * dialog = gtk_file_chooser_dialog_new ("Open File",
@@ -160,36 +154,31 @@
  *                                       _("_Cancel"), GTK_RESPONSE_CANCEL,
  *                                       _("_Open"), GTK_RESPONSE_ACCEPT,
  *                                       NULL);
- * </programlisting></informalexample>
+ * ]|
  * </para>
+ *
+ * <para id="gtkfilechooserdialog-responses">
  * This will create buttons for "Cancel" and "Open" that use stock
  * response identifiers from #GtkResponseType.  For most dialog
  * boxes you can use your own custom response codes rather than the
  * ones in #GtkResponseType, but #GtkFileChooserDialog assumes that
  * its "accept"-type action, e.g. an "Open" or "Save" button,
- * <emphasis>will</emphasis> have one of the following response
- * codes:
- * <para>
- * <simplelist id="gtkfilechooserdialog-responses">
- * <member>#GTK_RESPONSE_ACCEPT</member>
- * <member>#GTK_RESPONSE_OK</member>
- * <member>#GTK_RESPONSE_YES</member>
- * <member>#GTK_RESPONSE_APPLY</member>
- * </simplelist>
+ * will have one of the following response codes:
  * </para>
+ * - #GTK_RESPONSE_ACCEPT
+ * - #GTK_RESPONSE_OK
+ * - #GTK_RESPONSE_YES
+ * - #GTK_RESPONSE_APPLY
+ *
  * This is because #GtkFileChooserDialog must intercept responses
  * and switch to folders if appropriate, rather than letting the
  * dialog terminate &mdash; the implementation uses these known
  * response codes to know which responses can be blocked if
  * appropriate.
- * <para>
- * <note>
+ *
  * To summarize, make sure you use a
  * <link linkend="gtkfilechooserdialog-responses">stock response code</link>
  * when you use #GtkFileChooserDialog to ensure proper operation.
- * </note>
- * </para>
- * </section>
  */
 
 
@@ -246,13 +235,13 @@ gtk_file_chooser_dialog_class_init (GtkFileChooserDialogClass *class)
   /* Bind class to template
    */
   gtk_widget_class_set_template_from_resource (widget_class,
-					       "/org/gtk/libgtk/gtkfilechooserdialog.ui");
+					       "/org/gtk/libgtk/ui/gtkfilechooserdialog.ui");
 
-  gtk_widget_class_bind_child (widget_class, GtkFileChooserDialogPrivate, widget);
-  gtk_widget_class_bind_callback (widget_class, response_cb);
-  gtk_widget_class_bind_callback (widget_class, file_chooser_widget_file_activated);
-  gtk_widget_class_bind_callback (widget_class, file_chooser_widget_default_size_changed);
-  gtk_widget_class_bind_callback (widget_class, file_chooser_widget_response_requested);
+  gtk_widget_class_bind_template_child_private (widget_class, GtkFileChooserDialog, widget);
+  gtk_widget_class_bind_template_callback (widget_class, response_cb);
+  gtk_widget_class_bind_template_callback (widget_class, file_chooser_widget_file_activated);
+  gtk_widget_class_bind_template_callback (widget_class, file_chooser_widget_default_size_changed);
+  gtk_widget_class_bind_template_callback (widget_class, file_chooser_widget_response_requested);
 }
 
 static void
@@ -262,11 +251,34 @@ gtk_file_chooser_dialog_init (GtkFileChooserDialog *dialog)
   dialog->priv->response_requested = FALSE;
 
   gtk_widget_init_template (GTK_WIDGET (dialog));
+  gtk_dialog_set_use_header_bar_from_setting (GTK_DIALOG (dialog));
 
   _gtk_file_chooser_set_delegate (GTK_FILE_CHOOSER (dialog),
 				  GTK_FILE_CHOOSER (dialog->priv->widget));
 }
 
+static GtkWidget *
+get_accept_action_widget (GtkDialog *dialog)
+{
+  gint response[] = {
+    GTK_RESPONSE_ACCEPT,
+    GTK_RESPONSE_OK,
+    GTK_RESPONSE_YES,
+    GTK_RESPONSE_APPLY
+  };
+  gint i;
+  GtkWidget *widget;
+
+  for (i = 0; i < G_N_ELEMENTS (response); i++)
+    {
+      widget = gtk_dialog_get_widget_for_response (dialog, response[i]);
+      if (widget && gtk_widget_is_sensitive (widget))
+	return widget;
+    }
+
+  return NULL;
+}
+
 static gboolean
 is_stock_accept_response_id (int response_id)
 {
@@ -281,9 +293,7 @@ static void
 file_chooser_widget_file_activated (GtkFileChooser       *chooser,
 				    GtkFileChooserDialog *dialog)
 {
-  GtkDialog *fc_dialog = GTK_DIALOG (dialog);
-  GtkWidget *action_area;
-  GList *children, *l;
+  GtkWidget *widget;
 
   if (gtk_window_activate_default (GTK_WINDOW (dialog)))
     return;
@@ -291,25 +301,9 @@ file_chooser_widget_file_activated (GtkFileChooser       *chooser,
   /* There probably isn't a default widget, so make things easier for the
    * programmer by looking for a reasonable button on our own.
    */
-  action_area = gtk_dialog_get_action_area (fc_dialog);
-  children = gtk_container_get_children (GTK_CONTAINER (action_area));
-
-  for (l = children; l; l = l->next)
-    {
-      GtkWidget *widget;
-      int response_id;
-
-      widget = GTK_WIDGET (l->data);
-      response_id = gtk_dialog_get_response_for_widget (fc_dialog, widget);
-      if (gtk_widget_is_sensitive (widget) &&
-          is_stock_accept_response_id (response_id))
-	{
-	  gtk_widget_activate (widget); /* Should we gtk_dialog_response (dialog, response_id) instead? */
-	  break;
-	}
-    }
-
-  g_list_free (children);
+  widget = get_accept_action_widget (GTK_DIALOG (dialog));
+  if (widget)
+    gtk_widget_activate (widget); /* Should we gtk_dialog_response (dialog, response_id) instead? */
 }
 
 #if 0
@@ -381,9 +375,7 @@ static void
 file_chooser_widget_response_requested (GtkWidget            *widget,
 					GtkFileChooserDialog *dialog)
 {
-  GtkDialog *fc_dialog = GTK_DIALOG (dialog);
-  GtkWidget *action_area;
-  GList *children, *l;
+  GtkWidget *button;
 
   dialog->priv->response_requested = TRUE;
 
@@ -393,28 +385,14 @@ file_chooser_widget_response_requested (GtkWidget            *widget,
   /* There probably isn't a default widget, so make things easier for the
    * programmer by looking for a reasonable button on our own.
    */
-  action_area = gtk_dialog_get_action_area (fc_dialog);
-  children = gtk_container_get_children (GTK_CONTAINER (action_area));
-
-  for (l = children; l; l = l->next)
+  button = get_accept_action_widget (GTK_DIALOG (dialog));
+  if (button)
     {
-      GtkWidget *widget;
-      int response_id;
-
-      widget = GTK_WIDGET (l->data);
-      response_id = gtk_dialog_get_response_for_widget (fc_dialog, widget);
-      if (gtk_widget_is_sensitive (widget) &&
-          is_stock_accept_response_id (response_id))
-	{
-	  gtk_widget_activate (widget); /* Should we gtk_dialog_response (dialog, response_id) instead? */
-	  break;
-	}
+      gtk_widget_activate (button);
+      return;
     }
 
-  if (l == NULL)
-    dialog->priv->response_requested = FALSE;
-
-  g_list_free (children);
+  dialog->priv->response_requested = FALSE;
 }
 
 static void
@@ -449,27 +427,14 @@ gtk_file_chooser_dialog_get_property (GObject         *object,
   g_object_get_property (G_OBJECT (priv->widget), pspec->name, value);
 }
 
-static void
-foreach_ensure_default_response_cb (GtkWidget *widget,
-				    gpointer   data)
-{
-  GtkFileChooserDialog *dialog = GTK_FILE_CHOOSER_DIALOG (data);
-  int response_id;
-
-  response_id = gtk_dialog_get_response_for_widget (GTK_DIALOG (dialog), widget);
-  if (is_stock_accept_response_id (response_id))
-    gtk_dialog_set_default_response (GTK_DIALOG (dialog), response_id);
-}
-
 static void
 ensure_default_response (GtkFileChooserDialog *dialog)
 {
-  GtkWidget *action_area;
+  GtkWidget *widget;
 
-  action_area = gtk_dialog_get_action_area (GTK_DIALOG (dialog));
-  gtk_container_foreach (GTK_CONTAINER (action_area),
-			 foreach_ensure_default_response_cb,
-			 dialog);
+  widget = get_accept_action_widget (GTK_DIALOG (dialog));
+  if (widget)
+    gtk_widget_grab_default (widget); 
 }
 
 /* GtkWidget::map handler */
