@@ -528,7 +528,7 @@ gtk_font_button_class_init (GtkFontButtonClass *klass)
    * When handling this signal, use gtk_font_button_get_font_name() 
    * to find out which font was just selected.
    *
-   * Note that this signal is only emitted when the <emphasis>user</emphasis>
+   * Note that this signal is only emitted when the user
    * changes the font. If you need to react to programmatic font changes
    * as well, use the notify::font-name signal.
    *
@@ -544,10 +544,10 @@ gtk_font_button_class_init (GtkFontButtonClass *klass)
 
   /* Bind class to template
    */
-  gtk_widget_class_set_template_from_resource (widget_class, "/org/gtk/libgtk/gtkfontbutton.ui");
-  gtk_widget_class_bind_child (widget_class, GtkFontButtonPrivate, font_label);
-  gtk_widget_class_bind_child (widget_class, GtkFontButtonPrivate, size_label);
-  gtk_widget_class_bind_child (widget_class, GtkFontButtonPrivate, font_size_box);
+  gtk_widget_class_set_template_from_resource (widget_class, "/org/gtk/libgtk/ui/gtkfontbutton.ui");
+  gtk_widget_class_bind_template_child_private (widget_class, GtkFontButton, font_label);
+  gtk_widget_class_bind_template_child_private (widget_class, GtkFontButton, size_label);
+  gtk_widget_class_bind_template_child_private (widget_class, GtkFontButton, font_size_box);
 }
 
 static void
