@@ -28,12 +28,14 @@
 #include "gtkfontchooserwidget.h"
 #include "gtkfontchooserutils.h"
 #include "gtkbox.h"
-#include "gtkstock.h"
+#include "deprecated/gtkstock.h"
 #include "gtkintl.h"
 #include "gtkaccessible.h"
 #include "gtkbuildable.h"
 #include "gtkprivate.h"
 #include "gtkwidget.h"
+#include "gtksettings.h"
+#include "gtkdialogprivate.h"
 
 struct _GtkFontChooserDialogPrivate
 {
@@ -52,12 +54,11 @@ struct _GtkFontChooserDialogPrivate
  * The #GtkFontChooserDialog widget is a dialog for selecting a font.
  * It implements the #GtkFontChooser interface.
  *
- * <refsect2 id="GtkFontChooserDialog-BUILDER-UI">
- * <title>GtkFontChooserDialog as GtkBuildable</title>
- * The GtkFontChooserDialog implementation of the GtkBuildable interface
- * exposes the buttons with the names
- * "select_button" and "cancel_button.
- * </refsect2>
+ * ## GtkFontChooserDialog as GtkBuildable
+ *
+ * The GtkFontChooserDialog implementation of the #GtkBuildable
+ * interface exposes the buttons with the names "select_button"
+ * and "cancel_button".
  *
  * Since: 3.2
  */
@@ -134,12 +135,10 @@ gtk_font_chooser_dialog_class_init (GtkFontChooserDialogClass *klass)
   /* Bind class to template
    */
   gtk_widget_class_set_template_from_resource (widget_class,
-					       "/org/gtk/libgtk/gtkfontchooserdialog.ui");
+					       "/org/gtk/libgtk/ui/gtkfontchooserdialog.ui");
 
-  gtk_widget_class_bind_child (widget_class, GtkFontChooserDialogPrivate, fontchooser);
-  gtk_widget_class_bind_child (widget_class, GtkFontChooserDialogPrivate, select_button);
-  gtk_widget_class_bind_child (widget_class, GtkFontChooserDialogPrivate, cancel_button);
-  gtk_widget_class_bind_callback (widget_class, font_activated_cb);
+  gtk_widget_class_bind_template_child_private (widget_class, GtkFontChooserDialog, fontchooser);
+  gtk_widget_class_bind_template_callback (widget_class, font_activated_cb);
 }
 
 static void
@@ -151,11 +150,21 @@ gtk_font_chooser_dialog_init (GtkFontChooserDialog *fontchooserdiag)
   priv = fontchooserdiag->priv;
 
   gtk_widget_init_template (GTK_WIDGET (fontchooserdiag));
-
+  gtk_dialog_set_use_header_bar_from_setting (GTK_DIALOG (fontchooserdiag));
+  gtk_dialog_add_buttons (GTK_DIALOG (fontchooserdiag),
+                          _("_Cancel"), GTK_RESPONSE_CANCEL,
+                          _("_Select"), GTK_RESPONSE_OK,
+                          NULL);
+  gtk_dialog_set_default_response (GTK_DIALOG (fontchooserdiag), GTK_RESPONSE_OK);
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   gtk_dialog_set_alternative_button_order (GTK_DIALOG (fontchooserdiag),
                                            GTK_RESPONSE_OK,
                                            GTK_RESPONSE_CANCEL,
                                            -1);
+G_GNUC_END_IGNORE_DEPRECATIONS
+
+  priv->select_button = gtk_dialog_get_widget_for_response (GTK_DIALOG (fontchooserdiag), GTK_RESPONSE_OK);
+  priv->cancel_button = gtk_dialog_get_widget_for_response (GTK_DIALOG (fontchooserdiag), GTK_RESPONSE_CANCEL);
 
   _gtk_font_chooser_set_delegate (GTK_FONT_CHOOSER (fontchooserdiag),
                                   GTK_FONT_CHOOSER (priv->fontchooser));
