@@ -55,12 +55,21 @@ struct _GtkFrame
   GtkFramePrivate *priv;
 };
 
+/**
+ * GtkFrameClass:
+ * @parent_class: The parent class.
+ * @compute_child_allocation:
+ */
 struct _GtkFrameClass
 {
   GtkBinClass parent_class;
 
+  /*< public >*/
+
   void (*compute_child_allocation) (GtkFrame *frame, GtkAllocation *allocation);
 
+  /*< private >*/
+
   /* Padding for future expansion */
   void (*_gtk_reserved1) (void);
   void (*_gtk_reserved2) (void);
@@ -69,24 +78,34 @@ struct _GtkFrameClass
 };
 
 
+GDK_AVAILABLE_IN_ALL
 GType      gtk_frame_get_type         (void) G_GNUC_CONST;
+GDK_AVAILABLE_IN_ALL
 GtkWidget* gtk_frame_new              (const gchar   *label);
 
+GDK_AVAILABLE_IN_ALL
 void          gtk_frame_set_label (GtkFrame    *frame,
                                    const gchar *label);
+GDK_AVAILABLE_IN_ALL
 const gchar * gtk_frame_get_label (GtkFrame    *frame);
 
+GDK_AVAILABLE_IN_ALL
 void       gtk_frame_set_label_widget (GtkFrame      *frame,
 				       GtkWidget     *label_widget);
+GDK_AVAILABLE_IN_ALL
 GtkWidget *gtk_frame_get_label_widget (GtkFrame      *frame);
+GDK_AVAILABLE_IN_ALL
 void       gtk_frame_set_label_align  (GtkFrame      *frame,
 				       gfloat         xalign,
 				       gfloat         yalign);
+GDK_AVAILABLE_IN_ALL
 void       gtk_frame_get_label_align  (GtkFrame      *frame,
 				       gfloat        *xalign,
 				       gfloat        *yalign);
+GDK_AVAILABLE_IN_ALL
 void       gtk_frame_set_shadow_type  (GtkFrame      *frame,
 				       GtkShadowType  type);
+GDK_AVAILABLE_IN_ALL
 GtkShadowType gtk_frame_get_shadow_type (GtkFrame    *frame);
 
 
