@@ -35,10 +35,10 @@
  * SECTION:gtkheaderbar
  * @Short_description: A box with a centered child
  * @Title: GtkHeaderBar
- * @See_also: #GtkBox
+ * @See_also: #GtkBox, #GtkActionBar
  *
- * GtkHeaderBar is similar to a horizontal #GtkBox, it allows to place
- * children at the start or the end. In addition, it allows a title and
+ * GtkHeaderBar is similar to a horizontal #GtkBox. It allows children to 
+ * be placed at the start or the end. In addition, it allows a title and
  * subtitle to be displayed. The title will be centered with respect to
  * the width of the box, even if the children at either side take up
  * different amounts of space. The height of the titlebar will be
@@ -51,6 +51,7 @@
  */
 
 #define DEFAULT_SPACING 6
+#define MIN_TITLE_CHARS 20
 
 struct _GtkHeaderBarPrivate
 {
@@ -155,6 +156,7 @@ init_sizing_box (GtkHeaderBar *bar)
   gtk_label_set_line_wrap (GTK_LABEL (w), FALSE);
   gtk_label_set_single_line_mode (GTK_LABEL (w), TRUE);
   gtk_label_set_ellipsize (GTK_LABEL (w), PANGO_ELLIPSIZE_END);
+  gtk_label_set_width_chars (GTK_LABEL (w), MIN_TITLE_CHARS);
 
   w = gtk_label_new (NULL);
   context = gtk_widget_get_style_context (w);
@@ -191,6 +193,7 @@ create_title_box (const char *title,
   gtk_label_set_ellipsize (GTK_LABEL (title_label), PANGO_ELLIPSIZE_END);
   gtk_box_pack_start (GTK_BOX (label_box), title_label, FALSE, FALSE, 0);
   gtk_widget_show (title_label);
+  gtk_label_set_width_chars (GTK_LABEL (title_label), MIN_TITLE_CHARS);
 
   subtitle_label = gtk_label_new (subtitle);
   context = gtk_widget_get_style_context (subtitle_label);
@@ -215,54 +218,20 @@ _gtk_header_bar_update_window_icon (GtkHeaderBar *bar,
                                     GtkWindow    *window)
 {
   GtkHeaderBarPrivate *priv = gtk_header_bar_get_instance_private (bar);
-  gint size;
-  GList *list;
-  const gchar *name;
-  GdkPixbuf *best = NULL;
+  GdkPixbuf *pixbuf;
 
   if (priv->titlebar_icon == NULL)
     return FALSE;
 
   if (GTK_IS_BUTTON (gtk_widget_get_parent (priv->titlebar_icon)))
-    size = 16;
+    pixbuf = gtk_window_get_icon_for_size (window, 16);
   else
-    size = 20;
+    pixbuf = gtk_window_get_icon_for_size (window, 20);
 
-  list = gtk_window_get_icon_list (window);
-
-  if (list != NULL)
+  if (pixbuf)
     {
-      GdkPixbuf *pixbuf;
-      GList *l;
-
-      best = NULL;
-      for (l = list; l; l = l->next)
-        {
-          pixbuf = list->data;
-          if (gdk_pixbuf_get_width (pixbuf) <= size)
-            {
-              best = g_object_ref (pixbuf);
-              break;
-            }
-        }
-
-      if (best == NULL)
-        best = gdk_pixbuf_scale_simple (GDK_PIXBUF (list->data), size, size, GDK_INTERP_BILINEAR);
-
-      g_list_free (list);
-    }
-  else
-    {
-      name = gtk_window_get_icon_name (window);
-      if (name != NULL)
-        best = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
-                                         name, size, GTK_ICON_LOOKUP_FORCE_SIZE, NULL);
-    }
-
-  if (best)
-    {
-      gtk_image_set_from_pixbuf (GTK_IMAGE (priv->titlebar_icon), best);
-      g_object_unref (best);
+      gtk_image_set_from_pixbuf (GTK_IMAGE (priv->titlebar_icon), pixbuf);
+      g_object_unref (pixbuf);
       gtk_widget_show (priv->titlebar_icon);
 
       return TRUE;
@@ -727,8 +696,7 @@ gtk_header_bar_compute_size_for_orientation (GtkWidget *widget,
         }
     }
 
-  if (priv->label_box != NULL &&
-      gtk_widget_get_visible (priv->label_box))
+  if (priv->label_box != NULL)
     {
       gtk_widget_get_preferred_width (priv->label_sizing_box,
                                       &child_size, &child_natural);
@@ -862,8 +830,7 @@ gtk_header_bar_compute_size_for_opposing_orientation (GtkWidget *widget,
       i += 1;
     }
 
-  if (priv->label_box != NULL &&
-      gtk_widget_get_visible (priv->label_box))
+  if (priv->label_box != NULL)
     {
       gtk_widget_get_preferred_height (priv->label_sizing_box,
                                        &child_minimum, &child_natural);
@@ -990,14 +957,19 @@ gtk_header_bar_size_allocate (GtkWidget     *widget,
       i++;
     }
 
-  if (priv->custom_title)
+  title_minimum_size = 0;
+  title_natural_size = 0;
+
+  if (priv->custom_title &&
+      gtk_widget_get_visible (priv->custom_title))
     {
       gtk_widget_get_preferred_width_for_height (priv->custom_title,
                                                  height,
                                                  &title_minimum_size,
                                                  &title_natural_size);
     }
-  else
+
+  if (priv->label_box != NULL)
     {
       gtk_widget_get_preferred_width_for_height (priv->label_box,
                                                  height,
@@ -1105,9 +1077,11 @@ gtk_header_bar_size_allocate (GtkWidget     *widget,
   if (direction == GTK_TEXT_DIR_RTL)
     child_allocation.x = allocation->x + allocation->width - (child_allocation.x - allocation->x) - child_allocation.width;
 
-  if (priv->custom_title)
+  if (priv->custom_title != NULL &&
+      gtk_widget_get_visible (priv->custom_title))
     gtk_widget_size_allocate (priv->custom_title, &child_allocation);
-  else
+
+  if (priv->label_box != NULL)
     gtk_widget_size_allocate (priv->label_box, &child_allocation);
 
   if (priv->titlebar_start_box)
@@ -1173,7 +1147,7 @@ gtk_header_bar_set_title (GtkHeaderBar *bar,
  * Retrieves the title of the header. See gtk_header_bar_set_title().
  *
  * Return value: the title of the header, or %NULL if none has
- *    been set explicitely. The returned string is owned by the widget
+ *    been set explicitly. The returned string is owned by the widget
  *    and must not be modified or freed.
  *
  * Since: 3.10
@@ -1234,7 +1208,7 @@ gtk_header_bar_set_subtitle (GtkHeaderBar *bar,
  * Retrieves the subtitle of the header. See gtk_header_bar_set_subtitle().
  *
  * Return value: the subtitle of the header, or %NULL if none has
- *    been set explicitely. The returned string is owned by the widget
+ *    been set explicitly. The returned string is owned by the widget
  *    and must not be modified or freed.
  *
  * Since: 3.10
@@ -1295,7 +1269,6 @@ gtk_header_bar_set_custom_title (GtkHeaderBar *bar,
 
       gtk_widget_set_parent (priv->custom_title, GTK_WIDGET (bar));
       gtk_widget_set_valign (priv->custom_title, GTK_ALIGN_CENTER);
-      gtk_widget_show (title_widget);
 
       if (priv->label_box != NULL)
         {
@@ -1327,7 +1300,7 @@ gtk_header_bar_set_custom_title (GtkHeaderBar *bar,
  * gtk_header_bar_set_custom_title().
  *
  * Return value: (transfer none): the custom title widget
- *    of the header, or %NULL if none has been set explicitely.
+ *    of the header, or %NULL if none has been set explicitly.
  *
  * Since: 3.10
  */
@@ -2036,7 +2009,7 @@ gtk_header_bar_set_has_subtitle (GtkHeaderBar *bar,
  * gtk_header_bar_get_has_subtitle:
  * @bar: a #GtkHeaderBar
  *
- * Returns whether the header bar reserves space
+ * Returns: %TRUE if the header bar reserves space
  * for a subtitle.
  *
  * Since: 3.12
