@@ -19,6 +19,7 @@
 #include <string.h>
 #include "gtkimcontext.h"
 #include "gtkprivate.h"
+#include "gtktypebuiltins.h"
 #include "gtkmarshalers.h"
 #include "gtkintl.h"
 
@@ -32,8 +33,6 @@
  * is used by GTK+ text input widgets like #GtkEntry to map from key events to
  * Unicode character strings.
  *
- * The user may change the current input method via a context menu, unless the   
- * #GtkSettings:gtk-show-input-method-menu GtkSettings property is set to FALSE. 
  * The default input method can be set programmatically via the 
  * #GtkSettings:gtk-im-module GtkSettings property. Alternatively, you may set 
  * the GTK_IM_MODULE environment variable as documented in #gtk-running.
@@ -59,34 +58,34 @@
  * implements a subclass of #GtkIMContext or #GtkIMContextSimple and exports
  * these four functions:
  *
- * <informalexample><programlisting>
+ * |[<!-- language="C" -->
  * void im_module_init(#GTypeModule *module);
- * </programlisting></informalexample>
+ * ]|
  * This function should register the #GType of the #GtkIMContext subclass which
  * implements the input method by means of g_type_module_register_type(). Note
  * that g_type_register_static() cannot be used as the type needs to be
  * registered dynamically.
  *
- * <informalexample><programlisting>
+ * |[<!-- language="C" -->
  * void im_module_exit(void);
- * </programlisting></informalexample>
+ * ]|
  * Here goes any cleanup code your input method might require on module unload.
  *
- * <informalexample><programlisting>
+ * |[<!-- language="C" -->
  * void im_module_list(const #GtkIMContextInfo ***contexts, int *n_contexts)
  * {
  *   *contexts = info_list;
  *   *n_contexts = G_N_ELEMENTS (info_list);
  * }
- * </programlisting></informalexample>
+ * ]|
  * This function returns the list of input methods provided by the module. The
  * example implementation above shows a common solution and simply returns a
  * pointer to statically defined array of #GtkIMContextInfo items for each
  * provided input method.
  *
- * <informalexample><programlisting>
+ * |[<!-- language="C" -->
  * #GtkIMContext * im_module_create(const #gchar *context_id);
- * </programlisting></informalexample>
+ * ]|
  * This function should return a pointer to a newly created instance of the
  * #GtkIMContext subclass identified by @context_id. The context ID is the same
  * as specified in the #GtkIMContextInfo array returned by im_module_list().
@@ -107,7 +106,20 @@ enum {
   LAST_SIGNAL
 };
 
-static guint im_context_signals[LAST_SIGNAL] = { 0 };
+enum {
+  PROP_INPUT_PURPOSE = 1,
+  PROP_INPUT_HINTS,
+  LAST_PROPERTY
+};
+
+static guint im_context_signals[LAST_SIGNAL] = { 0, };
+static GParamSpec *properties[LAST_PROPERTY] = { NULL, };
+
+typedef struct _GtkIMContextPrivate GtkIMContextPrivate;
+struct _GtkIMContextPrivate {
+  GtkInputPurpose purpose;
+  GtkInputHints hints;
+};
 
 static void     gtk_im_context_real_get_preedit_string (GtkIMContext   *context,
 							gchar         **str,
@@ -123,7 +135,17 @@ static void     gtk_im_context_real_set_surrounding    (GtkIMContext   *context,
 							gint            len,
 							gint            cursor_index);
 
-G_DEFINE_ABSTRACT_TYPE (GtkIMContext, gtk_im_context, G_TYPE_OBJECT)
+static void     gtk_im_context_get_property            (GObject        *obj,
+                                                        guint           property_id,
+                                                        GValue         *value,
+                                                        GParamSpec     *pspec);
+static void     gtk_im_context_set_property            (GObject        *obj,
+                                                        guint           property_id,
+                                                        const GValue   *value,
+                                                        GParamSpec     *pspec);
+
+
+G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE (GtkIMContext, gtk_im_context, G_TYPE_OBJECT)
 
 /**
  * GtkIMContextClass:
@@ -185,6 +207,11 @@ G_DEFINE_ABSTRACT_TYPE (GtkIMContext, gtk_im_context, G_TYPE_OBJECT)
 static void
 gtk_im_context_class_init (GtkIMContextClass *klass)
 {
+  GObjectClass *object_class = G_OBJECT_CLASS (klass);
+
+  object_class->get_property = gtk_im_context_get_property;
+  object_class->set_property = gtk_im_context_set_property;
+
   klass->get_preedit_string = gtk_im_context_real_get_preedit_string;
   klass->filter_keypress = gtk_im_context_real_filter_keypress;
   klass->get_surrounding = gtk_im_context_real_get_surrounding;
@@ -297,6 +324,24 @@ gtk_im_context_class_init (GtkIMContextClass *klass)
                   G_TYPE_BOOLEAN, 2,
                   G_TYPE_INT,
 		  G_TYPE_INT);
+
+  properties[PROP_INPUT_PURPOSE] =
+    g_param_spec_enum ("input-purpose",
+                         P_("Purpose"),
+                         P_("Purpose of the text field"),
+                         GTK_TYPE_INPUT_PURPOSE,
+                         GTK_INPUT_PURPOSE_FREE_FORM,
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+
+  properties[PROP_INPUT_HINTS] =
+    g_param_spec_flags ("input-hints",
+                         P_("hints"),
+                         P_("Hints for the text field behaviour"),
+                         GTK_TYPE_INPUT_HINTS,
+                         GTK_INPUT_HINT_NONE,
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+
+  g_object_class_install_properties (object_class, LAST_PROPERTY, properties);
 }
 
 static void
@@ -706,3 +751,47 @@ gtk_im_context_delete_surrounding (GtkIMContext *context,
 
   return result;
 }
+
+static void
+gtk_im_context_get_property (GObject    *obj,
+                             guint       property_id,
+                             GValue     *value,
+                             GParamSpec *pspec)
+{
+  GtkIMContextPrivate *priv = gtk_im_context_get_instance_private (GTK_IM_CONTEXT (obj));
+
+  switch (property_id)
+    {
+    case PROP_INPUT_PURPOSE:
+      g_value_set_enum (value, priv->purpose);
+      break;
+    case PROP_INPUT_HINTS:
+      g_value_set_flags (value, priv->hints);
+      break;
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, property_id, pspec);
+      break;
+    }
+}
+
+static void
+gtk_im_context_set_property (GObject      *obj,
+                             guint         property_id,
+                             const GValue *value,
+                             GParamSpec   *pspec)
+{
+  GtkIMContextPrivate *priv = gtk_im_context_get_instance_private (GTK_IM_CONTEXT (obj));
+
+  switch (property_id)
+    {
+    case PROP_INPUT_PURPOSE:
+      priv->purpose = g_value_get_enum (value);
+      break;
+    case PROP_INPUT_HINTS:
+      priv->hints = g_value_get_flags (value);
+      break;
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, property_id, pspec);
+      break;
+    }
+}
