@@ -52,10 +52,10 @@
  * example, when an Open button is clicked you might display a
  * #GtkFileChooserDialog. After a callback finishes, GTK+ will return to the
  * main loop and await more user input.
- * </para>
+ *
  * <example>
- * <title>Typical <function>main()</function> function for a GTK+ application</title>
- * <programlisting>
+ * <title>Typical main() function for a GTK+ application</title>
+ * |[<!-- language="C" -->
  * int
  * main (int argc, char **argv)
  * {
@@ -80,9 +80,9 @@
  *   /&ast; The user lost interest &ast;/
  *   return 0;
  * }
- * </programlisting>
+ * ]|
  * </example>
- * <para>
+ *
  * It's OK to use the GLib main loop directly instead of gtk_main(), though it
  * involves slightly more typing. See #GMainLoop in the GLib documentation.
  */
@@ -910,7 +910,7 @@ gtk_init_with_args (gint                 *argc,
  * Any arguments used by GTK+ or GDK are removed from the array and
  * @argc and @argv are updated accordingly.
  *
- * There is no need to call this function explicitely if you are using
+ * There is no need to call this function explicitly if you are using
  * gtk_init(), or gtk_init_check().
  *
  * Return value: %TRUE if initialization succeeded, otherwise %FALSE
@@ -1009,23 +1009,19 @@ gtk_init_check (int    *argc,
  * if you are calling gtk_parse_args(), gtk_init_check(),
  * gtk_init_with_args() or g_option_context_parse() with
  * the option group returned by gtk_get_option_group(),
- * you <emphasis>don't</emphasis> have to call gtk_init().
+ * you don't have to call gtk_init().
  *
- * <note><para>
  * This function will terminate your program if it was unable to
  * initialize the windowing system for some reason. If you want
  * your program to fall back to a textual interface you want to
  * call gtk_init_check() instead.
- * </para></note>
  *
- * <note><para>
  * Since 2.18, GTK+ calls <literal>signal (SIGPIPE, SIG_IGN)</literal>
  * during initialization, to ignore SIGPIPE signals, since these are
  * almost never wanted in graphical applications. If you do need to
  * handle SIGPIPE for some reason, reset the handler after gtk_init(),
  * but notice that other libraries (e.g. libdbus or gvfs) might do
  * similar things.
- * </para></note>
  */
 void
 gtk_init (int *argc, char ***argv)
@@ -1121,7 +1117,7 @@ gtk_init_check_abi_check (int *argc, char ***argv, int num_checks, size_t sizeof
  * changed after GTK+ has already been initialized. In this case,
  * you can use it to update the default text direction as follows:
  *
- * |[
+ * |[<!-- language="C" -->
  * setlocale (LC_ALL, new_locale);
  * direction = gtk_get_locale_direction ();
  * gtk_widget_set_default_direction (direction);
@@ -1253,14 +1249,14 @@ gtk_main_quit (void)
  *
  * <example>
  * <title>Updating the UI during a long computation</title>
- * <programlisting>
+ * |[<!-- language="C" -->
  *  /&ast; computation going on... &ast;/
  *
  *  while (gtk_events_pending ())
  *    gtk_main_iteration ();
  *
  *  /&ast; ...computation continued &ast;/
- * </programlisting>
+ * ]|
  * </example>
  *
  * Returns: %TRUE if any events are pending, %FALSE otherwise
@@ -1467,51 +1463,33 @@ rewrite_event_for_grabs (GdkEvent *event)
  * know how exactly events are handled. So here is what this function
  * does with the event:
  *
- * <orderedlist>
- * <listitem><para>
- *   Compress enter/leave notify events. If the event passed build an
- *   enter/leave pair together with the next event (peeked from GDK), both
- *   events are thrown away. This is to avoid a backlog of (de-)highlighting
- *   widgets crossed by the pointer.
- * </para></listitem>
- * <listitem><para>
- *   Find the widget which got the event. If the widget can't be determined
- *   the event is thrown away unless it belongs to a INCR transaction.
- * </para></listitem>
- * <listitem><para>
- *   Then the event is pushed onto a stack so you can query the currently
- *   handled event with gtk_get_current_event().
- * </para></listitem>
- * <listitem><para>
- *   The event is sent to a widget. If a grab is active all events for widgets
- *   that are not in the contained in the grab widget are sent to the latter
- *   with a few exceptions:
- *   <itemizedlist>
- *   <listitem><para>
- *     Deletion and destruction events are still sent to the event widget for
- *     obvious reasons.
- *   </para></listitem>
- *   <listitem><para>
- *     Events which directly relate to the visual representation of the event
- *     widget.
- *   </para></listitem>
- *   <listitem><para>
- *     Leave events are delivered to the event widget if there was an enter
- *     event delivered to it before without the paired leave event.
- *   </para></listitem>
- *   <listitem><para>
- *     Drag events are not redirected because it is unclear what the semantics
- *     of that would be.
- *   </para></listitem>
- *   </itemizedlist>
- *   Another point of interest might be that all key events are first passed
- *   through the key snooper functions if there are any. Read the description
- *   of gtk_key_snooper_install() if you need this feature.
- * </para></listitem>
- * <listitem><para>
- *   After finishing the delivery the event is popped from the event stack.
- * </para></listitem>
- * </orderedlist>
+ * 1. Compress enter/leave notify events. If the event passed build an
+ *    enter/leave pair together with the next event (peeked from GDK), both
+ *    events are thrown away. This is to avoid a backlog of (de-)highlighting
+ *    widgets crossed by the pointer.
+ * 
+ * 2. Find the widget which got the event. If the widget can't be determined
+ *    the event is thrown away unless it belongs to a INCR transaction.
+ *
+ * 3. Then the event is pushed onto a stack so you can query the currently
+ *    handled event with gtk_get_current_event().
+ * 
+ * 4. The event is sent to a widget. If a grab is active all events for widgets
+ *    that are not in the contained in the grab widget are sent to the latter
+ *    with a few exceptions:
+ *    - Deletion and destruction events are still sent to the event widget for
+ *      obvious reasons.
+ *    - Events which directly relate to the visual representation of the event
+ *      widget.
+ *    - Leave events are delivered to the event widget if there was an enter
+ *      event delivered to it before without the paired leave event.
+ *    - Drag events are not redirected because it is unclear what the semantics
+ *      of that would be.
+ *    Another point of interest might be that all key events are first passed
+ *    through the key snooper functions if there are any. Read the description
+ *    of gtk_key_snooper_install() if you need this feature.
+ * 
+ * 5. After finishing the delivery the event is popped from the event stack.
  */
 void
 gtk_main_do_event (GdkEvent *event)
@@ -1568,6 +1546,12 @@ gtk_main_do_event (GdkEvent *event)
       event_widget = gtk_get_event_widget (event);
     }
 
+  if (GTK_IS_WINDOW (event_widget))
+    {
+      if (_gtk_window_check_handle_wm_event (event))
+        return;
+    }
+
   window_group = gtk_main_get_window_group (event_widget);
   device = gdk_event_get_device (event);
 
@@ -1822,15 +1806,15 @@ gtk_main_do_event (GdkEvent *event)
  *
  * <example>
  * <title>A persistent window</title>
- * <programlisting>
- * #include &lt;gtk/gtk.h>&lt;
+ * |[<!-- language="C" -->
+ * #include <gtk/gtk.h>
  *
  * int
  * main (int argc, char **argv)
  * {
  *   GtkWidget *win, *but;
  *
- *   gtk_init (&amp;argc, &amp;argv);
+ *   gtk_init (&argc, &argv);
  *
  *   win = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  *   g_signal_connect (win, "delete-event",
@@ -1849,7 +1833,7 @@ gtk_main_do_event (GdkEvent *event)
  *
  *   return 0;
  * }
- * </programlisting>
+ * ]|
  * </example>
  *
  * Returns: %TRUE
