@@ -148,6 +148,8 @@
 #include "gtktypebuiltins.h"
 #include "gtkwindow.h"
 #include "gtkmain.h"
+#include "gtkaccessible.h"
+#include "a11y/gtkmenubuttonaccessible.h"
 
 #include "gtkprivate.h"
 #include "gtkintl.h"
@@ -160,9 +162,9 @@ struct _GtkMenuButtonPrivate
   GtkMenuButtonShowMenuCallback func;
   gpointer user_data;
 
-  GtkArrowType arrow_type;
   GtkWidget *align_widget;
   gpointer arrow_widget;
+  GtkArrowType arrow_type;
 };
 
 enum
@@ -253,13 +255,12 @@ menu_position_up_down_func (GtkMenu       *menu,
   GtkMenuButtonPrivate *priv = menu_button->priv;
   GtkWidget *widget = GTK_WIDGET (menu_button);
   GtkWidget *toplevel;
-  GtkRequisition menu_req;
   GtkTextDirection direction;
   GdkRectangle monitor;
   gint monitor_num;
   GdkScreen *screen;
   GdkWindow *window;
-  GtkAllocation allocation, arrow_allocation;
+  GtkAllocation menu_allocation, allocation, arrow_allocation;
   GtkAlign align;
 
   /* In the common case the menu button is showing a dropdown menu, set the
@@ -272,9 +273,6 @@ menu_position_up_down_func (GtkMenu       *menu,
       gtk_window_set_type_hint (GTK_WINDOW (toplevel), GDK_WINDOW_TYPE_HINT_DROPDOWN_MENU);
     }
 
-  gtk_widget_get_preferred_size (GTK_WIDGET (priv->popup),
-                                 &menu_req, NULL);
-
   align = gtk_widget_get_halign (GTK_WIDGET (priv->popup));
   direction = gtk_widget_get_direction (widget);
   window = gtk_widget_get_window (priv->align_widget ? priv->align_widget : widget);
@@ -287,6 +285,7 @@ menu_position_up_down_func (GtkMenu       *menu,
 
   gtk_widget_get_allocation (priv->align_widget ? priv->align_widget : widget, &allocation);
   gtk_widget_get_allocation (widget, &arrow_allocation);
+  gtk_widget_get_allocation (GTK_WIDGET (priv->popup), &menu_allocation);
 
   gdk_window_get_origin (window, x, y);
   *x += allocation.x;
@@ -297,27 +296,27 @@ menu_position_up_down_func (GtkMenu       *menu,
     align = GTK_ALIGN_START;
 
   if (align == GTK_ALIGN_CENTER)
-    *x -= (menu_req.width - allocation.width) / 2;
+    *x -= (menu_allocation.width - allocation.width) / 2;
   else if ((align == GTK_ALIGN_START && direction == GTK_TEXT_DIR_LTR) ||
            (align == GTK_ALIGN_END && direction == GTK_TEXT_DIR_RTL))
-    *x += MAX (allocation.width - menu_req.width, 0);
-  else if (menu_req.width > allocation.width)
-    *x -= menu_req.width - allocation.width;
+    *x += MAX (allocation.width - menu_allocation.width, 0);
+  else if (menu_allocation.width > allocation.width)
+    *x -= menu_allocation.width - allocation.width;
 
-  if (priv->arrow_type == GTK_ARROW_UP && *y - menu_req.height >= monitor.y)
+  if (priv->arrow_type == GTK_ARROW_UP && *y - menu_allocation.height >= monitor.y)
     {
-      *y -= menu_req.height;
+      *y -= menu_allocation.height;
     }
   else
     {
-      if ((*y + arrow_allocation.height + menu_req.height) <= monitor.y + monitor.height)
+      if ((*y + arrow_allocation.height + menu_allocation.height) <= monitor.y + monitor.height)
         *y += arrow_allocation.height;
-      else if ((*y - menu_req.height) >= monitor.y)
-        *y -= menu_req.height;
+      else if ((*y - menu_allocation.height) >= monitor.y)
+        *y -= menu_allocation.height;
       else if (monitor.y + monitor.height - (*y + arrow_allocation.height) > *y)
         *y += arrow_allocation.height;
       else
-        *y -= menu_req.height;
+        *y -= menu_allocation.height;
     }
 
   *push_in = FALSE;
@@ -332,8 +331,8 @@ menu_position_side_func (GtkMenu       *menu,
 {
   GtkMenuButtonPrivate *priv = menu_button->priv;
   GtkAllocation allocation;
+  GtkAllocation menu_allocation;
   GtkWidget *widget = GTK_WIDGET (menu_button);
-  GtkRequisition menu_req;
   GdkRectangle monitor;
   gint monitor_num;
   GdkScreen *screen;
@@ -341,9 +340,6 @@ menu_position_side_func (GtkMenu       *menu,
   GtkAlign align;
   GtkTextDirection direction;
 
-  gtk_widget_get_preferred_size (GTK_WIDGET (priv->popup),
-                                 &menu_req, NULL);
-
   window = gtk_widget_get_window (widget);
 
   direction = gtk_widget_get_direction (widget);
@@ -357,20 +353,21 @@ menu_position_side_func (GtkMenu       *menu,
   gdk_window_get_origin (gtk_button_get_event_window (GTK_BUTTON (menu_button)), x, y);
 
   gtk_widget_get_allocation (widget, &allocation);
+  gtk_widget_get_allocation (GTK_WIDGET (priv->popup), &menu_allocation);
 
   if ((priv->arrow_type == GTK_ARROW_RIGHT && direction == GTK_TEXT_DIR_LTR) ||
       (priv->arrow_type == GTK_ARROW_LEFT && direction == GTK_TEXT_DIR_RTL))
 
     {
-      if (*x + allocation.width + menu_req.width <= monitor.x + monitor.width)
+      if (*x + allocation.width + menu_allocation.width <= monitor.x + monitor.width)
         *x += allocation.width;
       else
-        *x -= menu_req.width;
+        *x -= menu_allocation.width;
     }
   else
     {
-      if (*x - menu_req.width >= monitor.x)
-        *x -= menu_req.width;
+      if (*x - menu_allocation.width >= monitor.x)
+        *x -= menu_allocation.width;
       else
         *x += allocation.width;
     }
@@ -380,9 +377,9 @@ menu_position_side_func (GtkMenu       *menu,
     align = GTK_ALIGN_START;
 
   if (align == GTK_ALIGN_CENTER)
-    *y -= (menu_req.height - allocation.height) / 2;
+    *y -= (menu_allocation.height - allocation.height) / 2;
   else if (align == GTK_ALIGN_END)
-    *y -= menu_req.height - allocation.height;
+    *y -= menu_allocation.height - allocation.height;
 
   *push_in = FALSE;
 }
@@ -510,7 +507,7 @@ gtk_menu_button_class_init (GtkMenuButtonClass *klass)
   g_object_class_install_property (gobject_class,
                                    PROP_POPUP,
                                    g_param_spec_object ("popup",
-                                                        P_("popup"),
+                                                        P_("Popup"),
                                                         P_("The dropdown menu."),
                                                         GTK_TYPE_MENU,
                                                         G_PARAM_READWRITE));
@@ -527,7 +524,7 @@ gtk_menu_button_class_init (GtkMenuButtonClass *klass)
   g_object_class_install_property (gobject_class,
                                    PROP_MODEL,
                                    g_param_spec_object ("menu-model",
-                                                        P_("menu-model"),
+                                                        P_("Menu model"),
                                                         P_("The dropdown menu's model."),
                                                         G_TYPE_MENU_MODEL,
                                                         G_PARAM_READWRITE));
@@ -541,7 +538,7 @@ gtk_menu_button_class_init (GtkMenuButtonClass *klass)
   g_object_class_install_property (gobject_class,
                                    PROP_ALIGN_WIDGET,
                                    g_param_spec_object ("align-widget",
-                                                        P_("align-widget"),
+                                                        P_("Align with"),
                                                         P_("The parent widget which the menu should align with."),
                                                         GTK_TYPE_CONTAINER,
                                                         G_PARAM_READWRITE));
@@ -556,11 +553,13 @@ gtk_menu_button_class_init (GtkMenuButtonClass *klass)
   g_object_class_install_property (gobject_class,
                                    PROP_DIRECTION,
                                    g_param_spec_enum ("direction",
-                                                      P_("direction"),
+                                                      P_("Direction"),
                                                       P_("The direction the arrow should point."),
                                                       GTK_TYPE_ARROW_TYPE,
                                                       GTK_ARROW_DOWN,
                                                       G_PARAM_READWRITE));
+
+  gtk_widget_class_set_accessible_type (widget_class, GTK_TYPE_MENU_BUTTON_ACCESSIBLE);
 }
 
 static void
@@ -578,6 +577,7 @@ static void
 gtk_menu_button_init (GtkMenuButton *menu_button)
 {
   GtkMenuButtonPrivate *priv;
+  AtkObject *accessible;
 
   priv = gtk_menu_button_get_instance_private (menu_button);
   menu_button->priv = priv;
@@ -586,6 +586,10 @@ gtk_menu_button_init (GtkMenuButton *menu_button)
   add_arrow (menu_button);
 
   gtk_widget_set_sensitive (GTK_WIDGET (menu_button), FALSE);
+
+  accessible = gtk_widget_get_accessible (GTK_WIDGET (menu_button));
+  if (GTK_IS_ACCESSIBLE (accessible))
+    atk_object_set_name (accessible, _("Menu"));
 }
 
 /**
