@@ -32,8 +32,8 @@
 #include "gtkbuildable.h"
 #include "gtklabel.h"
 #include "gtkbox.h"
+#include "gtkbbox.h"
 #include "gtkimage.h"
-#include "gtkiconfactory.h"
 #include "gtkintl.h"
 #include "gtkprivate.h"
 #include "gtktypebuiltins.h"
@@ -57,44 +57,40 @@
  * you can also pass in the %GTK_DIALOG_MODAL flag, gtk_dialog_run() automatically
  * makes the dialog modal and waits for the user to respond to it. gtk_dialog_run()
  * returns when any dialog button is clicked.
- * <example>
- * <title>A modal dialog.</title>
- * <programlisting>
+ *
+ * An example for using a modal dialog:
+ * |[<!-- language="C" -->
  *  dialog = gtk_message_dialog_new (main_application_window,
  *                                   GTK_DIALOG_DESTROY_WITH_PARENT,
  *                                   GTK_MESSAGE_ERROR,
  *                                   GTK_BUTTONS_CLOSE,
- *                                   "Error loading file '&percnt;s': &percnt;s",
+ *                                   "Error loading file '%s': %s",
  *                                   filename, g_strerror (errno));
  *  gtk_dialog_run (GTK_DIALOG (dialog));
  *  gtk_widget_destroy (dialog);
- * </programlisting>
- * </example>
+ * ]|
+ *
  * You might do a non-modal #GtkMessageDialog as follows:
- * <example>
- * <title>A non-modal dialog.</title>
- * <programlisting>
+ *
+ * An example for a non-modal dialog:
+ * |[<!-- language="C" -->
  *  dialog = gtk_message_dialog_new (main_application_window,
  *                                   GTK_DIALOG_DESTROY_WITH_PARENT,
  *                                   GTK_MESSAGE_ERROR,
  *                                   GTK_BUTTONS_CLOSE,
- *                                   "Error loading file '&percnt;s': &percnt;s",
+ *                                   "Error loading file '%s': %s",
  *                                   filename, g_strerror (errno));
  *
  *  /&ast; Destroy the dialog when the user responds to it (e.g. clicks a button) &ast;/
  *  g_signal_connect_swapped (dialog, "response",
  *                            G_CALLBACK (gtk_widget_destroy),
  *                            dialog);
- * </programlisting>
- * </example>
+ * ]|
+ *
+ * ## GtkMessageDialog as GtkBuildable
  *
- * <refsect2 id="GtkMessageDialog-BUILDER-UI">
- * <title>GtkMessageDialog as GtkBuildable</title>
- * <para>
  * The GtkMessageDialog implementation of the GtkBuildable interface exposes
  * the message area as an internal child with the name "message_area".
- * </para>
- * </refsect2>
  */
 
 struct _GtkMessageDialogPrivate
@@ -295,17 +291,18 @@ gtk_message_dialog_class_init (GtkMessageDialogClass *class)
 							GTK_PARAM_READABLE));
 
   /* Setup Composite data */
-  gtk_widget_class_set_template_from_resource (widget_class, "/org/gtk/libgtk/gtkmessagedialog.ui");
-  gtk_widget_class_bind_child (widget_class, GtkMessageDialogPrivate, image);
-  gtk_widget_class_bind_child (widget_class, GtkMessageDialogPrivate, label);
-  gtk_widget_class_bind_child (widget_class, GtkMessageDialogPrivate, secondary_label);
-  gtk_widget_class_bind_child_internal (widget_class, GtkMessageDialogPrivate, message_area);
+  gtk_widget_class_set_template_from_resource (widget_class, "/org/gtk/libgtk/ui/gtkmessagedialog.ui");
+  gtk_widget_class_bind_template_child_private (widget_class, GtkMessageDialog, image);
+  gtk_widget_class_bind_template_child_private (widget_class, GtkMessageDialog, label);
+  gtk_widget_class_bind_template_child_private (widget_class, GtkMessageDialog, secondary_label);
+  gtk_widget_class_bind_template_child_internal_private (widget_class, GtkMessageDialog, message_area);
 }
 
 static void
 gtk_message_dialog_init (GtkMessageDialog *dialog)
 {
   GtkMessageDialogPrivate *priv;
+  GtkWidget *action_area;
 
   dialog->priv = gtk_message_dialog_get_instance_private (dialog);
   priv = dialog->priv;
@@ -317,6 +314,10 @@ gtk_message_dialog_init (GtkMessageDialog *dialog)
 
   gtk_widget_init_template (GTK_WIDGET (dialog));
   gtk_message_dialog_style_updated (GTK_WIDGET (dialog));
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+  action_area = gtk_dialog_get_action_area (GTK_DIALOG (dialog));
+G_GNUC_END_IGNORE_DEPRECATIONS
+  gtk_button_box_set_layout (GTK_BUTTON_BOX (action_area), GTK_BUTTONBOX_EXPAND);
 }
 
 static void
@@ -550,6 +551,7 @@ gtk_message_dialog_new (GtkWindow     *parent,
   g_return_val_if_fail (parent == NULL || GTK_IS_WINDOW (parent), NULL);
 
   widget = g_object_new (GTK_TYPE_MESSAGE_DIALOG,
+			 "use-header-bar", FALSE,
 			 "message-type", type,
 			 "buttons", buttons,
 			 NULL);
@@ -604,7 +606,7 @@ gtk_message_dialog_new (GtkWindow     *parent,
  * instead, since you can't pass the markup string either
  * as the format (it might contain '%' characters) or as a string
  * argument.
- * |[
+ * |[<!-- language="C" -->
  *  GtkWidget *dialog;
  *  dialog = gtk_message_dialog_new (main_application_window,
  *                                   GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -794,13 +796,13 @@ gtk_message_dialog_format_secondary_text (GtkMessageDialog *message_dialog,
  * may contain special XML characters, you should use g_markup_printf_escaped()
  * to escape it.
 
- * <informalexample><programlisting>
+ * |[<!-- language="C" -->
  * gchar *msg;
  *
  * msg = g_markup_printf_escaped (message_format, ...);
  * gtk_message_dialog_format_secondary_markup (message_dialog, "&percnt;s", msg);
  * g_free (msg);
- * </programlisting></informalexample>
+ * ]|
  *
  * Since: 2.6
  */
@@ -869,6 +871,7 @@ gtk_message_dialog_add_buttons (GtkMessageDialog* message_dialog,
 {
   GtkDialog* dialog = GTK_DIALOG (message_dialog);
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   switch (buttons)
     {
     case GTK_BUTTONS_NONE:
@@ -876,30 +879,20 @@ gtk_message_dialog_add_buttons (GtkMessageDialog* message_dialog,
       break;
 
     case GTK_BUTTONS_OK:
-      gtk_dialog_add_button (dialog,
-                             _("_OK"),
-                             GTK_RESPONSE_OK);
+      gtk_dialog_add_button (dialog, _("_OK"), GTK_RESPONSE_OK);
       break;
 
     case GTK_BUTTONS_CLOSE:
-      gtk_dialog_add_button (dialog,
-                             _("_Close"),
-                             GTK_RESPONSE_CLOSE);
+      gtk_dialog_add_button (dialog, _("_Close"), GTK_RESPONSE_CLOSE);
       break;
 
     case GTK_BUTTONS_CANCEL:
-      gtk_dialog_add_button (dialog,
-                             _("_Cancel"),
-                             GTK_RESPONSE_CANCEL);
+      gtk_dialog_add_button (dialog, _("_Cancel"), GTK_RESPONSE_CANCEL);
       break;
 
     case GTK_BUTTONS_YES_NO:
-      gtk_dialog_add_button (dialog,
-                             _("_No"),
-                             GTK_RESPONSE_NO);
-      gtk_dialog_add_button (dialog,
-                             _("_Yes"),
-                             GTK_RESPONSE_YES);
+      gtk_dialog_add_button (dialog, _("_No"), GTK_RESPONSE_NO);
+      gtk_dialog_add_button (dialog, _("_Yes"), GTK_RESPONSE_YES);
       gtk_dialog_set_alternative_button_order (GTK_DIALOG (dialog),
 					       GTK_RESPONSE_YES,
 					       GTK_RESPONSE_NO,
@@ -907,12 +900,8 @@ gtk_message_dialog_add_buttons (GtkMessageDialog* message_dialog,
       break;
 
     case GTK_BUTTONS_OK_CANCEL:
-      gtk_dialog_add_button (dialog,
-                             _("_Cancel"),
-                             GTK_RESPONSE_CANCEL);
-      gtk_dialog_add_button (dialog,
-                             _("_OK"),
-                             GTK_RESPONSE_OK);
+      gtk_dialog_add_button (dialog, _("_Cancel"), GTK_RESPONSE_CANCEL);
+      gtk_dialog_add_button (dialog, _("_OK"), GTK_RESPONSE_OK);
       gtk_dialog_set_alternative_button_order (GTK_DIALOG (dialog),
 					       GTK_RESPONSE_OK,
 					       GTK_RESPONSE_CANCEL,
@@ -923,6 +912,7 @@ gtk_message_dialog_add_buttons (GtkMessageDialog* message_dialog,
       g_warning ("Unknown GtkButtonsType");
       break;
     } 
+G_GNUC_END_IGNORE_DEPRECATIONS
 
   g_object_notify (G_OBJECT (message_dialog), "buttons");
 }
