@@ -30,6 +30,11 @@
 #include "gtkprintoperation.h"  /* for GtkPrintError */
 #include "gtkintl.h"
 
+/* _gtk_load_custom_papers() only on Unix so far  */
+#ifdef G_OS_UNIX
+#include "gtkcustompaperunixdialog.h"
+#endif
+
 #include "paper_names_offsets.c"
 
 
@@ -454,8 +459,6 @@ gtk_paper_size_is_equal (GtkPaperSize *size1,
                  gtk_paper_size_get_name (size2)) == 0;
 }
 
-GList * _gtk_load_custom_papers (void);
-
 /**
  * gtk_paper_size_get_paper_sizes:
  * @include_custom: whether to include custom paper sizes
@@ -473,7 +476,8 @@ gtk_paper_size_get_paper_sizes (gboolean include_custom)
 {
   GList *list = NULL;
   guint i;
-#ifdef G_OS_UNIX                /* _gtk_load_custom_papers() only on Unix so far  */
+/* _gtk_load_custom_papers() only on Unix so far  */
+#ifdef G_OS_UNIX
   if (include_custom)
     {
       GList *page_setups, *l;
