@@ -20,10 +20,7 @@
 
 #include "gtkpopover.h"
 
-G_BEGIN_DECLS
-
-void gtk_popover_update_position (GtkPopover *popover);
-
-G_END_DECLS
+void    _gtk_popover_set_apply_shape   (GtkPopover   *popover,
+                                        gboolean      modal);
 
 #endif /* __GTK_POPOVER_PRIVATE_H__ */
