@@ -37,7 +37,7 @@
  *
  * <example>
  * <title>Using GtkPrintContext in a #GtkPrintOperation::draw-page callback</title>
- * <programlisting>
+ * |[<!-- language="C" -->
  * static void
  * draw_page (GtkPrintOperation *operation,
  * 	   GtkPrintContext   *context,
@@ -89,7 +89,7 @@
  *
  *   g_object_unref (layout);
  * }
- * </programlisting>
+ * ]|
  * </example>
  *
  * Printing support was added in GTK+ 2.10.
@@ -285,6 +285,36 @@ _gtk_print_context_rotate_according_to_orientation (GtkPrintContext *context)
     }
 }
 
+void
+_gtk_print_context_reverse_according_to_orientation (GtkPrintContext *context)
+{
+  cairo_t *cr = context->cr;
+  cairo_matrix_t matrix;
+  gdouble width, height;
+
+  width = gtk_page_setup_get_paper_width (context->page_setup, GTK_UNIT_INCH);
+  width = width * context->surface_dpi_x / context->pixels_per_unit_x;
+  height = gtk_page_setup_get_paper_height (context->page_setup, GTK_UNIT_INCH);
+  height = height * context->surface_dpi_y / context->pixels_per_unit_y;
+
+  switch (gtk_page_setup_get_orientation (context->page_setup))
+    {
+    default:
+    case GTK_PAGE_ORIENTATION_PORTRAIT:
+    case GTK_PAGE_ORIENTATION_LANDSCAPE:
+      break;
+    case GTK_PAGE_ORIENTATION_REVERSE_PORTRAIT:
+    case GTK_PAGE_ORIENTATION_REVERSE_LANDSCAPE:
+      cairo_translate (cr, width, height);
+      cairo_matrix_init (&matrix,
+			 -1,  0,
+			  0, -1,
+			  0,  0);
+      cairo_transform (cr, &matrix);
+      break;
+    }
+}
+
 void
 _gtk_print_context_translate_into_margin (GtkPrintContext *context)
 {
