@@ -23,6 +23,8 @@
 #include "gtkrecentchooserutils.h"
 #include "gtkrecentmanager.h"
 #include "gtktypebuiltins.h"
+#include "gtksettings.h"
+#include "gtkdialogprivate.h"
 
 #include <stdarg.h>
 
@@ -46,13 +48,13 @@
  * <title>Typical usage</title>
  * In the simplest of cases, you can use the following code to use
  * a #GtkRecentChooserDialog to select a recently used file:
- * <programlisting>
+ * |[<!-- language="C" -->
  * GtkWidget *dialog;
  *
  * dialog = gtk_recent_chooser_dialog_new ("Recent Documents",
  *                                         parent_window,
- *                                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
- *                                         GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+ *                                         _("_Cancel"), GTK_RESPONSE_CANCEL,
+ *                                         _("_Open"), GTK_RESPONSE_ACCEPT,
  *                                         NULL);
  *
  * if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
@@ -65,7 +67,7 @@
  *   }
  *
  * gtk_widget_destroy (dialog);
- * </programlisting>
+ * ]|
  * </example>
  *
  * Recently used files are supported since GTK+ 2.10.
@@ -101,6 +103,7 @@ static void gtk_recent_chooser_dialog_get_property (GObject      *object,
 G_DEFINE_TYPE_WITH_CODE (GtkRecentChooserDialog,
 			 gtk_recent_chooser_dialog,
 			 GTK_TYPE_DIALOG,
+                         G_ADD_PRIVATE (GtkRecentChooserDialog)
 			 G_IMPLEMENT_INTERFACE (GTK_TYPE_RECENT_CHOOSER,
 		       				_gtk_recent_chooser_delegate_iface_init))
 
@@ -115,29 +118,27 @@ gtk_recent_chooser_dialog_class_init (GtkRecentChooserDialogClass *klass)
   gobject_class->finalize = gtk_recent_chooser_dialog_finalize;
   
   _gtk_recent_chooser_install_properties (gobject_class);
-  
-  g_type_class_add_private (klass, sizeof (GtkRecentChooserDialogPrivate));
 }
 
 static void
 gtk_recent_chooser_dialog_init (GtkRecentChooserDialog *dialog)
 {
+  GtkRecentChooserDialogPrivate *priv;
   GtkWidget *content_area, *action_area;
-
-  GtkRecentChooserDialogPrivate *priv = G_TYPE_INSTANCE_GET_PRIVATE (dialog,
-  								     GTK_TYPE_RECENT_CHOOSER_DIALOG,
-  								     GtkRecentChooserDialogPrivate);
   GtkDialog *rc_dialog = GTK_DIALOG (dialog);
-  
+
+  priv = gtk_recent_chooser_dialog_get_instance_private (dialog);
   dialog->priv = priv;
+  gtk_dialog_set_use_header_bar_from_setting (GTK_DIALOG (dialog));
 
   content_area = gtk_dialog_get_content_area (rc_dialog);
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   action_area = gtk_dialog_get_action_area (rc_dialog);
+G_GNUC_END_IGNORE_DEPRECATIONS
 
   gtk_container_set_border_width (GTK_CONTAINER (rc_dialog), 5);
   gtk_box_set_spacing (GTK_BOX (content_area), 2); /* 2 * 5 + 2 = 12 */
   gtk_container_set_border_width (GTK_CONTAINER (action_area), 5);
-
 }
 
 /* we intercept the GtkRecentChooser::item_activated signal and try to
@@ -158,7 +159,9 @@ gtk_recent_chooser_item_activated_cb (GtkRecentChooser *chooser,
   if (gtk_window_activate_default (GTK_WINDOW (dialog)))
     return;
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   action_area = gtk_dialog_get_action_area (rc_dialog);
+G_GNUC_END_IGNORE_DEPRECATIONS
   children = gtk_container_get_children (GTK_CONTAINER (action_area));
   
   for (l = children; l; l = l->next)
@@ -277,7 +280,7 @@ gtk_recent_chooser_dialog_new_valist (const gchar      *title,
   GtkWidget *result;
   const char *button_text = first_button_text;
   gint response_id;
-  
+
   result = g_object_new (GTK_TYPE_RECENT_CHOOSER_DIALOG,
                          "title", title,
                          "recent-manager", manager,
