@@ -56,11 +56,11 @@
  *
  * <example>
  * <title>Creating a search bar</title>
- * <programlisting>
+ * |[<!-- language="C" -->
  * <xi:include xmlns:xi="http://www.w3.org/2001/XInclude" parse="text" href="../../../../examples/search-bar.c">
  *  <xi:fallback>FIXME: MISSING XINCLUDE CONTENT</xi:fallback>
  * </xi:include>
- * </programlisting>
+ * ]|
  * </example>
  *
  * Since: 3.10
@@ -168,7 +168,7 @@ preedit_changed_cb (GtkEntry  *entry,
  *
  * <example>
  * <title>Showing the search bar on key presses</title>
- * <programlisting><![CDATA[
+ * |[<!-- language="C" -->
  * static gboolean
  * window_key_press_event_cb (GtkWidget *widget,
  *                            GdkEvent  *event,
@@ -179,7 +179,7 @@ preedit_changed_cb (GtkEntry  *entry,
  *
  * g_signal_connect (window, "key-press-event",
  *                   G_CALLBACK (window_key_press_event_cb), search_bar);
- * ]]></programlisting>
+ * ]|
  * </example>
  *
  * Return value: %GDK_EVENT_STOP if the key press event resulted
@@ -421,7 +421,7 @@ gtk_search_bar_class_init (GtkSearchBarClass *klass)
 
   g_object_class_install_properties (object_class, LAST_PROPERTY, widget_props);
 
-  gtk_widget_class_set_template_from_resource (widget_class, "/org/gtk/libgtk/gtksearchbar.ui");
+  gtk_widget_class_set_template_from_resource (widget_class, "/org/gtk/libgtk/ui/gtksearchbar.ui");
   gtk_widget_class_bind_template_child_internal_private (widget_class, GtkSearchBar, tool_box);
   gtk_widget_class_bind_template_child_internal_private (widget_class, GtkSearchBar, revealer);
   gtk_widget_class_bind_template_child_internal_private (widget_class, GtkSearchBar, box_center);
@@ -456,7 +456,7 @@ gtk_search_bar_init (GtkSearchBar *bar)
  *
  * Creates a #GtkSearchBar. You will need to tell it about
  * which widget is going to be your text entry using
- * gtk_search_bar_set_entry().
+ * gtk_search_bar_connect_entry().
  *
  * Return value: a new #GtkSearchBar
  *
