@@ -82,9 +82,8 @@
  * by way of #GtkLabel:width-chars for instance. Widgets with static sizes as well
  * as widgets that grow (such as ellipsizing text) need no such considerations.
  *
- * <refsect2 id="GtkSizeGroup-BUILDER-UI">
- * <title>GtkSizeGroup as GtkBuildable</title>
- * <para>
+ * ## GtkSizeGroup as GtkBuildable
+ *
  * Size groups can be specified in a UI definition by placing an
  * &lt;object&gt; element with <literal>class="GtkSizeGroup"</literal>
  * somewhere in the UI definition. The widgets that belong to the
@@ -92,9 +91,8 @@
  * contain multiple &lt;widget&gt; elements, one for each member
  * of the size group. The name attribute gives the id of the widget.
  *
- * <example>
- * <title>A UI definition fragment with GtkSizeGroup</title>
- * <programlisting><![CDATA[
+ * An example of a UI definition fragment with GtkSizeGroup:
+ * |[
  * <object class="GtkSizeGroup">
  *   <property name="mode">GTK_SIZE_GROUP_HORIZONTAL</property>
  *   <widgets>
@@ -102,10 +100,7 @@
  *     <widget name="radio2"/>
  *   </widgets>
  * </object>
- * ]]></programlisting>
- * </example>
- * </para>
- * </refsect2>
+ * ]|
  */
 
 
@@ -151,6 +146,11 @@ G_STATIC_ASSERT (GTK_SIZE_GROUP_HORIZONTAL == (1 << GTK_ORIENTATION_HORIZONTAL))
 G_STATIC_ASSERT (GTK_SIZE_GROUP_VERTICAL == (1 << GTK_ORIENTATION_VERTICAL));
 G_STATIC_ASSERT (GTK_SIZE_GROUP_BOTH == (GTK_SIZE_GROUP_HORIZONTAL | GTK_SIZE_GROUP_VERTICAL));
 
+G_DEFINE_TYPE_WITH_CODE (GtkSizeGroup, gtk_size_group, G_TYPE_OBJECT,
+                         G_ADD_PRIVATE (GtkSizeGroup)
+			 G_IMPLEMENT_INTERFACE (GTK_TYPE_BUILDABLE,
+						gtk_size_group_buildable_init))
+
 static void
 add_widget_to_closure (GHashTable     *widgets,
                        GHashTable     *groups,
@@ -343,8 +343,6 @@ gtk_size_group_class_init (GtkSizeGroupClass *klass)
 							    "when determining the size of the group"),
 							 FALSE,
 							 GTK_PARAM_READWRITE));
-
-  g_type_class_add_private (klass, sizeof (GtkSizeGroupPrivate));
 }
 
 static void
@@ -352,9 +350,7 @@ gtk_size_group_init (GtkSizeGroup *size_group)
 {
   GtkSizeGroupPrivate *priv;
 
-  size_group->priv = G_TYPE_INSTANCE_GET_PRIVATE (size_group,
-                                                  GTK_TYPE_SIZE_GROUP,
-                                                  GtkSizeGroupPrivate);
+  size_group->priv = gtk_size_group_get_instance_private (size_group);
   priv = size_group->priv;
 
   priv->widgets = NULL;
@@ -369,10 +365,6 @@ gtk_size_group_buildable_init (GtkBuildableIface *iface)
   iface->custom_finished = gtk_size_group_buildable_custom_finished;
 }
 
-G_DEFINE_TYPE_WITH_CODE (GtkSizeGroup, gtk_size_group, G_TYPE_OBJECT,
-			 G_IMPLEMENT_INTERFACE (GTK_TYPE_BUILDABLE,
-						gtk_size_group_buildable_init))
-
 static void
 gtk_size_group_set_property (GObject      *object,
 			     guint         prop_id,
