@@ -358,14 +358,14 @@ gtk_widget_query_size_for_orientation (GtkWidget        *widget,
  * not cached. If the for_size here is -1, then get_preferred_width()
  * or get_preferred_height() will be used.
  */
-void
-_gtk_widget_compute_size_for_orientation (GtkWidget        *widget,
-                                          GtkOrientation    orientation,
-                                          gint              for_size,
-                                          gint             *minimum,
-                                          gint             *natural,
-					  gint             *minimum_baseline,
-					  gint             *natural_baseline)
+static void
+gtk_widget_compute_size_for_orientation (GtkWidget        *widget,
+                                         GtkOrientation    orientation,
+                                         gint              for_size,
+                                         gint             *minimum,
+                                         gint             *natural,
+                                         gint             *minimum_baseline,
+                                         gint             *natural_baseline)
 {
   GHashTable *widgets;
   GHashTableIter iter;
@@ -433,10 +433,10 @@ _gtk_widget_compute_size_for_orientation (GtkWidget        *widget,
  * Gets whether the widget prefers a height-for-width layout
  * or a width-for-height layout.
  *
- * <note><para>#GtkBin widgets generally propagate the preference of
+ * #GtkBin widgets generally propagate the preference of
  * their child, container widgets need to request something either in
  * context of their children or in context of their allocation
- * capabilities.</para></note>
+ * capabilities.
  *
  * Returns: The #GtkSizeRequestMode preferred by @widget.
  *
@@ -468,8 +468,7 @@ gtk_widget_get_request_mode (GtkWidget *widget)
  *
  * Retrieves a widget's initial minimum and natural width.
  *
- * <note><para>This call is specific to height-for-width
- * requests.</para></note>
+ * This call is specific to height-for-width requests.
  *
  * The returned request will be modified by the
  * GtkWidgetClass::adjust_size_request virtual method and by any
@@ -487,12 +486,12 @@ gtk_widget_get_preferred_width (GtkWidget *widget,
   g_return_if_fail (GTK_IS_WIDGET (widget));
   g_return_if_fail (minimum_width != NULL || natural_width != NULL);
 
-  _gtk_widget_compute_size_for_orientation (widget,
-                                            GTK_ORIENTATION_HORIZONTAL,
-                                            -1,
-                                            minimum_width,
-                                            natural_width,
-					    NULL, NULL);
+  gtk_widget_compute_size_for_orientation (widget,
+                                           GTK_ORIENTATION_HORIZONTAL,
+                                           -1,
+                                           minimum_width,
+                                           natural_width,
+                                           NULL, NULL);
 }
 
 
@@ -504,7 +503,7 @@ gtk_widget_get_preferred_width (GtkWidget *widget,
  *
  * Retrieves a widget's initial minimum and natural height.
  *
- * <note><para>This call is specific to width-for-height requests.</para></note>
+ * This call is specific to width-for-height requests.
  *
  * The returned request will be modified by the
  * GtkWidgetClass::adjust_size_request virtual method and by any
@@ -522,12 +521,12 @@ gtk_widget_get_preferred_height (GtkWidget *widget,
   g_return_if_fail (GTK_IS_WIDGET (widget));
   g_return_if_fail (minimum_height != NULL || natural_height != NULL);
 
-  _gtk_widget_compute_size_for_orientation (widget,
-                                            GTK_ORIENTATION_VERTICAL,
-                                            -1,
-                                            minimum_height,
-                                            natural_height,
-					    NULL, NULL);
+  gtk_widget_compute_size_for_orientation (widget,
+                                           GTK_ORIENTATION_VERTICAL,
+                                           -1,
+                                           minimum_height,
+                                           natural_height,
+                                           NULL, NULL);
 }
 
 
@@ -560,12 +559,12 @@ gtk_widget_get_preferred_width_for_height (GtkWidget *widget,
   g_return_if_fail (minimum_width != NULL || natural_width != NULL);
   g_return_if_fail (height >= 0);
 
-  _gtk_widget_compute_size_for_orientation (widget,
-                                            GTK_ORIENTATION_HORIZONTAL,
-                                            height,
-                                            minimum_width,
-                                            natural_width,
-					    NULL, NULL);
+  gtk_widget_compute_size_for_orientation (widget,
+                                           GTK_ORIENTATION_HORIZONTAL,
+                                           height,
+                                           minimum_width,
+                                           natural_width,
+                                           NULL, NULL);
 }
 
 /**
@@ -596,12 +595,12 @@ gtk_widget_get_preferred_height_for_width (GtkWidget *widget,
   g_return_if_fail (minimum_height != NULL || natural_height != NULL);
   g_return_if_fail (width >= 0);
 
-  _gtk_widget_compute_size_for_orientation (widget,
-                                            GTK_ORIENTATION_VERTICAL,
-                                            width,
-                                            minimum_height,
-                                            natural_height,
-					    NULL, NULL);
+  gtk_widget_compute_size_for_orientation (widget,
+                                           GTK_ORIENTATION_VERTICAL,
+                                           width,
+                                           minimum_height,
+                                           natural_height,
+                                           NULL, NULL);
 }
 
 /**
@@ -637,17 +636,17 @@ gtk_widget_get_preferred_height_and_baseline_for_width (GtkWidget *widget,
   g_return_if_fail (minimum_height != NULL || natural_height != NULL);
   g_return_if_fail (width >= -1);
 
-  _gtk_widget_compute_size_for_orientation (widget,
-                                            GTK_ORIENTATION_VERTICAL,
-                                            width,
-                                            minimum_height,
-                                            natural_height,
-					    minimum_baseline,
-					    natural_baseline);
+  gtk_widget_compute_size_for_orientation (widget,
+                                           GTK_ORIENTATION_VERTICAL,
+                                           width,
+                                           minimum_height,
+                                           natural_height,
+                                           minimum_baseline,
+                                           natural_baseline);
 }
 
-/**
- * gtk_widget_get_preferred_size_and_baseline:
+/*
+ * _gtk_widget_get_preferred_size_and_baseline:
  * @widget: a #GtkWidget instance
  * @minimum_size: (out) (allow-none): location for storing the minimum size, or %NULL
  * @natural_size: (out) (allow-none): location for storing the natural size, or %NULL
@@ -661,19 +660,17 @@ gtk_widget_get_preferred_height_and_baseline_for_width (GtkWidget *widget,
  * to deduce toplevel window and menu sizes as well as child widgets in
  * free-form containers such as GtkLayout.
  *
- * <note><para>Handle with care. Note that the natural height of a height-for-width
+ * Handle with care. Note that the natural height of a height-for-width
  * widget will generally be a smaller size than the minimum height, since the required
  * height for the natural width is generally smaller than the required height for
- * the minimum width.</para></note>
- *
- * Since: 3.10
+ * the minimum width.
  */
 void
-gtk_widget_get_preferred_size_and_baseline (GtkWidget      *widget,
-					    GtkRequisition *minimum_size,
-					    GtkRequisition *natural_size,
-					    gint           *minimum_baseline,
-					    gint           *natural_baseline)
+_gtk_widget_get_preferred_size_and_baseline (GtkWidget      *widget,
+                                             GtkRequisition *minimum_size,
+                                             GtkRequisition *natural_size,
+                                             gint           *minimum_baseline,
+                                             gint           *natural_baseline)
 {
   gint min_width, nat_width;
   gint min_height, nat_height;
@@ -732,12 +729,12 @@ gtk_widget_get_preferred_size_and_baseline (GtkWidget      *widget,
  * to deduce toplevel window and menu sizes as well as child widgets in
  * free-form containers such as GtkLayout.
  *
- * <note><para>Handle with care. Note that the natural height of a height-for-width
+ * Handle with care. Note that the natural height of a height-for-width
  * widget will generally be a smaller size than the minimum height, since the required
  * height for the natural width is generally smaller than the required height for
- * the minimum width.</para></note>
+ * the minimum width.
  *
- * Use gtk_widget_get_preferred_size_and_baseline() if you want to support
+ * Use gtk_widget_get_preferred_height_and_baseline_for_width() if you want to support
  * baseline alignment.
  *
  * Since: 3.0
@@ -747,8 +744,8 @@ gtk_widget_get_preferred_size (GtkWidget      *widget,
                                GtkRequisition *minimum_size,
                                GtkRequisition *natural_size)
 {
-  gtk_widget_get_preferred_size_and_baseline (widget, minimum_size, natural_size,
-					      NULL, NULL);
+  _gtk_widget_get_preferred_size_and_baseline (widget, minimum_size, natural_size,
+                                               NULL, NULL);
 }
 
 static gint
