@@ -70,7 +70,7 @@
  *
  * <example>
  * <title>Obtaining the window ID of a socket.</title>
- * <programlisting>
+ * |[<!-- language="C" -->
  * GtkWidget *socket = gtk_socket_new (<!-- -->);
  * gtk_widget_show (socket);
  * gtk_container_add (GTK_CONTAINER (parent), socket);
@@ -81,7 +81,7 @@
  * gtk_widget_realize (socket);
  * g_print ("The ID of the sockets window is %#x\n",
  *          gtk_socket_get_id (socket));
- * </programlisting>
+ * ]|
  * </example>
  *
  * Note that if you pass the window ID of the socket to another
@@ -107,13 +107,11 @@
  * integration when embedding a <application>Qt</application> widget
  * in GTK or vice versa.
  *
- * <note>
  * The #GtkPlug and #GtkSocket widgets are only available when GTK+
  * is compiled for the X11 platform and %GDK_WINDOWING_X11 is defined.
  * They can only be used on a #GdkX11Display. To use #GtkPlug and
  * #GtkSocket, you need to include the <filename>gtk/gtkx.h</filename>
  * header.
- * </note>
  */
 
 /* Forward declararations */
@@ -176,7 +174,7 @@ enum {
 
 static guint socket_signals[LAST_SIGNAL] = { 0 };
 
-G_DEFINE_TYPE (GtkSocket, gtk_socket, GTK_TYPE_CONTAINER)
+G_DEFINE_TYPE_WITH_PRIVATE (GtkSocket, gtk_socket, GTK_TYPE_CONTAINER)
 
 static void
 gtk_socket_finalize (GObject *object)
@@ -255,8 +253,6 @@ gtk_socket_class_init (GtkSocketClass *class)
                   _gtk_boolean_handled_accumulator, NULL,
 		  _gtk_marshal_BOOLEAN__VOID,
 		  G_TYPE_BOOLEAN, 0);
-
-  g_type_class_add_private (gobject_class, sizeof (GtkSocketPrivate));
 }
 
 static void
@@ -264,10 +260,9 @@ gtk_socket_init (GtkSocket *socket)
 {
   GtkSocketPrivate *priv;
 
-  priv = G_TYPE_INSTANCE_GET_PRIVATE (socket,
-                                      GTK_TYPE_SOCKET,
-                                      GtkSocketPrivate);
+  priv = gtk_socket_get_instance_private (socket);
   socket->priv = priv;
+
   priv->request_width = 0;
   priv->request_height = 0;
   priv->current_width = 0;
