@@ -24,7 +24,7 @@
 
 #include <glib-object.h>
 #include <gtk/gtkenums.h>
-#include <gtk/gtkiconfactory.h>
+#include <gtk/deprecated/gtkiconfactory.h>
 #include <gtk/gtkstyleproperties.h>
 #include <gtk/gtktypes.h>
 
@@ -92,8 +92,11 @@ typedef struct _GtkStyleProvider GtkStyleProvider; /* dummy typedef */
  */
 struct _GtkStyleProviderIface
 {
+  /*< private >*/
   GTypeInterface g_iface;
 
+  /*< public >*/
+
   GtkStyleProperties * (* get_style) (GtkStyleProvider *provider,
                                       GtkWidgetPath    *path);
 
