@@ -43,11 +43,18 @@ G_BEGIN_DECLS
  * GtkTextBTree is the PRIVATE internal representation of it.
  */
 
-/* these values are used as "info" for the targets contained in the
- * lists returned by gtk_text_buffer_get_copy,paste_target_list()
+/**
+ * GtkTextBufferTargetInfo:
+ * @GTK_TEXT_BUFFER_TARGET_INFO_BUFFER_CONTENTS: Buffer contents
+ * @GTK_TEXT_BUFFER_TARGET_INFO_RICH_TEXT: Rich text
+ * @GTK_TEXT_BUFFER_TARGET_INFO_TEXT: Text
  *
- * the enum counts down from G_MAXUINT to avoid clashes with application
- * added drag destinations which usually start at 0.
+ * These values are used as "info" for the targets contained in the
+ * lists returned by gtk_text_buffer_get_copy_target_list() and
+ * gtk_text_buffer_get_paste_target_list().
+ *
+ * The values counts down from <literal>-1</literal> to avoid clashes
+ * with application added drag destinations which usually start at 0.
  */
 typedef enum
 {
@@ -137,52 +144,65 @@ struct _GtkTextBufferClass
   void (*_gtk_reserved4) (void);
 };
 
+GDK_AVAILABLE_IN_ALL
 GType        gtk_text_buffer_get_type       (void) G_GNUC_CONST;
 
 
 
 /* table is NULL to create a new one */
+GDK_AVAILABLE_IN_ALL
 GtkTextBuffer *gtk_text_buffer_new            (GtkTextTagTable *table);
+GDK_AVAILABLE_IN_ALL
 gint           gtk_text_buffer_get_line_count (GtkTextBuffer   *buffer);
+GDK_AVAILABLE_IN_ALL
 gint           gtk_text_buffer_get_char_count (GtkTextBuffer   *buffer);
 
 
+GDK_AVAILABLE_IN_ALL
 GtkTextTagTable* gtk_text_buffer_get_tag_table (GtkTextBuffer  *buffer);
 
 /* Delete whole buffer, then insert */
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_set_text          (GtkTextBuffer *buffer,
                                         const gchar   *text,
                                         gint           len);
 
 /* Insert into the buffer */
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_insert            (GtkTextBuffer *buffer,
                                         GtkTextIter   *iter,
                                         const gchar   *text,
                                         gint           len);
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_insert_at_cursor  (GtkTextBuffer *buffer,
                                         const gchar   *text,
                                         gint           len);
 
+GDK_AVAILABLE_IN_ALL
 gboolean gtk_text_buffer_insert_interactive           (GtkTextBuffer *buffer,
                                                        GtkTextIter   *iter,
                                                        const gchar   *text,
                                                        gint           len,
                                                        gboolean       default_editable);
+GDK_AVAILABLE_IN_ALL
 gboolean gtk_text_buffer_insert_interactive_at_cursor (GtkTextBuffer *buffer,
                                                        const gchar   *text,
                                                        gint           len,
                                                        gboolean       default_editable);
 
+GDK_AVAILABLE_IN_ALL
 void     gtk_text_buffer_insert_range             (GtkTextBuffer     *buffer,
                                                    GtkTextIter       *iter,
                                                    const GtkTextIter *start,
                                                    const GtkTextIter *end);
+GDK_AVAILABLE_IN_ALL
 gboolean gtk_text_buffer_insert_range_interactive (GtkTextBuffer     *buffer,
                                                    GtkTextIter       *iter,
                                                    const GtkTextIter *start,
                                                    const GtkTextIter *end,
                                                    gboolean           default_editable);
 
+GDK_AVAILABLE_IN_ALL
 void    gtk_text_buffer_insert_with_tags          (GtkTextBuffer     *buffer,
                                                    GtkTextIter       *iter,
                                                    const gchar       *text,
@@ -190,6 +210,7 @@ void    gtk_text_buffer_insert_with_tags          (GtkTextBuffer     *buffer,
                                                    GtkTextTag        *first_tag,
                                                    ...) G_GNUC_NULL_TERMINATED;
 
+GDK_AVAILABLE_IN_ALL
 void    gtk_text_buffer_insert_with_tags_by_name  (GtkTextBuffer     *buffer,
                                                    GtkTextIter       *iter,
                                                    const gchar       *text,
@@ -198,71 +219,90 @@ void    gtk_text_buffer_insert_with_tags_by_name  (GtkTextBuffer     *buffer,
                                                    ...) G_GNUC_NULL_TERMINATED;
 
 /* Delete from the buffer */
+GDK_AVAILABLE_IN_ALL
 void     gtk_text_buffer_delete             (GtkTextBuffer *buffer,
 					     GtkTextIter   *start,
 					     GtkTextIter   *end);
+GDK_AVAILABLE_IN_ALL
 gboolean gtk_text_buffer_delete_interactive (GtkTextBuffer *buffer,
 					     GtkTextIter   *start_iter,
 					     GtkTextIter   *end_iter,
 					     gboolean       default_editable);
+GDK_AVAILABLE_IN_ALL
 gboolean gtk_text_buffer_backspace          (GtkTextBuffer *buffer,
 					     GtkTextIter   *iter,
 					     gboolean       interactive,
 					     gboolean       default_editable);
 
 /* Obtain strings from the buffer */
+GDK_AVAILABLE_IN_ALL
 gchar          *gtk_text_buffer_get_text            (GtkTextBuffer     *buffer,
                                                      const GtkTextIter *start,
                                                      const GtkTextIter *end,
                                                      gboolean           include_hidden_chars);
 
+GDK_AVAILABLE_IN_ALL
 gchar          *gtk_text_buffer_get_slice           (GtkTextBuffer     *buffer,
                                                      const GtkTextIter *start,
                                                      const GtkTextIter *end,
                                                      gboolean           include_hidden_chars);
 
 /* Insert a pixbuf */
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_insert_pixbuf         (GtkTextBuffer *buffer,
                                             GtkTextIter   *iter,
                                             GdkPixbuf     *pixbuf);
 
 /* Insert a child anchor */
+GDK_AVAILABLE_IN_ALL
 void               gtk_text_buffer_insert_child_anchor (GtkTextBuffer      *buffer,
                                                         GtkTextIter        *iter,
                                                         GtkTextChildAnchor *anchor);
 
 /* Convenience, create and insert a child anchor */
+GDK_AVAILABLE_IN_ALL
 GtkTextChildAnchor *gtk_text_buffer_create_child_anchor (GtkTextBuffer *buffer,
                                                          GtkTextIter   *iter);
 
 /* Mark manipulation */
+GDK_AVAILABLE_IN_ALL
 void           gtk_text_buffer_add_mark    (GtkTextBuffer     *buffer,
                                             GtkTextMark       *mark,
                                             const GtkTextIter *where);
+GDK_AVAILABLE_IN_ALL
 GtkTextMark   *gtk_text_buffer_create_mark (GtkTextBuffer     *buffer,
                                             const gchar       *mark_name,
                                             const GtkTextIter *where,
                                             gboolean           left_gravity);
+GDK_AVAILABLE_IN_ALL
 void           gtk_text_buffer_move_mark   (GtkTextBuffer     *buffer,
                                             GtkTextMark       *mark,
                                             const GtkTextIter *where);
+GDK_AVAILABLE_IN_ALL
 void           gtk_text_buffer_delete_mark (GtkTextBuffer     *buffer,
                                             GtkTextMark       *mark);
+GDK_AVAILABLE_IN_ALL
 GtkTextMark*   gtk_text_buffer_get_mark    (GtkTextBuffer     *buffer,
                                             const gchar       *name);
 
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_move_mark_by_name   (GtkTextBuffer     *buffer,
                                           const gchar       *name,
                                           const GtkTextIter *where);
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_delete_mark_by_name (GtkTextBuffer     *buffer,
                                           const gchar       *name);
 
+GDK_AVAILABLE_IN_ALL
 GtkTextMark* gtk_text_buffer_get_insert          (GtkTextBuffer *buffer);
+GDK_AVAILABLE_IN_ALL
 GtkTextMark* gtk_text_buffer_get_selection_bound (GtkTextBuffer *buffer);
 
 /* efficiently move insert and selection_bound at the same time */
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_place_cursor (GtkTextBuffer     *buffer,
                                    const GtkTextIter *where);
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_select_range (GtkTextBuffer     *buffer,
                                    const GtkTextIter *ins,
 				   const GtkTextIter *bound);
@@ -270,22 +310,27 @@ void gtk_text_buffer_select_range (GtkTextBuffer     *buffer,
 
 
 /* Tag manipulation */
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_apply_tag             (GtkTextBuffer     *buffer,
                                             GtkTextTag        *tag,
                                             const GtkTextIter *start,
                                             const GtkTextIter *end);
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_remove_tag            (GtkTextBuffer     *buffer,
                                             GtkTextTag        *tag,
                                             const GtkTextIter *start,
                                             const GtkTextIter *end);
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_apply_tag_by_name     (GtkTextBuffer     *buffer,
                                             const gchar       *name,
                                             const GtkTextIter *start,
                                             const GtkTextIter *end);
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_remove_tag_by_name    (GtkTextBuffer     *buffer,
                                             const gchar       *name,
                                             const GtkTextIter *start,
                                             const GtkTextIter *end);
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_remove_all_tags       (GtkTextBuffer     *buffer,
                                             const GtkTextIter *start,
                                             const GtkTextIter *end);
@@ -294,6 +339,7 @@ void gtk_text_buffer_remove_all_tags       (GtkTextBuffer     *buffer,
 /* You can either ignore the return value, or use it to
  * set the attributes of the tag. tag_name can be NULL
  */
+GDK_AVAILABLE_IN_ALL
 GtkTextTag    *gtk_text_buffer_create_tag (GtkTextBuffer *buffer,
                                            const gchar   *tag_name,
                                            const gchar   *first_property_name,
@@ -302,31 +348,40 @@ GtkTextTag    *gtk_text_buffer_create_tag (GtkTextBuffer *buffer,
 /* Obtain iterators pointed at various places, then you can move the
  * iterator around using the GtkTextIter operators
  */
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_get_iter_at_line_offset (GtkTextBuffer *buffer,
                                               GtkTextIter   *iter,
                                               gint           line_number,
                                               gint           char_offset);
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_get_iter_at_line_index  (GtkTextBuffer *buffer,
                                               GtkTextIter   *iter,
                                               gint           line_number,
                                               gint           byte_index);
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_get_iter_at_offset      (GtkTextBuffer *buffer,
                                               GtkTextIter   *iter,
                                               gint           char_offset);
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_get_iter_at_line        (GtkTextBuffer *buffer,
                                               GtkTextIter   *iter,
                                               gint           line_number);
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_get_start_iter          (GtkTextBuffer *buffer,
                                               GtkTextIter   *iter);
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_get_end_iter            (GtkTextBuffer *buffer,
                                               GtkTextIter   *iter);
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_get_bounds              (GtkTextBuffer *buffer,
                                               GtkTextIter   *start,
                                               GtkTextIter   *end);
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_get_iter_at_mark        (GtkTextBuffer *buffer,
                                               GtkTextIter   *iter,
                                               GtkTextMark   *mark);
 
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_get_iter_at_child_anchor (GtkTextBuffer      *buffer,
                                                GtkTextIter        *iter,
                                                GtkTextChildAnchor *anchor);
@@ -340,39 +395,53 @@ void gtk_text_buffer_get_iter_at_child_anchor (GtkTextBuffer      *buffer,
    flag, but if you would like them to you can connect a handler to
    the tag/mark signals and call set_modified in your handler */
 
+GDK_AVAILABLE_IN_ALL
 gboolean        gtk_text_buffer_get_modified            (GtkTextBuffer *buffer);
+GDK_AVAILABLE_IN_ALL
 void            gtk_text_buffer_set_modified            (GtkTextBuffer *buffer,
                                                          gboolean       setting);
 
+GDK_AVAILABLE_IN_ALL
 gboolean        gtk_text_buffer_get_has_selection       (GtkTextBuffer *buffer);
 
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_add_selection_clipboard    (GtkTextBuffer     *buffer,
 						 GtkClipboard      *clipboard);
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_remove_selection_clipboard (GtkTextBuffer     *buffer,
 						 GtkClipboard      *clipboard);
 
+GDK_AVAILABLE_IN_ALL
 void            gtk_text_buffer_cut_clipboard           (GtkTextBuffer *buffer,
 							 GtkClipboard  *clipboard,
                                                          gboolean       default_editable);
+GDK_AVAILABLE_IN_ALL
 void            gtk_text_buffer_copy_clipboard          (GtkTextBuffer *buffer,
 							 GtkClipboard  *clipboard);
+GDK_AVAILABLE_IN_ALL
 void            gtk_text_buffer_paste_clipboard         (GtkTextBuffer *buffer,
 							 GtkClipboard  *clipboard,
 							 GtkTextIter   *override_location,
                                                          gboolean       default_editable);
 
+GDK_AVAILABLE_IN_ALL
 gboolean        gtk_text_buffer_get_selection_bounds    (GtkTextBuffer *buffer,
                                                          GtkTextIter   *start,
                                                          GtkTextIter   *end);
+GDK_AVAILABLE_IN_ALL
 gboolean        gtk_text_buffer_delete_selection        (GtkTextBuffer *buffer,
                                                          gboolean       interactive,
                                                          gboolean       default_editable);
 
 /* Called to specify atomic user actions, used to implement undo */
+GDK_AVAILABLE_IN_ALL
 void            gtk_text_buffer_begin_user_action       (GtkTextBuffer *buffer);
+GDK_AVAILABLE_IN_ALL
 void            gtk_text_buffer_end_user_action         (GtkTextBuffer *buffer);
 
+GDK_AVAILABLE_IN_ALL
 GtkTargetList * gtk_text_buffer_get_copy_target_list    (GtkTextBuffer *buffer);
+GDK_AVAILABLE_IN_ALL
 GtkTargetList * gtk_text_buffer_get_paste_target_list   (GtkTextBuffer *buffer);
 
 /* INTERNAL private stuff */
