@@ -30,8 +30,8 @@
 #include "gtklabel.h"
 #include "gtkmain.h"
 #include "gtkmarshalers.h"
-#include "gtktoggleaction.h"
-#include "gtkactivatable.h"
+#include "deprecated/gtktoggleaction.h"
+#include "deprecated/gtkactivatable.h"
 #include "gtkprivate.h"
 #include "gtkintl.h"
 #include "a11y/gtktogglebuttonaccessible.h"
@@ -60,7 +60,7 @@
  *
  * <example>
  * <title>Creating two #GtkToggleButton widgets.</title>
- * <programlisting>
+ * |[<!-- language="C" -->
  * void make_toggles (void) {
  *    GtkWidget *dialog, *toggle1, *toggle2;
  *
@@ -84,7 +84,7 @@
  *
  *    gtk_widget_show_all (dialog);
  * }
- * </programlisting>
+ * ]|
  * </example>
  */
 
