@@ -53,7 +53,7 @@
  * to a #GtkToolPalette. To add a #GtkToolItemGroup to a #GtkToolPalette,
  * use gtk_container_add().
  *
- * |[
+ * |[<!-- language="C" -->
  * GtkWidget *palette, *group;
  * GtkToolItem *item;
  *
@@ -61,7 +61,8 @@
  * group = gtk_tool_item_group_new (_("Test Category"));
  * gtk_container_add (GTK_CONTAINER (palette), group);
  *
- * item = gtk_tool_button_new_from_stock (GTK_STOCK_OK);
+ * item = gtk_tool_button_new_new (NULL, _("_Open"));
+ * gtk_tool_button_set_icon_name (GTK_TOOL_BUTTON (item), "document-open");
  * gtk_tool_item_group_insert (GTK_TOOL_ITEM_GROUP (group), item, -1);
  * ]|
  *
@@ -71,7 +72,7 @@
  * can be used to get the dragged item in the #GtkWidget::drag-data-received
  * signal handler of the drag target.
  *
- * |[
+ * |[<!-- language="C" -->
  * static void
  * passive_canvas_drag_data_received (GtkWidget        *widget,
  *                                    GdkDragContext   *context,
@@ -161,9 +162,6 @@ struct _GtkToolPalettePrivate
 
   GtkSizeGroup         *text_size_group;
 
-  GtkSettings          *settings;
-  gulong                settings_connection;
-
   guint                 drag_source : 2;
 
   /* GtkScrollablePolicy needs to be checked when
@@ -194,18 +192,16 @@ static void gtk_tool_palette_set_vadjustment (GtkToolPalette *palette,
 
 
 G_DEFINE_TYPE_WITH_CODE (GtkToolPalette,
-               gtk_tool_palette,
-               GTK_TYPE_CONTAINER,
-               G_IMPLEMENT_INTERFACE (GTK_TYPE_ORIENTABLE, NULL)
-	       G_IMPLEMENT_INTERFACE (GTK_TYPE_SCROLLABLE, NULL))
+                         gtk_tool_palette,
+                         GTK_TYPE_CONTAINER,
+                         G_ADD_PRIVATE (GtkToolPalette)
+                         G_IMPLEMENT_INTERFACE (GTK_TYPE_ORIENTABLE, NULL)
+                         G_IMPLEMENT_INTERFACE (GTK_TYPE_SCROLLABLE, NULL))
 
 static void
 gtk_tool_palette_init (GtkToolPalette *palette)
 {
-  palette->priv = G_TYPE_INSTANCE_GET_PRIVATE (palette,
-                                               GTK_TYPE_TOOL_PALETTE,
-                                               GtkToolPalettePrivate);
-
+  palette->priv = gtk_tool_palette_get_instance_private (palette);
   palette->priv->groups = g_ptr_array_sized_new (4);
   g_ptr_array_set_free_func (palette->priv->groups, g_free);
 
@@ -389,14 +385,6 @@ gtk_tool_palette_dispose (GObject *object)
       palette->priv->text_size_group = NULL;
     }
 
-  if (palette->priv->settings_connection > 0)
-    {
-      g_signal_handler_disconnect (palette->priv->settings, palette->priv->settings_connection);
-      palette->priv->settings_connection = 0;
-    }
-
-  g_clear_object (&palette->priv->settings);
-
   G_OBJECT_CLASS (gtk_tool_palette_parent_class)->dispose (object);
 }
 
@@ -891,77 +879,11 @@ gtk_tool_palette_get_child_property (GtkContainer *container,
     }
 }
 
-static void
-style_change_notify (GtkToolPalette *palette)
-{
-  GtkToolPalettePrivate* priv = palette->priv;
-
-  if (!priv->style_set)
-    {
-      /* pretend it was set, then unset, thus reverting to new default */
-      priv->style_set = TRUE;
-      gtk_tool_palette_unset_style (palette);
-    }
-}
-
-static void
-icon_size_change_notify (GtkToolPalette *palette)
-{
-  GtkToolPalettePrivate* priv = palette->priv;
-
-  if (!priv->icon_size_set)
-    {
-      /* pretend it was set, then unset, thus reverting to new default */
-      priv->icon_size_set = TRUE;
-      gtk_tool_palette_unset_icon_size (palette);
-    }
-}
-
-static void
-gtk_tool_palette_settings_change_notify (GtkSettings      *settings,
-                                         const GParamSpec *pspec,
-                                         GtkToolPalette   *palette)
-{
-  if (strcmp (pspec->name, "gtk-toolbar-style") == 0)
-    style_change_notify (palette);
-  else if (strcmp (pspec->name, "gtk-toolbar-icon-size") == 0)
-    icon_size_change_notify (palette);
-}
-
 static void
 gtk_tool_palette_screen_changed (GtkWidget *widget,
                                  GdkScreen *previous_screen)
 {
   GtkToolPalette *palette = GTK_TOOL_PALETTE (widget);
-  GtkToolPalettePrivate* priv = palette->priv;
-  GtkSettings *old_settings = priv->settings;
-  GtkSettings *settings;
-
-  if (gtk_widget_has_screen (GTK_WIDGET (palette)))
-    settings = gtk_widget_get_settings (GTK_WIDGET (palette));
-  else
-    settings = NULL;
-
-  if (settings == old_settings)
-    return;
-
-  if (old_settings)
-  {
-    g_signal_handler_disconnect (old_settings, priv->settings_connection);
-    priv->settings_connection = 0;
-    g_object_unref (old_settings);
-  }
-
-  if (settings)
-  {
-    priv->settings_connection =
-      g_signal_connect (settings, "notify",
-                        G_CALLBACK (gtk_tool_palette_settings_change_notify),
-                        palette);
-    priv->settings = g_object_ref (settings);
-  }
-  else
-    priv->settings = NULL;
 
   gtk_tool_palette_reconfigured (palette);
 }
@@ -991,7 +913,7 @@ gtk_tool_palette_class_init (GtkToolPaletteClass *cls)
   cclass->set_child_property  = gtk_tool_palette_set_child_property;
   cclass->get_child_property  = gtk_tool_palette_get_child_property;
 
-  /* Handle screen-changed so we can update our GtkSettings.
+  /* Handle screen-changed so we can update our configuration.
    */
   wclass->screen_changed      = gtk_tool_palette_screen_changed;
 
@@ -1005,9 +927,8 @@ gtk_tool_palette_class_init (GtkToolPaletteClass *cls)
   /**
    * GtkToolPalette:icon-size:
    *
-   * The size of the icons in a tool palette is normally determined by
-   * the #GtkSettings:gtk-toolbar-icon-size setting. When this property is set,
-   * it overrides the setting.
+   * The size of the icons in a tool palette. When this property is set,
+   * it overrides the default setting.
    *
    * This should only be used for special-purpose tool palettes, normal
    * application tool palettes should respect the user preferences for the
@@ -1084,8 +1005,6 @@ gtk_tool_palette_class_init (GtkToolPaletteClass *cls)
                                                                     P_("Whether the item group should receive extra space when the palette grows"),
                                                                     DEFAULT_CHILD_EXPAND,
                                                                     GTK_PARAM_READWRITE));
-
-  g_type_class_add_private (cls, sizeof (GtkToolPalettePrivate));
 }
 
 /**
@@ -1141,13 +1060,6 @@ gtk_tool_palette_set_icon_size (GtkToolPalette *palette,
   gtk_widget_queue_resize (GTK_WIDGET (palette));
 }
 
-static GtkSettings *
-toolpalette_get_settings (GtkToolPalette *palette)
-{
-  GtkToolPalettePrivate *priv = palette->priv;
-  return priv->settings;
-}
-
 /**
  * gtk_tool_palette_unset_icon_size:
  * @palette: a #GtkToolPalette
@@ -1167,22 +1079,13 @@ gtk_tool_palette_unset_icon_size (GtkToolPalette *palette)
 
   if (palette->priv->icon_size_set)
     {
-      GtkSettings *settings = toolpalette_get_settings (palette);
-
-      if (settings)
-        {
-          g_object_get (settings,
-            "gtk-toolbar-icon-size", &size,
-            NULL);
-        }
-      else
-        size = DEFAULT_ICON_SIZE;
+      size = DEFAULT_ICON_SIZE;
 
       if (size != palette->priv->icon_size)
       {
         gtk_tool_palette_set_icon_size (palette, size);
         g_object_notify (G_OBJECT (palette), "icon-size");
-	    }
+      }
 
       priv->icon_size_set = FALSE;
       g_object_notify (G_OBJECT (palette), "icon-size-set");
@@ -1250,14 +1153,7 @@ gtk_tool_palette_unset_style (GtkToolPalette *palette)
 
   if (priv->style_set)
     {
-      GtkSettings *settings = toolpalette_get_settings (palette);
-
-      if (settings)
-        g_object_get (settings,
-                      "gtk-toolbar-style", &style,
-                      NULL);
-      else
-        style = DEFAULT_TOOLBAR_STYLE;
+      style = DEFAULT_TOOLBAR_STYLE;
 
       if (style != priv->style)
         gtk_tool_palette_change_style (palette, style);
