@@ -42,9 +42,10 @@
  * SECTION:gtktreeviewcolumn
  * @Short_description: A visible column in a GtkTreeView widget
  * @Title: GtkTreeViewColumn
- * @See_also: #GtkTreeView, #GtkTreeSelection, #GtkTreeDnd, #GtkTreeMode, #GtkTreeSortable,
+ * @See_also: #GtkTreeView, #GtkTreeSelection, #GtkTreeModel, #GtkTreeSortable,
  *   #GtkTreeModelSort, #GtkListStore, #GtkTreeStore, #GtkCellRenderer, #GtkCellEditable,
- *   #GtkCellRendererPixbuf, #GtkCellRendererText, #GtkCellRendererToggle
+ *   #GtkCellRendererPixbuf, #GtkCellRendererText, #GtkCellRendererToggle,
+ *   <link linkend="gtk3-GtkTreeView-drag-and-drop">GtkTreeView drag-and-drop</link>
  *
  * The GtkTreeViewColumn object represents a visible column in a #GtkTreeView widget.
  * It allows to set properties of the column header, and functions as a holding pen for
@@ -464,7 +465,7 @@ gtk_tree_view_column_init (GtkTreeViewColumn *tree_column)
   priv->button = NULL;
   priv->xalign = 0.0;
   priv->width = 0;
-  priv->padding = -1;
+  priv->padding = 0;
   priv->min_width = -1;
   priv->max_width = -1;
   priv->column_type = GTK_TREE_VIEW_COLUMN_GROW_ONLY;
@@ -1652,7 +1653,7 @@ gtk_tree_view_column_new_with_area (GtkCellArea *area)
  * gtk_tree_view_column_set_attributes() on the newly created #GtkTreeViewColumn.
  *
  * Here's a simple example:
- * |[
+ * |[<!-- language="C" -->
  *  enum { TEXT_COLUMN, COLOR_COLUMN, N_COLUMNS };
  *  ...
  *  {
@@ -2794,7 +2795,7 @@ gtk_tree_view_column_get_sort_indicator  (GtkTreeViewColumn     *tree_column)
  *
  * Changes the appearance of the sort indicator. 
  * 
- * This <emphasis>does not</emphasis> actually sort the model.  Use
+ * This does not actually sort the model.  Use
  * gtk_tree_view_column_set_sort_column_id() if you want automatic sorting
  * support.  This function is primarily for custom sorting behavior, and should
  * be used in conjunction with gtk_tree_sortable_set_sort_column_id() to do
