@@ -38,6 +38,13 @@
 G_BEGIN_DECLS
 
 /* Kinds of widget-specific help */
+/**
+ * GtkWidgetHelpType:
+ * @GTK_WIDGET_HELP_TOOLTIP: Tooltip.
+ * @GTK_WIDGET_HELP_WHATS_THIS: What's this.
+ *
+ * Kinds of widget-specific help. Used by the ::show-help signal.
+ */
 typedef enum
 {
   GTK_WIDGET_HELP_TOOLTIP,
@@ -68,7 +75,7 @@ typedef struct _GtkWidgetAuxInfo       GtkWidgetAuxInfo;
  * @width: the width of the widget's allocated area.
  * @height: the height of the widget's allocated area.
  *
- * A <structname>GtkAllocation</structname> of a widget represents region
+ * A #GtkAllocation-struct of a widget represents region
  * which has been allocated to the widget by its parent. It is a subregion
  * of its parents allocation. See <xref linkend="geometry-management"/> for
  * more information.
@@ -108,7 +115,7 @@ typedef gboolean (*GtkTickCallback) (GtkWidget     *widget,
  * @width: the widget's desired width
  * @height: the widget's desired height
  *
- * A <structname>GtkRequisition</structname> represents the desired size of a widget. See
+ * A #GtkRequisition-struct represents the desired size of a widget. See
  * <xref linkend="geometry-management"/> for more information.
  */
 struct _GtkRequisition
@@ -138,6 +145,46 @@ struct _GtkWidget
  * @activate_signal: The signal to emit when a widget of this class is
  *   activated, gtk_widget_activate() handles the emission.
  *   Implementation of this signal is optional.
+ * @dispatch_child_properties_changed: Seldomly overidden.
+ * @destroy: Signals that all holders of a reference to the widget
+ *   should release the reference that they hold.
+ * @show: Signal emitted when widget is shown
+ * @show_all: Recursively shows a widget, and any child widgets (if the widget is
+ * a container).
+ * @hide: Signal emitted when widget is hidden.
+ * @map: Signal emitted when widget is going to be mapped, that is
+ *   when the widget is visible (which is controlled with
+ *   gtk_widget_set_visible()) and all its parents up to the toplevel
+ *   widget are also visible.
+ * @unmap: Signal emitted when widget is going to be unmapped, which
+ *   means that either it or any of its parents up to the toplevel
+ *   widget have been set as hidden.
+ * @realize: Signal emitted when widget is associated with a
+ *   #GdkWindow, which means that gtk_widget_realize() has been called or
+ *   the widget has been mapped (that is, it is going to be drawn).
+ * @unrealize: Signal emitted when the GdkWindow associated with
+ *   widget is destroyed, which means that gtk_widget_unrealize() has
+ *   been called or the widget has been unmapped (that is, it is going
+ *   to be hidden).
+ * @size_allocate: Signal emitted to get the widget allocation.
+ * @state_changed: Signal emitted when the widget state
+ *   changes. Deprecated: 3.0
+ * @state_flags_changed: Signal emitted when the widget state changes,
+ *   see gtk_widget_get_state_flags().
+ * @parent_set: Signal emitted when a new parent has been set on a
+ *   widget.
+ * @hierarchy_changed: Signal emitted when the anchored state of a
+ *   widget changes.
+ * @style_set: Signal emitted when a new style has been set on a
+ * widget. Deprecated: 3.0
+ * @direction_changed: Signal emitted when the text direction of a
+ *   widget changes.
+ * @grab_notify: Signal emitted when a widget becomes shadowed by a
+ *   GTK+ grab (not a pointer or keyboard grab) on another widget, or
+ *   when it becomes unshadowed due to a grab being removed.
+ * @child_notify: Signal emitted for each child property that has
+ *   changed on an object.
+ * @draw: Signal emitted when a widget is supposed to render itself.
  * @get_request_mode: This allows a widget to tell its parent container whether
  *   it prefers to be allocated in %GTK_SIZE_REQUEST_HEIGHT_FOR_WIDTH or
  *   %GTK_SIZE_REQUEST_WIDTH_FOR_HEIGHT mode.
@@ -176,6 +223,99 @@ struct _GtkWidget
  *   contextual width to request height for. By implementing this virtual
  *   method it is possible for a #GtkLabel to tell its parent how much height
  *   would be required if the label were to be allocated a said width.
+ * @mnemonic_activate: Activates the @widget if @group_cycling is
+ *   %FALSE, and just grabs the focus if @group_cycling is %TRUE.
+ * @grab_focus: Causes @widget to have the keyboard focus for the
+ *   #GtkWindow it's inside.
+ * @focus:
+ * @move_focus: Signal emitted when a change of focus is requested
+ * @keynav_failed: Signal emitted if keyboard navigation fails.
+ * @event: The GTK+ main loop will emit three signals for each GDK
+ *   event delivered to a widget: one generic ::event signal, another,
+ *   more specific, signal that matches the type of event delivered
+ *   (e.g. "key-press-event") and finally a generic "event-after"
+ *   signal.
+ * @button_press_event: Signal will be emitted when a button
+ *   (typically from a mouse) is pressed.
+ * @button_release_event: Signal will be emitted when a button
+ *   (typically from a mouse) is released.
+ * @scroll_event: Signal emitted when a button in the 4 to 7 range is
+ *   pressed.
+ * @motion_notify_event: Signal emitted when the pointer moves over
+ *   the widget's #GdkWindow.
+ * @delete_event: Signal emitted if a user requests that a toplevel
+ *   window is closed.
+ * @destroy_event: Signal is emitted when a #GdkWindow is destroyed.
+ * @key_press_event: Signal emitted when a key is pressed.
+ * @key_release_event: Signal is emitted when a key is released.
+ * @enter_notify_event: Signal event will be emitted when the pointer
+ *   enters the widget's window.
+ * @leave_notify_event: Will be emitted when the pointer leaves the
+ *   widget's window.
+ * @configure_event: Signal will be emitted when the size, position or
+ *   stacking of the widget's window has changed.
+ * @focus_in_event: Signal emitted when the keyboard focus enters the
+ * widget's window.
+ * @focus_out_event: Signal emitted when the keyboard focus leaves the
+ * widget's window.
+ * @map_event: Signal emitted when the widget's window is mapped.
+ * @unmap_event: Signal will be emitted when the widget's window is
+ *   unmapped.
+ * @property_notify_event: Signal will be emitted when a property on
+ *   the widget's window has been changed or deleted.
+ * @selection_clear_event: Signal will be emitted when the the
+ *   widget's window has lost ownership of a selection.
+ * @selection_request_event: Signal will be emitted when another
+ *   client requests ownership of the selection owned by the widget's
+ *   window.
+ * @selection_notify_event:
+ * @proximity_in_event:
+ * @proximity_out_event:
+ * @visibility_notify_event: Signal emitted when the widget's window is
+ *   obscured or unobscured.
+ * @window_state_event: Signal emitted when the state of the toplevel
+ *   window associated to the widget changes.
+ * @damage_event: Signal emitted when a redirected window belonging to
+ *   widget gets drawn into.
+ * @grab_broken_event: Signal emitted when a pointer or keyboard grab
+ *   on a window belonging to widget gets broken.
+ * @selection_get:
+ * @selection_received:
+ * @drag_begin: Signal emitted on the drag source when a drag is
+ *   started.
+ * @drag_end: Signal emitted on the drag source when a drag is
+ *   finished.
+ * @drag_data_get: Signal emitted on the drag source when the drop
+ *   site requests the data which is dragged.
+ * @drag_data_delete: Signal emitted on the drag source when a drag
+ *   with the action %GDK_ACTION_MOVE is successfully completed.
+ * @drag_leave: Signal emitted on the drop site when the cursor leaves
+ *   the widget.
+ * @drag_motion: signal emitted on the drop site when the user moves
+ *   the cursor over the widget during a drag.
+ * @drag_drop: Signal emitted on the drop site when the user drops the
+ *   data onto the widget.
+ * @drag_data_received: Signal emitted on the drop site when the
+ *   dragged data has been received.
+ * @drag_failed: Signal emitted on the drag source when a drag has
+ *   failed.
+ * @popup_menu: Signal emitted whenever a widget should pop up a
+ *   context menu.
+ * @show_help:
+ * @get_accessible: Returns the accessible object that describes the
+ *   widget to an assistive technology.
+ * @screen_changed: Signal emitted when the screen of a widget has
+ *   changed.
+ * @can_activate_accel: Signal allows applications and derived widgets
+ *   to override the default GtkWidget handling for determining whether
+ *   an accelerator can be activated.
+ * @composited_changed: Signal emitted when the composited status of
+ *   widgets screen changes. See gdk_screen_is_composited().
+ * @query_tooltip: Signal emitted when "has-tooltip" is %TRUE and the
+ *   hover timeout has expired with the cursor hovering "above"
+ *   widget; or emitted when widget got focus in keyboard mode.
+ * @compute_expand: Computes whether a container should give this
+ *   widget extra space when possible.
  * @adjust_size_request: Convert an initial size request from a widget's
  *   #GtkSizeRequestMode virtual method implementations into a size request to
  *   be used by parent containers in laying out the widget.
@@ -206,6 +346,15 @@ struct _GtkWidget
  *   passed in should be adjusted in the same way as the allocated size,
  *   which allows adjustments to perform alignments or other changes
  *   based on natural size.
+ * @style_updated: Signal emitted when the GtkStyleContext of a widget
+ *   is changed.
+ * @touch_event:
+ * @get_preferred_height_and_baseline_for_width:
+ * @adjust_baseline_request:
+ * @adjust_baseline_allocation:
+ * @queue_draw_region: Invalidates the area of widget defined by
+ *   region by calling gdk_window_invalidate_region() on the widget's
+ *   window and all its child windows.
  */
 struct _GtkWidgetClass
 {
@@ -456,6 +605,15 @@ struct _GtkWidgetClass
   void (*_gtk_reserved7) (void);
 };
 
+/**
+ * GtkWidgetAuxInfo:
+ * @width: the widget's width
+ * @height: the widget's height
+ * @halign: the widget's horizontal alignment
+ * @valign: the widget's horizontal alignment
+ * @margin: the widget's #GtkBorder margins
+ *
+ */
 struct _GtkWidgetAuxInfo
 {
   gint width;
@@ -852,7 +1010,7 @@ GDK_AVAILABLE_IN_3_10
 gint          gtk_widget_get_scale_factor (GtkWidget *widget);
 GDK_AVAILABLE_IN_ALL
 GdkDisplay *  gtk_widget_get_display     (GtkWidget *widget);
-GDK_AVAILABLE_IN_ALL
+GDK_DEPRECATED_IN_3_12
 GdkWindow *   gtk_widget_get_root_window (GtkWidget *widget);
 GDK_AVAILABLE_IN_ALL
 GtkSettings*  gtk_widget_get_settings    (GtkWidget *widget);
