@@ -135,8 +135,8 @@ button_clicked (GtkButton *b,
   w = gtk_file_chooser_dialog_new ("Select file",
                                    GTK_WINDOW (toplevel),
                                    GTK_FILE_CHOOSER_ACTION_OPEN,
-                                   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                   GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+                                   "_Cancel", GTK_RESPONSE_CANCEL,
+                                   "_Open", GTK_RESPONSE_ACCEPT,
                                    NULL);
 
   gtk_dialog_run (GTK_DIALOG (w));
