@@ -37,7 +37,9 @@ test_dialog_basic (void)
 
   dialog = gtk_dialog_new();
   g_assert (GTK_IS_DIALOG (dialog));
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   g_assert (gtk_dialog_get_action_area (GTK_DIALOG (dialog)) != NULL);
+G_GNUC_END_IGNORE_DEPRECATIONS
   g_assert (gtk_dialog_get_content_area (GTK_DIALOG (dialog)) != NULL);
 
   gtk_widget_destroy (dialog);
@@ -209,7 +211,7 @@ test_file_chooser_widget_basic (void)
   /* XXX BUG:
    *
    * Spin the mainloop for a bit, this allows the file operations
-   * to complete, GtkFileChooserDefault has a bug where it leaks
+   * to complete, GtkFileChooserWidget has a bug where it leaks
    * GtkTreeRowReferences to the internal shortcuts_model
    *
    * Since we assert all automated children are finalized we
@@ -320,9 +322,19 @@ test_print_unix_dialog_basic (void)
 int
 main (int argc, char **argv)
 {
+  gchar *schema_dir;
+
+  /* These must be set before before gtk_test_init */
+  g_setenv ("GIO_USE_VFS", "local", TRUE);
+  g_setenv ("GSETTINGS_BACKEND", "memory", TRUE);
+
   /* initialize test program */
   gtk_test_init (&argc, &argv);
 
+  /* g_test_build_filename must be called after gtk_test_init */
+  schema_dir = g_test_build_filename (G_TEST_BUILT, "", NULL);
+  g_setenv ("GSETTINGS_SCHEMA_DIR", schema_dir, TRUE);
+
   /* This environment variable cooperates with gtk_widget_destroy()
    * to assert that all automated compoenents are properly finalized
    * when a given composite widget is destroyed.
@@ -355,5 +367,7 @@ main (int argc, char **argv)
   g_test_add_func ("/Template/UnixPrint/GtkPrintUnixDialog/Basic", test_print_unix_dialog_basic);
 #endif
 
+  g_free (schema_dir);
+
   return g_test_run();
 }
